# Read in fold errors of repeated full and incomplete CV
# and the fold errors for calculating the step-specific 
# incomplete CV errors:
########################################################

workspacesafe <- getwd()
setwd("./CVIIMCodeData/Combinations/ResultsCombinations/")

load("comb1_1errorK3.Rda") 
load("comb1_1errorK5.Rda") 
load("comb1_1errorK10.Rda") 

setwd(workspacesafe)


# Calculation of CVIIM_s,n,K:
#############################

# Function to compute the CVIIM_s,n,K-values:

# errorfull: mean error of repeated incomplete CV,
# erroraddon: mean error of repeated full CV
measure <- function(errorfull, erroraddon) {
  meas <- sapply(1 - errorfull/erroraddon, function(x) max(c(0, x)))
  meas[is.na(meas)] <- 0
  return(meas)
}

# CVIIM_s,n,K-values:

measure(mean(errorcomb1K3full), mean(errorcomb1K3addon))
measure(mean(errorcomb1K5full), mean(errorcomb1K5addon))
measure(mean(errorcomb1K10full), mean(errorcomb1K10addon))




# Graphical display of results:
###############################

# Combine e_full, e_incomplete and the step-specific 
# incomplete CV errors in a matrix:

errormat <- cbind(c(mean(errorcomb1K3addon), mean(errorcomb1K3full),
mean(errorcomb1K3woimp), mean(errorcomb1K3wosel),
mean(errorcomb1K3wotuning)),
c(mean(errorcomb1K5addon), mean(errorcomb1K5full),
mean(errorcomb1K5woimp), mean(errorcomb1K5wosel),
mean(errorcomb1K5wotuning)),
c(mean(errorcomb1K10addon), mean(errorcomb1K10full),
mean(errorcomb1K10woimp), mean(errorcomb1K10wosel),
mean(errorcomb1K10wotuning)))

rownames(errormat) <- c("Full", "Incomplete", "Imputation", "Selection", "Tuning")
colnames(errormat) <- c("K3", "K5", "K10")

errormat




Kseq <- c("K = 3", "K = 5", "K = 10")
resultsdata <- data.frame(K=factor(rep(Kseq, each=nrow(errormat)), levels=Kseq),
method=factor(rep(rownames(errormat), times=ncol(errormat)), levels=rownames(errormat)),
error=as.vector(errormat))


xlength <- 0.2
resultsdata2 <- data.frame(resultsdata[rep(1:nrow(resultsdata), each=2),], x=rep(as.numeric(resultsdata$K), each=2) + rep(c(-1,1)*xlength, times=nrow(resultsdata)))
resultsdata2$lineID <- rep(1:nrow(resultsdata), each=2)

library("ggplot2")

p <- ggplot(data=resultsdata2, aes(x=K, y=error)) +
  geom_line(aes(x=x, y=error, group=lineID, color=method)) +
  scale_x_discrete(breaks=1:3, labels=Kseq, expand=c(0.2,-2)) +
  theme(legend.title=element_blank()) +
  scale_color_discrete(labels=c(expression(e["full, K"](bold(s))), expression(e["incompl, K"](bold(s))), "Imputation", "Selection", "Tuning")) +
  labs(x="", y="")

p

ggsave(file="./CVIIMCodeData/Plots/Supplementary Figure 13.eps", width=6, height=3.5)

rm(list=ls());gc()