# Accession number:
datasetid <- "E-GEOD-10320"

# Folder to store the CEL files in:
newfolder <- paste("./CVIIMCodeData/DataRetrieval/DataSetsNormalization/", datasetid, sep="")

# Download RAW data from ArrayExpress:
library("ArrayExpress")

getAE(datasetid, path = newfolder, type = "raw")

# Load Phenodata (for older microarray datasets the 'read.AnnotatedDataFrame' throws an
# error, in which cases the 'srd.txt'-file has to be read in manually):
adf <- try(read.AnnotatedDataFrame(paste(newfolder, "/", datasetid, ".sdrf.txt", sep="")))

if(class(adf)!="try-error") {
  datainfo <- adf@data
  arraydatafile <- "Array.Data.File"
} else {

adf <- readLines(paste("./CVIIMCodeData/DataRetrieval/DataSetsNormalization/", datasetid,"/", datasetid, ".sdrf.txt", sep=""))
table(sapply(adf, function(x) length(strsplit(x, split="\t")[[1]])))

datainfo <- data.frame(matrix(nrow=0, ncol=length(strsplit(adf[1], split="\t")[[1]])))
names(datainfo) <- strsplit(adf[1], split="\t")[[1]]

for(i in 1:(length(adf)-1))
  datainfo[i,] <- strsplit(adf[i+1], split="\t")[[1]]
rownames(datainfo) <- datainfo$'Source Name'

arraydatafile <- "Array Data File"
  
}




# Because the dataset would have been too large to handle from
# a computational point of view, we use a subset of size 100
# observations:
set.seed(1234)
selind <- sort(sample(1:nrow(datainfo), size=100))

selind <- c(2, 4, 5, 6, 7, 9, 12, 14, 15, 16, 17, 18, 20, 22, 23, 
 24, 25, 26, 27, 28, 29, 30, 32, 33, 34, 35, 36, 37, 38, 
 39, 40, 43, 44, 45, 46, 48, 50, 52, 53, 54, 56, 57, 58, 
 60, 61, 62, 63, 66, 67, 70, 71, 72, 73, 74, 79, 81, 82, 
 83, 85, 87, 88, 89, 90, 91, 92, 93, 94, 95, 97, 99, 103, 
 105, 106, 108, 109, 110, 113, 114, 115, 116, 117, 118, 
 119, 120, 121, 122, 124, 125, 126, 127, 129, 131, 132, 133, 
 135, 137, 138, 140, 141, 142)

datainfo <- datainfo[selind,]



# The not used CEL files are removed from the corresponding folder
# to spare memory space:

eval(parse(text=paste("celfiles <- datainfo$'", arraydatafile, "'", sep="")))

allcelfiles <- unique(c(grep(".cel", list.files(newfolder), value=TRUE), grep(".CEL", list.files(newfolder), value=TRUE)))

celfilestodelete <- setdiff(allcelfiles, celfiles)

length(celfilestodelete)
length(celfiles)+length(celfilestodelete)
length(allcelfiles)

for(i in seq(along=celfilestodelete)) {
  if(file.exists(paste(newfolder, "/", celfilestodelete[i], sep=""))) 
    file.remove(paste(newfolder, "/", celfilestodelete[i], sep=""))
}


######################
######################
######################




# Load in the CEL files and perform normalization with RMA:

library("affy")

wdsafe <- getwd()
setwd(newfolder)
aboall <- ReadAffy()
setwd(wdsafe)


library(docval)

functionfolder <- "./CVIIMCodeData/AddOnFunctionsetc/KostkaFunctions/"

allrscripts <- list.files(paste(functionfolder, "Rpack", sep=""), full.names = TRUE)
for(i in seq(along=allrscripts))
  source(allrscripts[i])

source(paste(functionfolder, "summarize_val.R",sep=''))
source(paste(functionfolder, "summarize_add.R",sep=''))
source(paste(functionfolder,'extractAffybatch.r',sep=''))

source("./CVIIMCodeData/AddOnFunctionsetc/Normalization_functions.R")


Xnormwhole <- RMAparam(1:length(aboall), aboall)$normdata



# Check whether the ordering of the observations in the phenodata 'datainfo' is the same
# as in 'Xnormwhole' and in not adjust the ordering:

eval(parse(text=paste("all(rownames(Xnormwhole)[nrow(Xnormwhole):1]==datainfo$'", arraydatafile, "')", sep="")))

eval(parse(text=paste("datainfo <- datainfo[as.numeric(factor(rownames(Xnormwhole), levels=datainfo$'", arraydatafile, "')),]", sep="")))

eval(parse(text=paste("all(rownames(Xnormwhole)==datainfo$'", arraydatafile, "')", sep="")))



# Extract the target variable from 'datainfo' and store it in the same folder
# the CEL files are stored:

y <- factor(as.numeric(datainfo$'Comment [Sample_characteristics]'=="Relapse")+1)
names(y) <- rownames(Xnormwhole)

save(y, file=paste(newfolder, "/target_variable.Rda", sep=""))



# Remove the zip files the CEL files where stored in to spare memory space:

filesinfolder <- list.files(newfolder)

zipfileind <- which(sapply(filesinfolder, function(x) {
  splitted <- strsplit(x, split="")[[1]]
  paste(splitted[(length(splitted)-2):length(splitted)], collapse="")=="zip"
}))

zipfiles <- filesinfolder[zipfileind]

for(i in seq(along=zipfiles)) {
  if(file.exists(paste(newfolder, "/", zipfiles[i], sep=""))) 
    file.remove(paste(newfolder, "/", zipfiles[i], sep=""))
}



# Now check whether there is signal in the gene expression matrix with
# respect to the target variable:

library("CMA")

K <- 5; niter <- 2

cvdatasets <- GenerateLearningsets(y = y, method = "CV", fold = K, niter = niter)

tunenestedcv <- tune(Xnormwhole, y, learningsets = cvdatasets, classifier = scdaCMA)

which.min(tunenestedcv@tuneres[[1]])

nestedcrossval <- classification(Xnormwhole, y, learningsets = cvdatasets, 
  classifier = scdaCMA, tuneres = tunenestedcv)
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 

mean(errortunensc11K3addon)
min(c(mean(y==1), mean(y==2)))



# Look at PCA plots to get further insight into the class signal:

source("./CVIIMCodeData/AddOnFunctionsetc/compplot.R")
compplot(Xnormwhole, groups=factor(y))
