#######################################################################################
#######################################################################################
#
#  This script produces all datasets used in the Normalization study, storing the
#  CEL files and target variable values ("target_variable.Rda") in the corresponding
#  subfolders in "./CVIIMCodeData/DataRetrieval/DataSetsNormalization".
#
#######################################################################################
#######################################################################################








# Dataaset accession number:
datasetid <- "E-GEOD-10320"

# Folder to store the CEL files in:
newfolder <- paste("./CVIIMCodeData/DataRetrieval/DataSetsNormalization/", datasetid, sep="")

# Download RAW data from ArrayExpress:
library("ArrayExpress")

getAE(datasetid, path = newfolder, type = "raw")

# Load Phenodata (for older microarray datasets the 'read.AnnotatedDataFrame' throws an
# error, in which cases the 'srd.txt'-file has to be read in manually):
adf <- try(read.AnnotatedDataFrame(paste(newfolder, "/", datasetid, ".sdrf.txt", sep="")))

if(class(adf)!="try-error") {
  datainfo <- adf@data
  arraydatafile <- "Array.Data.File"
} else {

adf <- readLines(paste("./CVIIMCodeData/DataRetrieval/DataSetsNormalization/", datasetid,"/", datasetid, ".sdrf.txt", sep=""))
table(sapply(adf, function(x) length(strsplit(x, split="\t")[[1]])))

datainfo <- data.frame(matrix(nrow=0, ncol=length(strsplit(adf[1], split="\t")[[1]])))
names(datainfo) <- strsplit(adf[1], split="\t")[[1]]

for(i in 1:(length(adf)-1))
  datainfo[i,] <- strsplit(adf[i+1], split="\t")[[1]]
rownames(datainfo) <- datainfo$'Source Name'

arraydatafile <- "Array Data File"
  
}




# Because the dataset would have been too large to handle from
# a computational point of view, we use a subset of size 100
# observations:
set.seed(1234)
selind <- sort(sample(1:nrow(datainfo), size=100))

selind <- c(2, 4, 5, 6, 7, 9, 12, 14, 15, 16, 17, 18, 20, 22, 23, 
 24, 25, 26, 27, 28, 29, 30, 32, 33, 34, 35, 36, 37, 38, 
 39, 40, 43, 44, 45, 46, 48, 50, 52, 53, 54, 56, 57, 58, 
 60, 61, 62, 63, 66, 67, 70, 71, 72, 73, 74, 79, 81, 82, 
 83, 85, 87, 88, 89, 90, 91, 92, 93, 94, 95, 97, 99, 103, 
 105, 106, 108, 109, 110, 113, 114, 115, 116, 117, 118, 
 119, 120, 121, 122, 124, 125, 126, 127, 129, 131, 132, 133, 
 135, 137, 138, 140, 141, 142)

datainfo <- datainfo[selind,]



# The not used CEL files are removed from the corresponding folder
# to spare memory space:

eval(parse(text=paste("celfiles <- datainfo$'", arraydatafile, "'", sep="")))

allcelfiles <- unique(c(grep(".cel", list.files(newfolder), value=TRUE), grep(".CEL", list.files(newfolder), value=TRUE)))

celfilestodelete <- setdiff(allcelfiles, celfiles)

length(celfilestodelete)
length(celfiles)+length(celfilestodelete)
length(allcelfiles)

for(i in seq(along=celfilestodelete)) {
  if(file.exists(paste(newfolder, "/", celfilestodelete[i], sep=""))) 
    file.remove(paste(newfolder, "/", celfilestodelete[i], sep=""))
}


######################
######################
######################




# Load in the CEL files and perform normalization with RMA:

library("affy")

wdsafe <- getwd()
setwd(newfolder)
aboall <- ReadAffy()
setwd(wdsafe)


library(docval)

functionfolder <- "./CVIIMCodeData/AddOnFunctionsetc/KostkaFunctions/"

allrscripts <- list.files(paste(functionfolder, "Rpack", sep=""), full.names = TRUE)
for(i in seq(along=allrscripts))
  source(allrscripts[i])

source(paste(functionfolder, "summarize_val.R",sep=''))
source(paste(functionfolder, "summarize_add.R",sep=''))
source(paste(functionfolder,'extractAffybatch.r',sep=''))

source("./CVIIMCodeData/AddOnFunctionsetc/Normalization_functions.R")


Xnormwhole <- RMAparam(1:length(aboall), aboall)$normdata



# Check whether the ordering of the observations in the phenodata 'datainfo' is the same
# as in 'Xnormwhole' and in not adjust the ordering:

eval(parse(text=paste("all(rownames(Xnormwhole)[nrow(Xnormwhole):1]==datainfo$'", arraydatafile, "')", sep="")))

eval(parse(text=paste("datainfo <- datainfo[as.numeric(factor(rownames(Xnormwhole), levels=datainfo$'", arraydatafile, "')),]", sep="")))

eval(parse(text=paste("all(rownames(Xnormwhole)==datainfo$'", arraydatafile, "')", sep="")))



# Extract the target variable from 'datainfo' and store it in the same folder
# the CEL files are stored:

y <- factor(as.numeric(datainfo$'Comment [Sample_characteristics]'=="Relapse")+1)
names(y) <- rownames(Xnormwhole)

save(y, file=paste(newfolder, "/target_variable.Rda", sep=""))



# Remove the zip files the CEL files where stored in to spare memory space:

filesinfolder <- list.files(newfolder)

zipfileind <- which(sapply(filesinfolder, function(x) {
  splitted <- strsplit(x, split="")[[1]]
  paste(splitted[(length(splitted)-2):length(splitted)], collapse="")=="zip"
}))

zipfiles <- filesinfolder[zipfileind]

for(i in seq(along=zipfiles)) {
  if(file.exists(paste(newfolder, "/", zipfiles[i], sep=""))) 
    file.remove(paste(newfolder, "/", zipfiles[i], sep=""))
}



# Now check whether there is signal in the gene expression matrix with
# respect to the target variable:

library("CMA")

K <- 5; niter <- 2

cvdatasets <- GenerateLearningsets(y = y, method = "CV", fold = K, niter = niter)

tunenestedcv <- tune(Xnormwhole, y, learningsets = cvdatasets, classifier = scdaCMA)

which.min(tunenestedcv@tuneres[[1]])

nestedcrossval <- classification(Xnormwhole, y, learningsets = cvdatasets, 
  classifier = scdaCMA, tuneres = tunenestedcv)
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 

mean(errortunensc11K3addon)
min(c(mean(y==1), mean(y==2)))



# Look at PCA plots to get further insight into the class signal:

source("./CVIIMCodeData/AddOnFunctionsetc/compplot.R")
# compplot(Xnormwhole, groups=factor(y))





rm(list=ls());gc()





















datasetid <- "E-GEOD-19722"

newfolder <- paste("./CVIIMCodeData/DataRetrieval/DataSetsNormalization/", datasetid, sep="")





library("ArrayExpress")


getAE(datasetid, path = newfolder, type = "raw")


adf <- try(read.AnnotatedDataFrame(paste(newfolder, "/", datasetid, ".sdrf.txt", sep="")))

if(class(adf)!="try-error") {
  datainfo <- adf@data
} else {
  
}




intervar <- datainfo$'Comment..Sample_title.'
intervar[grep("cells obtained from MSKCC", intervar)] <- "cells obtained from MSKCC"
intervar[grep("large airways, basal cell culture smoker", intervar)] <- "large airways, basal cell culture smoker"
intervar[grep("large airways, basal cell culture non-smoker", intervar)] <- "large airways, basal cell culture non-smoker"
intervar[grep("large airways, smoker", intervar)] <- "large airways, smoker"
intervar[grep("large airways, non-smoker", intervar)] <- "large airways, non-smoker"

datainfo$targetvar <- intervar

datainfo <- datainfo[datainfo$targetvar %in% c("large airways, non-smoker", "large airways, smoker"),]


datainfo <- datainfo[datainfo$'Array.Data.File'!="  ",]



celfiles <- datainfo$'Array.Data.File'
allcelfiles <- unique(c(grep(".cel", list.files(newfolder), value=TRUE), grep(".CEL", list.files(newfolder), value=TRUE)))

celfilestodelete <- setdiff(allcelfiles, celfiles)

for(i in seq(along=celfilestodelete)) {
  if(file.exists(paste(newfolder, "/", celfilestodelete[i], sep=""))) 
    file.remove(paste(newfolder, "/", celfilestodelete[i], sep=""))
}



library("affy")

wdsafe <- getwd()
setwd(newfolder)
aboall <- ReadAffy()
setwd(wdsafe)


library(docval)


functionfolder <- "./CVIIMCodeData/AddOnFunctionsetc/KostkaFunctions/"

allrscripts <- list.files(paste(functionfolder, "Rpack", sep=""), full.names = TRUE)
for(i in seq(along=allrscripts))
  source(allrscripts[i])

source(paste(functionfolder, "summarize_val.R",sep=''))
source(paste(functionfolder, "summarize_add.R",sep=''))
source(paste(functionfolder,'extractAffybatch.r',sep=''))


source("./CVIIMCodeData/AddOnFunctionsetc/Normalization_functions.R")



Xnormwhole <- RMAparam(1:length(aboall), aboall)$normdata


all(rownames(Xnormwhole)[nrow(Xnormwhole):1]==datainfo$'Array.Data.File')

datainfo <- datainfo[nrow(datainfo):1,]

y <- factor(as.numeric(datainfo$targetvar=="large airways, smoker")+1)
names(y) <- rownames(Xnormwhole)
save(y, file=paste(newfolder, "/target_variable.Rda", sep=""))



filesinfolder <- list.files(newfolder)

zipfileind <- which(sapply(filesinfolder, function(x) {
  splitted <- strsplit(x, split="")[[1]]
  paste(splitted[(length(splitted)-2):length(splitted)], collapse="")=="zip"
}))

zipfiles <- filesinfolder[zipfileind]

for(i in seq(along=zipfiles)) {
  if(file.exists(paste(newfolder, "/", zipfiles[i], sep=""))) 
    file.remove(paste(newfolder, "/", zipfiles[i], sep=""))
}




library("CMA")

K <- 5; niter <- 2

cvdatasets <- GenerateLearningsets(y = y, method = "CV", fold = K, niter = niter)

tunenestedcv <- tune(Xnormwhole, y, learningsets = cvdatasets, classifier = scdaCMA)

which.min(tunenestedcv@tuneres[[1]])

nestedcrossval <- classification(Xnormwhole, y, learningsets = cvdatasets, 
  classifier = scdaCMA, tuneres = tunenestedcv)
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 

mean(errortunensc11K3addon)
min(c(mean(y==1), mean(y==2)))




source("./CVIIMCodeData/AddOnFunctionsetc/compplot.R")
# compplot(Xnormwhole, groups=y)





rm(list=ls());gc()





















datasetid <- "E-GEOD-25639"

newfolder <- paste("./CVIIMCodeData/DataRetrieval/DataSetsNormalization/", datasetid, sep="")





library("ArrayExpress")

getAE(datasetid, path = newfolder, type = "raw")


adf <- try(read.AnnotatedDataFrame(paste(newfolder, "/", datasetid, ".sdrf.txt", sep="")))

if(class(adf)!="try-error") {
  datainfo <- adf@data
  arraydatafile <- "Array.Data.File"
} else {

adf <- readLines(paste("./CVIIMCodeData/DataRetrieval/DataSetsNormalization/", datasetid,"/", datasetid, ".sdrf.txt", sep=""))
table(sapply(adf, function(x) length(strsplit(x, split="\t")[[1]])))

datainfo <- data.frame(matrix(nrow=0, ncol=length(strsplit(adf[1], split="\t")[[1]])))
names(datainfo) <- strsplit(adf[1], split="\t")[[1]]

for(i in 1:(length(adf)-1))
  datainfo[i,] <- strsplit(adf[i+1], split="\t")[[1]]
rownames(datainfo) <- datainfo$'Source Name'

arraydatafile <- "Array Data File"
  
}



datainfo <- datainfo[datainfo$'Characteristics[Organism]'=="Homo sapiens",]

datainfo <- datainfo[datainfo$'Characteristics[disease status]' %in% c("DLBCL", "MALT lymphoma"),]



eval(parse(text=paste("celfiles <- datainfo$'", arraydatafile, "'", sep="")))

allcelfiles <- unique(c(grep(".cel", list.files(newfolder), value=TRUE), grep(".CEL", list.files(newfolder), value=TRUE)))

celfilestodelete <- setdiff(allcelfiles, celfiles)

length(celfilestodelete)
length(celfiles)+length(celfilestodelete)
length(allcelfiles)

for(i in seq(along=celfilestodelete)) {
  if(file.exists(paste(newfolder, "/", celfilestodelete[i], sep=""))) 
    file.remove(paste(newfolder, "/", celfilestodelete[i], sep=""))
}




library("affy")

wdsafe <- getwd()
setwd(newfolder)
aboall <- ReadAffy()
setwd(wdsafe)






library(docval)


functionfolder <- "./CVIIMCodeData/AddOnFunctionsetc/KostkaFunctions/"

allrscripts <- list.files(paste(functionfolder, "Rpack", sep=""), full.names = TRUE)
for(i in seq(along=allrscripts))
  source(allrscripts[i])

source(paste(functionfolder, "summarize_val.R",sep=''))
source(paste(functionfolder, "summarize_add.R",sep=''))
source(paste(functionfolder,'extractAffybatch.r',sep=''))


source("./CVIIMCodeData/AddOnFunctionsetc/Normalization_functions.R")



Xnormwhole <- RMAparam(1:length(aboall), aboall)$normdata



eval(parse(text=paste("all(rownames(Xnormwhole)[nrow(Xnormwhole):1]==datainfo$'", arraydatafile, "')", sep="")))

eval(parse(text=paste("datainfo <- datainfo[as.numeric(factor(rownames(Xnormwhole), levels=datainfo$'", arraydatafile, "')),]", sep="")))

eval(parse(text=paste("all(rownames(Xnormwhole)==datainfo$'", arraydatafile, "')", sep="")))



y <- factor(as.numeric(datainfo$'Characteristics[disease status]'=="DLBCL")+1)
names(y) <- rownames(Xnormwhole)
save(y, file=paste(newfolder, "/target_variable.Rda", sep=""))




filesinfolder <- list.files(newfolder)

zipfileind <- which(sapply(filesinfolder, function(x) {
  splitted <- strsplit(x, split="")[[1]]
  paste(splitted[(length(splitted)-2):length(splitted)], collapse="")=="zip"
}))

zipfiles <- filesinfolder[zipfileind]

for(i in seq(along=zipfiles)) {
  if(file.exists(paste(newfolder, "/", zipfiles[i], sep=""))) 
    file.remove(paste(newfolder, "/", zipfiles[i], sep=""))
}




library("CMA")

K <- 5; niter <- 2

cvdatasets <- GenerateLearningsets(y = y, method = "CV", fold = K, niter = niter)

tunenestedcv <- tune(Xnormwhole, y, learningsets = cvdatasets, classifier = scdaCMA)

which.min(tunenestedcv@tuneres[[1]])

nestedcrossval <- classification(Xnormwhole, y, learningsets = cvdatasets, 
  classifier = scdaCMA, tuneres = tunenestedcv)
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 

mean(errortunensc11K3addon)
min(c(mean(y==1), mean(y==2)))




source("./CVIIMCodeData/AddOnFunctionsetc/compplot.R")
# compplot(Xnormwhole, groups=factor(y))





rm(list=ls());gc()





















datasetid <- "E-GEOD-29044"

newfolder <- paste("./CVIIMCodeData/DataRetrieval/DataSetsNormalization/", datasetid, sep="")





library("ArrayExpress")


getAE(datasetid, path = newfolder, type = "raw")


adf <- try(read.AnnotatedDataFrame(paste(newfolder, "/", datasetid, ".sdrf.txt", sep="")))

if(class(adf)!="try-error") {
  datainfo <- adf@data
} else {
  
}



samplename <- datainfo$'Comment..Sample_title.'
samplename2 <-  sapply(samplename, function(x) strsplit(x, split=" \\(")[[1]][2])
names(samplename2) <- NULL
samplename2 <- gsub(")", "", samplename2)
samplename3 <- sapply(samplename2, function(x) strsplit(x, split=""))
samplename3 <- sapply(samplename3, function(x) {
  if((!is.na(x)) & x[length(x)]=="T")
    x <- x[-length(x)]
  x
})
samplename3 <- sapply(samplename3, function(x) {
  if((!is.na(x)) & x[length(x)]=="N")
    x <- x[-length(x)]
  x
})
samplename4 <- sapply(samplename3, function(x) paste(x, collapse=""))
names(samplename4) <- NULL

appearsonce <- names(table(samplename4[samplename4!="NA"]))[table(samplename4[samplename4!="NA"])==1]


datainfo <- datainfo[samplename4 %in% appearsonce,]




datainfo <- datainfo[!(datainfo$'Array.Data.File' %in% c("GSM719645.CEL", "GSM719646.CEL", "GSM719646CEL", "GSM719647.CEL", "GSM719648.CEL", 
  "GSM719651.CEL", "GSM719653.CEL", 
  "GSM719654.CEL", "GSM719659.CEL", "GSM719660.CEL", "GSM719665.CEL", "GSM719666.CEL", "GSM719667.CEL", "GSM719668.CEL", 
  "GSM719670.CEL", "GSM719671.CEL", "GSM719675.CEL", "GSM719704.CEL", "GSM719706.CEL", "GSM719707.CEL", "GSM719710.CEL", 
  "GSM719711.CEL", "GSM719712.CEL", "GSM719713.CEL", "GSM719714.CEL", "GSM719717.CEL", "GSM719727.CEL", "GSM719737.CEL")),]



celfiles <- datainfo$'Array.Data.File'
allcelfiles <- unique(c(grep(".cel", list.files(newfolder), value=TRUE), grep(".CEL", list.files(newfolder), value=TRUE)))

celfilestodelete <- setdiff(allcelfiles, celfiles)

for(i in seq(along=celfilestodelete)) {
  if(file.exists(paste(newfolder, "/", celfilestodelete[i], sep=""))) 
    file.remove(paste(newfolder, "/", celfilestodelete[i], sep=""))
}


library("affy")

wdsafe <- getwd()
setwd(newfolder)
aboall <- ReadAffy()
setwd(wdsafe)



library(docval)


functionfolder <- "./CVIIMCodeData/AddOnFunctionsetc/KostkaFunctions/"

allrscripts <- list.files(paste(functionfolder, "Rpack", sep=""), full.names = TRUE)
for(i in seq(along=allrscripts))
  source(allrscripts[i])

source(paste(functionfolder, "summarize_val.R",sep=''))
source(paste(functionfolder, "summarize_add.R",sep=''))
source(paste(functionfolder,'extractAffybatch.r',sep=''))


source("./CVIIMCodeData/AddOnFunctionsetc/Normalization_functions.R")



Xnormwhole <- RMAparam(1:length(aboall), aboall)$normdata




all(rownames(Xnormwhole)[nrow(Xnormwhole):1]==datainfo$'Array.Data.File')

datainfo <- datainfo[nrow(datainfo):1,]


y <- rep(1, nrow(datainfo))
y[grep("tumor", datainfo$'Comment..Sample_source_name.')] <- 2
y <- factor(y)
names(y) <- rownames(Xnormwhole)
save(y, file=paste(newfolder, "/target_variable.Rda", sep=""))



filesinfolder <- list.files(newfolder)

zipfileind <- which(sapply(filesinfolder, function(x) {
  splitted <- strsplit(x, split="")[[1]]
  paste(splitted[(length(splitted)-2):length(splitted)], collapse="")=="zip"
}))

zipfiles <- filesinfolder[zipfileind]

for(i in seq(along=zipfiles)) {
  if(file.exists(paste(newfolder, "/", zipfiles[i], sep=""))) 
    file.remove(paste(newfolder, "/", zipfiles[i], sep=""))
}




library("CMA")

K <- 5; niter <- 2

cvdatasets <- GenerateLearningsets(y = y, method = "CV", fold = K, niter = niter)

tunenestedcv <- tune(Xnormwhole, y, learningsets = cvdatasets, classifier = scdaCMA)

which.min(tunenestedcv@tuneres[[1]])

nestedcrossval <- classification(Xnormwhole, y, learningsets = cvdatasets, 
  classifier = scdaCMA, tuneres = tunenestedcv)
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 

mean(errortunensc11K3addon)
min(c(mean(y==1), mean(y==2)))




source("./CVIIMCodeData/AddOnFunctionsetc/compplot.R")
# compplot(Xnormwhole, groups=factor(y))








rm(list=ls());gc()





















datasetid <- "E-GEOD-30174"

newfolder <- paste("./CVIIMCodeData/DataRetrieval/DataSetsNormalization/", datasetid, sep="")





library("ArrayExpress")


getAE(datasetid, path = newfolder, type = "raw")


adf <- try(read.AnnotatedDataFrame(paste(newfolder, "/", datasetid, ".sdrf.txt", sep="")))

if(class(adf)!="try-error") {
  datainfo <- adf@data
} else {

adf <- readLines(paste("./CVIIMCodeData/DataRetrieval/DataSetsNormalization/", datasetid,"/", datasetid, ".sdrf.txt", sep=""))
table(sapply(adf, function(x) length(strsplit(x, split="\t")[[1]])))

datainfo <- data.frame(matrix(nrow=0, ncol=length(strsplit(adf[1], split="\t")[[1]])))
names(datainfo) <- strsplit(adf[1], split="\t")[[1]]

for(i in 1:(length(adf)-1))
  datainfo[i,] <- strsplit(adf[i+1], split="\t")[[1]]
rownames(datainfo) <- datainfo$'Source Name'
  
}



datainfo <- datainfo[datainfo$'Characteristics [time of wbc and fatigue score collection]' %in% c("  ", "baseline"),]



celfiles <- datainfo$'Array Data File'

allcelfiles <- unique(c(grep(".cel", list.files(newfolder), value=TRUE), grep(".CEL", list.files(newfolder), value=TRUE)))

celfilestodelete <- setdiff(allcelfiles, celfiles)

length(celfilestodelete)
length(celfiles)+length(celfilestodelete)
length(allcelfiles)

for(i in seq(along=celfilestodelete)) {
  if(file.exists(paste(newfolder, "/", celfilestodelete[i], sep=""))) 
    file.remove(paste(newfolder, "/", celfilestodelete[i], sep=""))
}




library("affy")

wdsafe <- getwd()
setwd(newfolder)
aboall <- ReadAffy()
setwd(wdsafe)




library(docval)


functionfolder <- "./CVIIMCodeData/AddOnFunctionsetc/KostkaFunctions/"

allrscripts <- list.files(paste(functionfolder, "Rpack", sep=""), full.names = TRUE)
for(i in seq(along=allrscripts))
  source(allrscripts[i])

source(paste(functionfolder, "summarize_val.R",sep=''))
source(paste(functionfolder, "summarize_add.R",sep=''))
source(paste(functionfolder,'extractAffybatch.r',sep=''))


source("./CVIIMCodeData/AddOnFunctionsetc/Normalization_functions.R")



Xnormwhole <- RMAparam(1:length(aboall), aboall)$normdata


all(rownames(Xnormwhole)[nrow(Xnormwhole):1]==datainfo$'Array Data File')

datainfo <- datainfo[as.numeric(factor(rownames(Xnormwhole), levels=datainfo$'Array Data File')),]

all(rownames(Xnormwhole)==datainfo$'Array Data File')


y <- factor(as.numeric(datainfo$'Characteristics [disease state]'=="non-metastatic prostate cancer")+1)
names(y) <- rownames(Xnormwhole)
save(y, file=paste(newfolder, "/target_variable.Rda", sep=""))




filesinfolder <- list.files(newfolder)

zipfileind <- which(sapply(filesinfolder, function(x) {
  splitted <- strsplit(x, split="")[[1]]
  paste(splitted[(length(splitted)-2):length(splitted)], collapse="")=="zip"
}))

zipfiles <- filesinfolder[zipfileind]

for(i in seq(along=zipfiles)) {
  if(file.exists(paste(newfolder, "/", zipfiles[i], sep=""))) 
    file.remove(paste(newfolder, "/", zipfiles[i], sep=""))
}



library("CMA")

K <- 5; niter <- 2

cvdatasets <- GenerateLearningsets(y = y, method = "CV", fold = K, niter = niter)

tunenestedcv <- tune(Xnormwhole, y, learningsets = cvdatasets, classifier = scdaCMA)

which.min(tunenestedcv@tuneres[[1]])

nestedcrossval <- classification(Xnormwhole, y, learningsets = cvdatasets, 
  classifier = scdaCMA, tuneres = tunenestedcv)
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 

mean(errortunensc11K3addon)
min(c(mean(y==1), mean(y==2)))




source("./CVIIMCodeData/AddOnFunctionsetc/compplot.R")
# compplot(Xnormwhole, groups=factor(y))






rm(list=ls());gc()





















datasetid <- "E-GEOD-34465"

newfolder <- paste("./CVIIMCodeData/DataRetrieval/DataSetsNormalization/", datasetid, sep="")





library("ArrayExpress")


getAE(datasetid, path = newfolder, type = "raw")


adf <- try(read.AnnotatedDataFrame(paste(newfolder, "/", datasetid, ".sdrf.txt", sep="")))

if(class(adf)!="try-error") {
  datainfo <- adf@data
} else {

adf <- readLines(paste("./CVIIMCodeData/DataRetrieval/DataSetsNormalization/", datasetid,"/", datasetid, ".sdrf.txt", sep=""))
table(sapply(adf, function(x) length(strsplit(x, split="\t")[[1]])))

datainfo <- data.frame(matrix(nrow=0, ncol=length(strsplit(adf[1], split="\t")[[1]])))
names(datainfo) <- strsplit(adf[1], split="\t")[[1]]

for(i in 1:(length(adf)-1))
  datainfo[i,] <- strsplit(adf[i+1], split="\t")[[1]]
rownames(datainfo) <- datainfo$'Source Name'
  
}



datainfo <- datainfo[datainfo$'Characteristics [group]' %in% c("control", "pre therapy"),]



celfiles <- datainfo$'Array Data File'

allcelfiles <- unique(c(grep(".cel", list.files(newfolder), value=TRUE), grep(".CEL", list.files(newfolder), value=TRUE)))

celfilestodelete <- setdiff(allcelfiles, celfiles)

length(celfilestodelete)
length(celfiles)+length(celfilestodelete)
length(allcelfiles)

for(i in seq(along=celfilestodelete)) {
  if(file.exists(paste(newfolder, "/", celfilestodelete[i], sep=""))) 
    file.remove(paste(newfolder, "/", celfilestodelete[i], sep=""))
}




library("affy")

wdsafe <- getwd()
setwd(newfolder)
aboall <- ReadAffy()
setwd(wdsafe)




library(docval)


functionfolder <- "./CVIIMCodeData/AddOnFunctionsetc/KostkaFunctions/"

allrscripts <- list.files(paste(functionfolder, "Rpack", sep=""), full.names = TRUE)
for(i in seq(along=allrscripts))
  source(allrscripts[i])

source(paste(functionfolder, "summarize_val.R",sep=''))
source(paste(functionfolder, "summarize_add.R",sep=''))
source(paste(functionfolder,'extractAffybatch.r',sep=''))


source("./CVIIMCodeData/AddOnFunctionsetc/Normalization_functions.R")



Xnormwhole <- RMAparam(1:length(aboall), aboall)$normdata




all(rownames(Xnormwhole)[nrow(Xnormwhole):1]==datainfo$'Array Data File')

datainfo <- datainfo[as.numeric(factor(rownames(Xnormwhole), levels=datainfo$'Array Data File')),]

all(rownames(Xnormwhole)==datainfo$'Array Data File')




y <- factor(as.numeric(datainfo$'Characteristics [group]'=="pre therapy")+1)
names(y) <- rownames(Xnormwhole)

save(y, file=paste(newfolder, "/target_variable.Rda", sep=""))




filesinfolder <- list.files(newfolder)

zipfileind <- which(sapply(filesinfolder, function(x) {
  splitted <- strsplit(x, split="")[[1]]
  paste(splitted[(length(splitted)-2):length(splitted)], collapse="")=="zip"
}))

zipfiles <- filesinfolder[zipfileind]

for(i in seq(along=zipfiles)) {
  if(file.exists(paste(newfolder, "/", zipfiles[i], sep=""))) 
    file.remove(paste(newfolder, "/", zipfiles[i], sep=""))
}



library("CMA")

K <- 5; niter <- 2

cvdatasets <- GenerateLearningsets(y = y, method = "CV", fold = K, niter = niter)

tunenestedcv <- tune(Xnormwhole, y, learningsets = cvdatasets, classifier = scdaCMA)

which.min(tunenestedcv@tuneres[[1]])

nestedcrossval <- classification(Xnormwhole, y, learningsets = cvdatasets, 
  classifier = scdaCMA, tuneres = tunenestedcv)
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 

mean(errortunensc11K3addon)
min(c(mean(y==1), mean(y==2)))




source("./CVIIMCodeData/AddOnFunctionsetc/compplot.R")
# compplot(Xnormwhole, groups=factor(y))





rm(list=ls());gc()





















datasetid <- "E-GEOD-39683"

newfolder <- paste("./CVIIMCodeData/DataRetrieval/DataSetsNormalization/", datasetid, sep="")





library("ArrayExpress")


getAE(datasetid, path = newfolder, type = "raw")


adf <- try(read.AnnotatedDataFrame(paste(newfolder, "/", datasetid, ".sdrf.txt", sep="")))

if(class(adf)!="try-error") {
  datainfo <- adf@data
} else {

adf <- readLines(paste("./CVIIMCodeData/DataRetrieval/DataSetsNormalization/", datasetid,"/", datasetid, ".sdrf.txt", sep=""))
table(sapply(adf, function(x) length(strsplit(x, split="\t")[[1]])))

datainfo <- data.frame(matrix(nrow=0, ncol=length(strsplit(adf[1], split="\t")[[1]])))
names(datainfo) <- strsplit(adf[1], split="\t")[[1]]

for(i in 1:(length(adf)-1))
  datainfo[i,] <- strsplit(adf[i+1], split="\t")[[1]]
  
}



datainfo <- datainfo[datainfo$'Characteristics..disease.state.' %in% c("multiple myeloma", "primary plasma cell leukemia"),]

table(datainfo$'Characteristics..disease.state.')


set.seed(1234)
indmulmyeol <- sort(sample(which(datainfo$'Characteristics..disease.state.'=="multiple myeloma"), size=12))

datainfo <- datainfo[c(9, 15, 20, 32, 40, 41, 42, 52, 54, 55, 60, 61, which(datainfo$'Characteristics..disease.state.'=="primary plasma cell leukemia")),]




celfiles <- datainfo$'Array.Data.File'
allcelfiles <- unique(c(grep(".cel", list.files(newfolder), value=TRUE), grep(".CEL", list.files(newfolder), value=TRUE)))

celfilestodelete <- setdiff(allcelfiles, celfiles)

length(celfiles)+length(celfilestodelete)
length(allcelfiles)

for(i in seq(along=celfilestodelete)) {
  if(file.exists(paste(newfolder, "/", celfilestodelete[i], sep=""))) 
    file.remove(paste(newfolder, "/", celfilestodelete[i], sep=""))
}





library("affy")

wdsafe <- getwd()
setwd(newfolder)
aboall <- ReadAffy()
setwd(wdsafe)




library(docval)


functionfolder <- "./CVIIMCodeData/AddOnFunctionsetc/KostkaFunctions/"

allrscripts <- list.files(paste(functionfolder, "Rpack", sep=""), full.names = TRUE)
for(i in seq(along=allrscripts))
  source(allrscripts[i])

source(paste(functionfolder, "summarize_val.R",sep=''))
source(paste(functionfolder, "summarize_add.R",sep=''))
source(paste(functionfolder,'extractAffybatch.r',sep=''))


source("./CVIIMCodeData/AddOnFunctionsetc/Normalization_functions.R")



Xnormwhole <- RMAparam(1:length(aboall), aboall)$normdata



all(rownames(Xnormwhole)[nrow(Xnormwhole):1]==datainfo$'Array.Data.File')

datainfo <- datainfo[as.numeric(factor(rownames(Xnormwhole), levels=datainfo$'Array.Data.File')),]

all(rownames(Xnormwhole)==datainfo$'Array.Data.File')


y <- factor(as.numeric(datainfo$'Characteristics..disease.state.'=="primary plasma cell leukemia")+1)
names(y) <- rownames(Xnormwhole)

save(y, file=paste(newfolder, "/target_variable.Rda", sep=""))




filesinfolder <- list.files(newfolder)

zipfileind <- which(sapply(filesinfolder, function(x) {
  splitted <- strsplit(x, split="")[[1]]
  paste(splitted[(length(splitted)-2):length(splitted)], collapse="")=="zip"
}))

zipfiles <- filesinfolder[zipfileind]

for(i in seq(along=zipfiles)) {
  if(file.exists(paste(newfolder, "/", zipfiles[i], sep=""))) 
    file.remove(paste(newfolder, "/", zipfiles[i], sep=""))
}



library("CMA")

K <- 5; niter <- 2

cvdatasets <- GenerateLearningsets(y = y, method = "CV", fold = K, niter = niter)

tunenestedcv <- tune(Xnormwhole, y, learningsets = cvdatasets, classifier = scdaCMA)

which.min(tunenestedcv@tuneres[[1]])

nestedcrossval <- classification(Xnormwhole, y, learningsets = cvdatasets, 
  classifier = scdaCMA, tuneres = tunenestedcv)
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 

mean(errortunensc11K3addon)
min(c(mean(y==1), mean(y==2)))




source("./CVIIMCodeData/AddOnFunctionsetc/compplot.R")
# compplot(Xnormwhole, groups=factor(y))





rm(list=ls());gc()





















datasetid <- "E-GEOD-40744"

newfolder <- paste("./CVIIMCodeData/DataRetrieval/DataSetsNormalization/", datasetid, sep="")





library("ArrayExpress")


getAE(datasetid, path = newfolder, type = "raw")


adf <- try(read.AnnotatedDataFrame(paste(newfolder, "/", datasetid, ".sdrf.txt", sep="")))

if(class(adf)!="try-error") {
  datainfo <- adf@data
} else {

adf <- readLines(paste("./CVIIMCodeData/DataRetrieval/DataSetsNormalization/", datasetid,"/", datasetid, ".sdrf.txt", sep=""))
table(sapply(adf, function(x) length(strsplit(x, split="\t")[[1]])))

datainfo <- data.frame(matrix(nrow=0, ncol=length(strsplit(adf[1], split="\t")[[1]])))
names(datainfo) <- strsplit(adf[1], split="\t")[[1]]

for(i in 1:(length(adf)-1))
  datainfo[i,] <- strsplit(adf[i+1], split="\t")[[1]]
rownames(datainfo) <- datainfo$'Source Name'
  
}




helpvar <- datainfo$'Comment [Sample_title]'
helpvar <- sapply(helpvar, function(x) strsplit(x, split="patient ")[[1]][2])
names(helpvar) <- NULL
helpvar <- gsub("specimen ", "", helpvar)
patientind <- as.numeric(sapply(helpvar, function(x) strsplit(x, split=" - ")[[1]][1]))
specimenind <- as.numeric(sapply(helpvar, function(x) strsplit(x, split=" - ")[[1]][2]))

datainfo$patientind <- patientind
datainfo$specimenind <- specimenind


datainfo <- datainfo[datainfo$specimenind==1,]


disease <- sapply(datainfo$'Comment [Sample_title]', function(x) strsplit(x, split=" - patient")[[1]][1])
names(disease) <- NULL

datainfo$disease <- disease


datainfo <- datainfo[datainfo$disease %in% c("HCV-associated cirrhosis surrounding HCC", "HCV-associated cirrhosis without HCC"),]





celfiles <- datainfo$'Array Data File'
allcelfiles <- unique(c(grep(".cel", list.files(newfolder), value=TRUE), grep(".CEL", list.files(newfolder), value=TRUE)))

celfilestodelete <- setdiff(allcelfiles, celfiles)

length(celfiles)+length(celfilestodelete)
length(allcelfiles)

for(i in seq(along=celfilestodelete)) {
  if(file.exists(paste(newfolder, "/", celfilestodelete[i], sep=""))) 
    file.remove(paste(newfolder, "/", celfilestodelete[i], sep=""))
}




library("affy")

wdsafe <- getwd()
setwd(newfolder)
aboall <- ReadAffy()
setwd(wdsafe)




library(docval)


functionfolder <- "./CVIIMCodeData/AddOnFunctionsetc/KostkaFunctions/"

allrscripts <- list.files(paste(functionfolder, "Rpack", sep=""), full.names = TRUE)
for(i in seq(along=allrscripts))
  source(allrscripts[i])

source(paste(functionfolder, "summarize_val.R",sep=''))
source(paste(functionfolder, "summarize_add.R",sep=''))
source(paste(functionfolder,'extractAffybatch.r',sep=''))


source("./CVIIMCodeData/AddOnFunctionsetc/Normalization_functions.R")



Xnormwhole <- RMAparam(1:length(aboall), aboall)$normdata


all(rownames(Xnormwhole)[nrow(Xnormwhole):1]==datainfo$'Array Data File')

datainfo <- datainfo[as.numeric(factor(rownames(Xnormwhole), levels=datainfo$'Array Data File')),]

all(rownames(Xnormwhole)==datainfo$'Array Data File')




y <- factor(as.numeric(datainfo$disease=="HCV-associated cirrhosis surrounding HCC")+1)
names(y) <- rownames(Xnormwhole)

save(y, file=paste(newfolder, "/target_variable.Rda", sep=""))




filesinfolder <- list.files(newfolder)

zipfileind <- which(sapply(filesinfolder, function(x) {
  splitted <- strsplit(x, split="")[[1]]
  paste(splitted[(length(splitted)-2):length(splitted)], collapse="")=="zip"
}))

zipfiles <- filesinfolder[zipfileind]

for(i in seq(along=zipfiles)) {
  if(file.exists(paste(newfolder, "/", zipfiles[i], sep=""))) 
    file.remove(paste(newfolder, "/", zipfiles[i], sep=""))
}



library("CMA")

K <- 5; niter <- 2

cvdatasets <- GenerateLearningsets(y = y, method = "CV", fold = K, niter = niter)

tunenestedcv <- tune(Xnormwhole, y, learningsets = cvdatasets, classifier = scdaCMA)

which.min(tunenestedcv@tuneres[[1]])

nestedcrossval <- classification(Xnormwhole, y, learningsets = cvdatasets, 
  classifier = scdaCMA, tuneres = tunenestedcv)
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 

mean(errortunensc11K3addon)
min(c(mean(y==1), mean(y==2)))





source("./CVIIMCodeData/AddOnFunctionsetc/compplot.R")
# compplot(Xnormwhole, groups=factor(y))





rm(list=ls());gc()





















datasetid <- "E-GEOD-46053"

newfolder <- paste("./CVIIMCodeData/DataRetrieval/DataSetsNormalization/", datasetid, sep="")





library("ArrayExpress")


getAE(datasetid, path = newfolder, type = "raw")


adf <- try(read.AnnotatedDataFrame(paste(newfolder, "/", datasetid, ".sdrf.txt", sep="")))
if(class(adf)!="try-error") {
  datainfo <- adf@data
} else {
  
}


usedindices <- grep("(i.e. no cocultured)", datainfo$'FactorValue..culture.condition.', invert=TRUE)
datainfo <- datainfo[usedindices,]



celfiles <- datainfo$'Array.Data.File'
allcelfiles <- grep(".CEL", list.files(newfolder), value=TRUE)

celfilestodelete <- setdiff(allcelfiles, celfiles)

for(i in seq(along=celfilestodelete)) {
  if(file.exists(paste(newfolder, "/", celfilestodelete[i], sep=""))) 
    file.remove(paste(newfolder, "/", celfilestodelete[i], sep=""))
}



library("affy")

wdsafe <- getwd()
setwd(newfolder)
aboall <- ReadAffy()
setwd(wdsafe)


library(docval)


functionfolder <- "./CVIIMCodeData/AddOnFunctionsetc/KostkaFunctions/"

allrscripts <- list.files(paste(functionfolder, "Rpack", sep=""), full.names = TRUE)
for(i in seq(along=allrscripts))
  source(allrscripts[i])

source(paste(functionfolder, "summarize_val.R",sep=''))
source(paste(functionfolder, "summarize_add.R",sep=''))
source(paste(functionfolder,'extractAffybatch.r',sep=''))


source("./CVIIMCodeData/AddOnFunctionsetc/Normalization_functions.R")



Xnormwhole <- RMAparam(1:length(aboall), aboall)$normdata


all(rownames(Xnormwhole)[nrow(Xnormwhole):1]==datainfo$'Array.Data.File')

datainfo <- datainfo[nrow(datainfo):1,]

y <- factor(as.numeric(datainfo$'Characteristics..tissue.source.'=="multiple myeloma (MM) patient")+1)
names(y) <- rownames(Xnormwhole)
save(y, file=paste(newfolder, "/target_variable.Rda", sep=""))



filesinfolder <- list.files(newfolder)

zipfileind <- which(sapply(filesinfolder, function(x) {
  splitted <- strsplit(x, split="")[[1]]
  paste(splitted[(length(splitted)-2):length(splitted)], collapse="")=="zip"
}))

zipfiles <- filesinfolder[zipfileind]

for(i in seq(along=zipfiles)) {
  if(file.exists(paste(newfolder, "/", zipfiles[i], sep=""))) 
    file.remove(paste(newfolder, "/", zipfiles[i], sep=""))
}



library("CMA")

K <- 5; niter <- 2

cvdatasets <- GenerateLearningsets(y = y, method = "CV", fold = K, niter = niter)

tunenestedcv <- tune(Xnormwhole, y, learningsets = cvdatasets, classifier = scdaCMA)

which.min(tunenestedcv@tuneres[[1]])

nestedcrossval <- classification(Xnormwhole, y, learningsets = cvdatasets, 
  classifier = scdaCMA, tuneres = tunenestedcv)
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 

mean(errortunensc11K3addon)
min(c(mean(y==1), mean(y==2)))






rm(list=ls());gc()





















datasetid <- "E-GEOD-47552"

newfolder <- paste("./CVIIMCodeData/DataRetrieval/DataSetsNormalization/", datasetid, sep="")





library("ArrayExpress")


getAE(datasetid, path = newfolder, type = "raw")


adf <- try(read.AnnotatedDataFrame(paste(newfolder, "/", datasetid, ".sdrf.txt", sep="")))

if(class(adf)!="try-error") {
  datainfo <- adf@data
} else {
  
}



datainfo <- datainfo[datainfo$'Comment..Sample_source_name.'!="Bone Marrow Healthy Donor",]


datainfo <- datainfo[datainfo$'Comment..Sample_source_name.'!="Bone Marrow MGUS patient",]


celfiles <- datainfo$'Array.Data.File'
allcelfiles <- unique(c(grep(".cel", list.files(newfolder), value=TRUE), grep(".CEL", list.files(newfolder), value=TRUE)))

celfilestodelete <- setdiff(allcelfiles, celfiles)

length(celfiles)+length(celfilestodelete)
length(allcelfiles)

for(i in seq(along=celfilestodelete)) {
  if(file.exists(paste(newfolder, "/", celfilestodelete[i], sep=""))) 
    file.remove(paste(newfolder, "/", celfilestodelete[i], sep=""))
}



library("affy")

wdsafe <- getwd()
setwd(newfolder)
aboall <- ReadAffy()
setwd(wdsafe)




library(docval)


functionfolder <- "./CVIIMCodeData/AddOnFunctionsetc/KostkaFunctions/"

allrscripts <- list.files(paste(functionfolder, "Rpack", sep=""), full.names = TRUE)
for(i in seq(along=allrscripts))
  source(allrscripts[i])

source(paste(functionfolder, "summarize_val.R",sep=''))
source(paste(functionfolder, "summarize_add.R",sep=''))
source(paste(functionfolder,'extractAffybatch.r',sep=''))


source("./CVIIMCodeData/AddOnFunctionsetc/Normalization_functions.R")



Xnormwhole <- RMAparam(1:length(aboall), aboall)$normdata







all(rownames(Xnormwhole)[nrow(Xnormwhole):1]==datainfo$'Array.Data.File')

datainfo <- datainfo[nrow(datainfo):1,]


y <- factor(as.numeric(datainfo$'Comment..Sample_source_name.'=="Bone Marrow MM patient")+1)
names(y) <- rownames(Xnormwhole)
save(y, file=paste(newfolder, "/target_variable.Rda", sep=""))




filesinfolder <- list.files(newfolder)

zipfileind <- which(sapply(filesinfolder, function(x) {
  splitted <- strsplit(x, split="")[[1]]
  paste(splitted[(length(splitted)-2):length(splitted)], collapse="")=="zip"
}))

zipfiles <- filesinfolder[zipfileind]

for(i in seq(along=zipfiles)) {
  if(file.exists(paste(newfolder, "/", zipfiles[i], sep=""))) 
    file.remove(paste(newfolder, "/", zipfiles[i], sep=""))
}



library("CMA")

K <- 5; niter <- 2

cvdatasets <- GenerateLearningsets(y = y, method = "CV", fold = K, niter = niter)

tunenestedcv <- tune(Xnormwhole, y, learningsets = cvdatasets, classifier = scdaCMA)

which.min(tunenestedcv@tuneres[[1]])

nestedcrossval <- classification(Xnormwhole, y, learningsets = cvdatasets, 
  classifier = scdaCMA, tuneres = tunenestedcv)
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 

mean(errortunensc11K3addon)
min(c(mean(y==1), mean(y==2)))




source("./CVIIMCodeData/AddOnFunctionsetc/compplot.R")
# compplot(Xnormwhole, groups=factor(y))





rm(list=ls());gc()





















datasetid <- "E-MEXP-3756"

newfolder <- paste("./CVIIMCodeData/DataRetrieval/DataSetsNormalization/", datasetid, sep="")





library("ArrayExpress")


getAE(datasetid, path = newfolder, type = "raw")


adf <- try(read.AnnotatedDataFrame(paste(newfolder, "/", datasetid, ".sdrf.txt", sep="")))

if(class(adf)!="try-error") {
  datainfo <- adf@data
} else {

adf <- readLines(paste("./CVIIMCodeData/DataRetrieval/DataSetsNormalization/", datasetid,"/", datasetid, ".sdrf.txt", sep=""))
table(sapply(adf, function(x) length(strsplit(x, split="\t")[[1]])))

datainfo <- data.frame(matrix(nrow=0, ncol=length(strsplit(adf[1], split="\t")[[1]])))
names(datainfo) <- strsplit(adf[1], split="\t")[[1]]

for(i in 1:(length(adf)-1))
  datainfo[i,] <- strsplit(adf[i+1], split="\t")[[1]]
  
}



datainfo <- datainfo[!((datainfo$'Characteristics.disease.state.'=="Control") & (datainfo$'Characteristics.sampling.time.point.'=="before colonoscopy")),]


celfiles <- datainfo$'Array.Data.File'
allcelfiles <- unique(c(grep(".cel", list.files(newfolder), value=TRUE), grep(".CEL", list.files(newfolder), value=TRUE)))

celfilestodelete <- setdiff(allcelfiles, celfiles)

length(celfiles)+length(celfilestodelete)
length(allcelfiles)

for(i in seq(along=celfilestodelete)) {
  if(file.exists(paste(newfolder, "/", celfilestodelete[i], sep=""))) 
    file.remove(paste(newfolder, "/", celfilestodelete[i], sep=""))
}



library("affy")

wdsafe <- getwd()
setwd(newfolder)
aboall <- ReadAffy()
setwd(wdsafe)




library(docval)


functionfolder <- "./CVIIMCodeData/AddOnFunctionsetc/KostkaFunctions/"

allrscripts <- list.files(paste(functionfolder, "Rpack", sep=""), full.names = TRUE)
for(i in seq(along=allrscripts))
  source(allrscripts[i])

source(paste(functionfolder, "summarize_val.R",sep=''))
source(paste(functionfolder, "summarize_add.R",sep=''))
source(paste(functionfolder,'extractAffybatch.r',sep=''))


source("./CVIIMCodeData/AddOnFunctionsetc/Normalization_functions.R")



Xnormwhole <- RMAparam(1:length(aboall), aboall)$normdata






all(rownames(Xnormwhole)[nrow(Xnormwhole):1]==datainfo$'Array.Data.File')

datainfo <- datainfo[as.numeric(factor(rownames(Xnormwhole), levels=datainfo$'Array.Data.File')),]

all(rownames(Xnormwhole)==datainfo$'Array.Data.File')


y <- factor(as.numeric(datainfo$'Characteristics.disease.state.'=="Colorectal cancer")+1)
names(y) <- rownames(Xnormwhole)
save(y, file=paste(newfolder, "/target_variable.Rda", sep=""))




filesinfolder <- list.files(newfolder)

zipfileind <- which(sapply(filesinfolder, function(x) {
  splitted <- strsplit(x, split="")[[1]]
  paste(splitted[(length(splitted)-2):length(splitted)], collapse="")=="zip"
}))

zipfiles <- filesinfolder[zipfileind]

for(i in seq(along=zipfiles)) {
  if(file.exists(paste(newfolder, "/", zipfiles[i], sep=""))) 
    file.remove(paste(newfolder, "/", zipfiles[i], sep=""))
}



library("CMA")

K <- 5; niter <- 2

cvdatasets <- GenerateLearningsets(y = y, method = "CV", fold = K, niter = niter)

tunenestedcv <- tune(Xnormwhole, y, learningsets = cvdatasets, classifier = scdaCMA)

which.min(tunenestedcv@tuneres[[1]])

nestedcrossval <- classification(Xnormwhole, y, learningsets = cvdatasets, 
  classifier = scdaCMA, tuneres = tunenestedcv)
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 

mean(errortunensc11K3addon)
min(c(mean(y==1), mean(y==2)))




source("./CVIIMCodeData/AddOnFunctionsetc/compplot.R")
# compplot(Xnormwhole, groups=factor(y))





rm(list=ls());gc()





















datasetid <- "E-MTAB-57"

newfolder <- paste("./CVIIMCodeData/DataRetrieval/DataSetsNormalization/", datasetid, sep="")





library("ArrayExpress")

getAE(datasetid, path = newfolder, type = "raw")


adf <- try(read.AnnotatedDataFrame(paste(newfolder, "/", datasetid, ".sdrf.txt", sep="")))

if(class(adf)!="try-error") {
  datainfo <- adf@data
  arraydatafile <- "Array.Data.File"
} else {

adf <- readLines(paste("./CVIIMCodeData/DataRetrieval/DataSetsNormalization/", datasetid,"/", datasetid, ".sdrf.txt", sep=""))
table(sapply(adf, function(x) length(strsplit(x, split="\t")[[1]])))

datainfo <- data.frame(matrix(nrow=0, ncol=length(strsplit(adf[1], split="\t")[[1]])))
names(datainfo) <- strsplit(adf[1], split="\t")[[1]]

for(i in 1:(length(adf)-1))
  datainfo[i,] <- strsplit(adf[i+1], split="\t")[[1]]
rownames(datainfo) <- datainfo$'Source Name'

arraydatafile <- "Array Data File"
  
}



eval(parse(text=paste("celfiles <- datainfo$'", arraydatafile, "'", sep="")))

allcelfiles <- unique(c(grep(".cel", list.files(newfolder), value=TRUE), grep(".CEL", list.files(newfolder), value=TRUE)))

celfilestodelete <- setdiff(allcelfiles, celfiles)

length(celfilestodelete)
length(celfiles)+length(celfilestodelete)
length(allcelfiles)

for(i in seq(along=celfilestodelete)) {
  if(file.exists(paste(newfolder, "/", celfilestodelete[i], sep=""))) 
    file.remove(paste(newfolder, "/", celfilestodelete[i], sep=""))
}




library("affy")

wdsafe <- getwd()
setwd(newfolder)
aboall <- ReadAffy()
setwd(wdsafe)




library(docval)


functionfolder <- "./CVIIMCodeData/AddOnFunctionsetc/KostkaFunctions/"

allrscripts <- list.files(paste(functionfolder, "Rpack", sep=""), full.names = TRUE)
for(i in seq(along=allrscripts))
  source(allrscripts[i])

source(paste(functionfolder, "summarize_val.R",sep=''))
source(paste(functionfolder, "summarize_add.R",sep=''))
source(paste(functionfolder,'extractAffybatch.r',sep=''))


source("./CVIIMCodeData/AddOnFunctionsetc/Normalization_functions.R")



Xnormwhole <- RMAparam(1:length(aboall), aboall)$normdata



eval(parse(text=paste("all(rownames(Xnormwhole)[nrow(Xnormwhole):1]==datainfo$'", arraydatafile, "')", sep="")))

eval(parse(text=paste("datainfo <- datainfo[as.numeric(factor(rownames(Xnormwhole), levels=datainfo$'", arraydatafile, "')),]", sep="")))

eval(parse(text=paste("all(rownames(Xnormwhole)==datainfo$'", arraydatafile, "')", sep="")))



y <- factor(as.numeric(datainfo$'Characteristics [DiseaseState]'=="tumor")+1)
names(y) <- rownames(Xnormwhole)
save(y, file=paste(newfolder, "/target_variable.Rda", sep=""))




filesinfolder <- list.files(newfolder)

zipfileind <- which(sapply(filesinfolder, function(x) {
  splitted <- strsplit(x, split="")[[1]]
  paste(splitted[(length(splitted)-2):length(splitted)], collapse="")=="zip"
}))

zipfiles <- filesinfolder[zipfileind]

for(i in seq(along=zipfiles)) {
  if(file.exists(paste(newfolder, "/", zipfiles[i], sep=""))) 
    file.remove(paste(newfolder, "/", zipfiles[i], sep=""))
}




library("CMA")

K <- 5; niter <- 2

cvdatasets <- GenerateLearningsets(y = y, method = "CV", fold = K, niter = niter)

tunenestedcv <- tune(Xnormwhole, y, learningsets = cvdatasets, classifier = scdaCMA)

which.min(tunenestedcv@tuneres[[1]])

nestedcrossval <- classification(Xnormwhole, y, learningsets = cvdatasets, 
  classifier = scdaCMA, tuneres = tunenestedcv)
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 

mean(errortunensc11K3addon)
min(c(mean(y==1), mean(y==2)))




source("./CVIIMCodeData/AddOnFunctionsetc/compplot.R")
# compplot(Xnormwhole, groups=factor(y))

rm(list=ls());gc()
