
# Data set accession number:
datasetid <- "E-GEOD-25609"

# Download processed Data:
library("ArrayExpress")
getAE(datasetid, path = paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, sep=""), type = "processed")


# Extract pheno data:

adf <- readLines(paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid,"/", datasetid, ".sdrf.txt", sep=""))
table(sapply(adf, function(x) length(strsplit(x, split="\t")[[1]])))

datainfo <- data.frame(matrix(nrow=0, ncol=length(strsplit(adf[1], split="\t")[[1]])))
names(datainfo) <- strsplit(adf[1], split="\t")[[1]]

for(i in 1:(length(adf)-1))
  datainfo[i,] <- strsplit(adf[i+1], split="\t")[[1]]
rownames(datainfo) <- datainfo$'Source Name'



# Subset the data set to feature only the required observations:

table(datainfo$'Characteristics [disease state]')

datainfo <- datainfo[datainfo$'Characteristics [disease state]' %in% 
  c("Colorectal Cancer", "control"),]


  
# Check, whether the ordering of the samples is the same in the 
# the pheno data file as it is in the gene data we read in:
  
files <- grep("_sample_table.txt", list.files(paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, sep=""), full.names=TRUE), value=TRUE)

datainfonames <- gsub(" 1", "", rownames(datainfo))

files.names2 <- sapply(files, function(x) strsplit(x, split=paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, "/", sep=""))[[1]][2])
filesnames <- sapply(files.names2, function(x) strsplit(x, split="_sample_table.txt")[[1]])
names(filesnames) <- NULL


files <- files[filesnames %in% datainfonames]


files.names2 <- sapply(files, function(x) strsplit(x, split=paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, "/", sep=""))[[1]][2])
filesnames <- sapply(files.names2, function(x) strsplit(x, split="_sample_table.txt")[[1]])
names(filesnames) <- NULL

# Order is reversed:
all(filesnames==datainfonames[length(datainfonames):1])

# Bring the pheno data information into the right order:
datainfo <- datainfo[nrow(datainfo):1,]




# Now read in the covariate information and generate the covariate matrix - on ArrayExpress, generally, the data for each observation sample is stored in 
# an individual file:

head(readLines(files[1]))

sampletemp <- readLines(files[1])[-1]
datamat <- matrix(nrow=length(files), ncol=length(sampletemp))

nit <- nrow(datamat)
for(i in seq(along=files)) {
  sampletemp <- readLines(files[i])[-1]
  datamat[i,] <- sapply(sampletemp, function(x) as.numeric(strsplit(x, split="\t")[[1]][2]))
  cat(paste("Sample", i, "of", nit), "\n")
}

X <- as.matrix(datamat)


# Generate the target variable - factor-valued with factors '1' and '2':

y <- factor(as.numeric(datainfo$'Characteristics [disease state]'=="Colorectal Cancer")+1)


# Save the data set:

save(X, y, file="./CVIIMCodeData/DataRetrieval/DataSetsPCA/E-GEOD-25609.Rda")


rm(list=ls()); gc()

if(FALSE) {


# Read the data set in again and perform some analyses to assess the strength of the signal.

# We note that we did not preselect the data sets according to the classification accuracy
# observed on them - such a procedure would of course be connected with a substantial selection
# bias.

# This signal strength analysis was done only to detect pathological cases, where full CV errors of zero were obtained - 
# these can be assumed to constitute no realistic applications. Rather, such cases can be
# assumed to be due to distortions by technological artefacts, occurring for example when the samples belonging to
# either class were processed in two different batches.


load("./CVIIMCodeData/DataRetrieval/DataSetsPCA/E-GEOD-25609.Rda")


library("CMA")

K <- 5; niter <- 2

cvdatasets <- GenerateLearningsets(y = y, method = "CV", fold = K, niter = niter)


geneselobj <- GeneSelection(X, y, learningsets = cvdatasets, method="t.test")

tunenestedcv <- tune(X, y, learningsets = cvdatasets, genesel=geneselobj, nbgene=1000, classifier = scdaCMA)

which.min(tunenestedcv@tuneres[[1]])

nestedcrossval <- classification(X, y, learningsets = cvdatasets, 
  classifier = scdaCMA, tuneres = tunenestedcv)
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 



nestedcrossval <- classification(X, y, learningsets = cvdatasets, 
  classifier = scdaCMA, gensel=geneselobj, delta=median(unlist(tunenestedcv@tuneres)))
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 



mean(errortunensc11K3addon)
min(c(mean(y==1), mean(y==2)))


source("./CVIIMCodeData/AddOnFunctionsetc/compplot.R")
compplot(data=X, groups=y, groupsy=y)



}
