# Library to handle (microarray) data sets from GEO:
library("GEOquery")

# Download data:
download.file(url="ftp://ftp.ncbi.nlm.nih.gov/geo/series/GSE20nnn/GSE20189/matrix/GSE20189_series_matrix.txt.gz", destfile="./CVIIMCodeData/DataRetrieval/DataSetsPCA/GSE20189/GSE20189_series_matrix.txt.gz")

# Read in expression data:
X1 <- getGEO(file="./CVIIMCodeData/DataRetrieval/DataSetsPCA/GSE20189/GSE20189_series_matrix.txt.gz")

# p x n - expression matrix:
Xdata <- exprs(X1)

# Pheno data:
Xpheno <- phenoData(X1)
Xpheno2 <- pData(Xpheno)


# Check whether the samples have the same order in pheno and expression data:
all(Xpheno2$geo_accession==colnames(Xdata))

# --> Yes.


# Transpose expression data and extract target variable:
X <- t(Xdata)
y <- Xpheno2$description

# --> There are some samples, which are declared as excluded.
#  --> Remove these from the data set:

included <- which(!(y %in% c("Case Excluded" , "Non Case Excluded")))
X <- X[included,]
y <- y[included]

# Recode target variable:
ytemp <- y
y <- rep(1, length(ytemp))
y[ytemp == "Case"] <- 2
y <- as.factor(y)

# Because of the high computional burden, we only consider a subset of randomly selected
# 100 Patients:
set.seed(1234); subsetall <- sort(sample(1:length(y), size=100))
# result:
# subsetall <- c(2, 4, 5, 6, 7, 8, 9, 11, 14, 16, 17, 18, 21, 22, 24, 25, 26, 27, 29, 
#   30, 31, 32, 33, 34, 35, 36, 37, 39, 40, 41, 43, 44, 48, 50, 51, 52, 55, 56, 57,
#   58, 61, 62, 63, 65, 67, 68, 69, 71, 73, 74, 75, 77, 78, 79, 80, 81, 83, 87, 88,
#   90, 93, 94, 95, 97, 98, 100, 101, 103, 104, 107, 112, 113, 114, 115, 116, 118,
#   119, 123, 124, 125, 128, 129, 130, 131, 134, 135, 136, 137, 138, 139, 140, 141,
#   142, 145, 146, 147, 149, 151, 152, 153)


# Subset data:
X <- X[subsetall,]
y <- y[subsetall]


# Save data set 'GSE20189':
save(X, y, file="./CVIIMCodeData/DataRetrieval/DataSetsPCA/GSE20189.Rda")

# Clear the workspace:
rm(list=ls())