#######################################################################################
#######################################################################################
#
#  This script produces all datasets used in the PCA study (except for 'ProstatecTranscr'
#  which is already present) and stores them as Rda-files in
#  "./CVIIMCodeData/DataRetrieval/DataSetsPCA".
#
#######################################################################################
#######################################################################################







# Data set accession number:
datasetid <- "E-GEOD-25609"

# Download processed Data:
library("ArrayExpress")
getAE(datasetid, path = paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, sep=""), type = "processed")


# Extract pheno data:

adf <- readLines(paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid,"/", datasetid, ".sdrf.txt", sep=""))
table(sapply(adf, function(x) length(strsplit(x, split="\t")[[1]])))

datainfo <- data.frame(matrix(nrow=0, ncol=length(strsplit(adf[1], split="\t")[[1]])))
names(datainfo) <- strsplit(adf[1], split="\t")[[1]]

for(i in 1:(length(adf)-1))
  datainfo[i,] <- strsplit(adf[i+1], split="\t")[[1]]
rownames(datainfo) <- datainfo$'Source Name'



# Subset the data set to feature only the required observations:

table(datainfo$'Characteristics [disease state]')

datainfo <- datainfo[datainfo$'Characteristics [disease state]' %in% 
  c("Colorectal Cancer", "control"),]


  
# Check, whether the ordering of the samples is the same in the 
# the pheno data file as it is in the gene data we read in:
  
files <- grep("_sample_table.txt", list.files(paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, sep=""), full.names=TRUE), value=TRUE)

datainfonames <- gsub(" 1", "", rownames(datainfo))

files.names2 <- sapply(files, function(x) strsplit(x, split=paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, "/", sep=""))[[1]][2])
filesnames <- sapply(files.names2, function(x) strsplit(x, split="_sample_table.txt")[[1]])
names(filesnames) <- NULL


files <- files[filesnames %in% datainfonames]


files.names2 <- sapply(files, function(x) strsplit(x, split=paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, "/", sep=""))[[1]][2])
filesnames <- sapply(files.names2, function(x) strsplit(x, split="_sample_table.txt")[[1]])
names(filesnames) <- NULL

# Order is reversed:
all(filesnames==datainfonames[length(datainfonames):1])

# Bring the pheno data information into the right order:
datainfo <- datainfo[nrow(datainfo):1,]




# Now read in the covariate information and generate the covariate matrix - on ArrayExpress, generally, the data for each observation sample is stored in 
# an individual file:

head(readLines(files[1]))

sampletemp <- readLines(files[1])[-1]
datamat <- matrix(nrow=length(files), ncol=length(sampletemp))

nit <- nrow(datamat)
for(i in seq(along=files)) {
  sampletemp <- readLines(files[i])[-1]
  datamat[i,] <- sapply(sampletemp, function(x) as.numeric(strsplit(x, split="\t")[[1]][2]))
  cat(paste("Sample", i, "of", nit), "\n")
}

X <- as.matrix(datamat)


# Generate the target variable - factor-valued with factors '1' and '2':

y <- factor(as.numeric(datainfo$'Characteristics [disease state]'=="Colorectal Cancer")+1)


# Save the data set:

save(X, y, file="./CVIIMCodeData/DataRetrieval/DataSetsPCA/E-GEOD-25609.Rda")


rm(list=ls()); gc()

if(FALSE) {


# Read the data set in again and perform some analyses to assess the strength of the signal.

# We note that we did not preselect the data sets according to the classification accuracy
# observed on them - such a procedure would of course be connected with a substantial selection
# bias.

# This signal strength analysis was done only to detect pathological cases, where full CV errors of zero were obtained - 
# these can be assumed to constitute no realistic applications. Rather, such cases can be
# assumed to be due to distortions by technological artefacts, occurring for example when the samples belonging to
# either class were processed in two different batches.


load("./CVIIMCodeData/DataRetrieval/DataSetsPCA/E-GEOD-25609.Rda")


library("CMA")

K <- 5; niter <- 2

cvdatasets <- GenerateLearningsets(y = y, method = "CV", fold = K, niter = niter)


geneselobj <- GeneSelection(X, y, learningsets = cvdatasets, method="t.test")

tunenestedcv <- tune(X, y, learningsets = cvdatasets, genesel=geneselobj, nbgene=1000, classifier = scdaCMA)

which.min(tunenestedcv@tuneres[[1]])

nestedcrossval <- classification(X, y, learningsets = cvdatasets, 
  classifier = scdaCMA, tuneres = tunenestedcv)
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 



nestedcrossval <- classification(X, y, learningsets = cvdatasets, 
  classifier = scdaCMA, gensel=geneselobj, delta=median(unlist(tunenestedcv@tuneres)))
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 



mean(errortunensc11K3addon)
min(c(mean(y==1), mean(y==2)))


source("./CVIIMCodeData/AddOnFunctionsetc/compplot.R")
compplot(data=X, groups=y, groupsy=y)



}





rm(list=ls());gc()





















datasetid <- "E-GEOD-31629"



library("ArrayExpress")
getAE(datasetid, path = paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, sep=""), type = "processed")



adf <- readLines(paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid,"/", datasetid, ".sdrf.txt", sep=""))
table(sapply(adf, function(x) length(strsplit(x, split="\t")[[1]])))

datainfo <- data.frame(matrix(nrow=0, ncol=length(strsplit(adf[1], split="\t")[[1]])))
names(datainfo) <- strsplit(adf[1], split="\t")[[1]]

for(i in 1:(length(adf)-1))
  datainfo[i,] <- strsplit(adf[i+1], split="\t")[[1]]
rownames(datainfo) <- datainfo$'Source Name'




files <- grep("_sample_table.txt", list.files(paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, sep=""), full.names=TRUE), value=TRUE)

datainfonames <- gsub(" 1", "", rownames(datainfo))

files.names2 <- sapply(files, function(x) strsplit(x, split=paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, "/", sep=""))[[1]][2])
filesnames <- sapply(files.names2, function(x) strsplit(x, split="_sample_table.txt")[[1]])
names(filesnames) <- NULL


files <- files[filesnames %in% datainfonames]


files.names2 <- sapply(files, function(x) strsplit(x, split=paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, "/", sep=""))[[1]][2])
filesnames <- sapply(files.names2, function(x) strsplit(x, split="_sample_table.txt")[[1]])
names(filesnames) <- NULL



all(filesnames==datainfonames[length(datainfonames):1])



datainfo <- datainfo[nrow(datainfo):1,]






head(readLines(files[1]))




sampletemp <- readLines(files[1])[-1]
datamat <- matrix(nrow=length(files), ncol=length(sampletemp))

nit <- nrow(datamat)
for(i in seq(along=files)) {
  sampletemp <- readLines(files[i])[-1]
  datamat[i,] <- sapply(sampletemp, function(x) as.numeric(strsplit(x, split="\t")[[1]][2]))
  cat(paste("Sample", i, "of", nit), "\n")
}



X <- as.matrix(datamat)


y <- factor(as.numeric(datainfo$'Characteristics[disease status]'=="ATL")+1)



save(X, y, file="./CVIIMCodeData/DataRetrieval/DataSetsPCA/E-GEOD-31629.Rda")


rm(list=ls()); gc()

if(FALSE) {


load("./CVIIMCodeData/DataRetrieval/DataSetsPCA/E-GEOD-31629.Rda")

library("CMA")

K <- 5; niter <- 2

cvdatasets <- GenerateLearningsets(y = y, method = "CV", fold = K, niter = niter)


geneselobj <- GeneSelection(X, y, learningsets = cvdatasets, method="t.test")

tunenestedcv <- tune(X, y, learningsets = cvdatasets, genesel=geneselobj, nbgene=1000, classifier = scdaCMA)

which.min(tunenestedcv@tuneres[[1]])

nestedcrossval <- classification(X, y, learningsets = cvdatasets, 
  classifier = scdaCMA, tuneres = tunenestedcv)
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 



nestedcrossval <- classification(X, y, learningsets = cvdatasets, 
  classifier = scdaCMA, gensel=geneselobj, delta=median(unlist(tunenestedcv@tuneres)))
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 



mean(errortunensc11K3addon)
min(c(mean(y==1), mean(y==2)))


source("./CVIIMCodeData/AddOnFunctionsetc/compplot.R")
compplot(data=X, groups=y, groupsy=y)



}





rm(list=ls());gc()





















datasetid <- "E-GEOD-32393"



library("ArrayExpress")
getAE(datasetid, path = paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, sep=""), type = "processed")



adf <- readLines(paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid,"/", datasetid, ".sdrf.txt", sep=""))
table(sapply(adf, function(x) length(strsplit(x, split="\t")[[1]])))

datainfo <- data.frame(matrix(nrow=0, ncol=length(strsplit(adf[1], split="\t")[[1]])))
names(datainfo) <- strsplit(adf[1], split="\t")[[1]]

for(i in 1:(length(adf)-1))
  datainfo[i,] <- strsplit(adf[i+1], split="\t")[[1]]
rownames(datainfo) <- datainfo$'Source Name'




table(datainfo$'Characteristics[cancer)]'=="  ", datainfo$'Characteristics[Stage]')


table(datainfo$'Characteristics[cancer)]'=="  ", datainfo$'Characteristics[grade]')


datainfo <- datainfo[(datainfo$'Characteristics[Stage]'==1) | (datainfo$'Characteristics[cancer)]'=="  "),]



files <- grep("_sample_table.txt", list.files(paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, sep=""), full.names=TRUE), value=TRUE)

datainfonames <- gsub(" 1", "", rownames(datainfo))

files.names2 <- sapply(files, function(x) strsplit(x, split=paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, "/", sep=""))[[1]][2])
filesnames <- sapply(files.names2, function(x) strsplit(x, split="_sample_table.txt")[[1]])
names(filesnames) <- NULL


files <- files[filesnames %in% datainfonames]


files.names2 <- sapply(files, function(x) strsplit(x, split=paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, "/", sep=""))[[1]][2])
filesnames <- sapply(files.names2, function(x) strsplit(x, split="_sample_table.txt")[[1]])
names(filesnames) <- NULL



all(filesnames==datainfonames[length(datainfonames):1])



datainfo <- datainfo[nrow(datainfo):1,]







head(readLines(files[1]))




sampletemp <- readLines(files[1])[-1]
datamat <- matrix(nrow=length(files), ncol=length(sampletemp))

nit <- nrow(datamat)
for(i in seq(along=files)) {
  sampletemp <- readLines(files[i])[-1]
  datamat[i,] <- sapply(sampletemp, function(x) as.numeric(strsplit(x, split="\t")[[1]][2]))
  cat(paste("Sample", i, "of", nit), "\n")
}



X <- as.matrix(datamat)


navars <- which(apply(X, 2, function(x) sum(is.na(x)))>0)

for(i in seq(along=navars)) {
    X[,navars[i]][is.na(X[,navars[i]])] <- median(X[,navars[i]], na.rm=TRUE)
}


y <- factor(as.numeric(datainfo$'Characteristics[Stage]'==1)+1)



save(X, y, file="./CVIIMCodeData/DataRetrieval/DataSetsPCA/E-GEOD-32393.Rda")


rm(list=ls()); gc()

if(FALSE) {


load("./CVIIMCodeData/DataRetrieval/DataSetsPCA/E-GEOD-32393.Rda")

library("CMA")

K <- 5; niter <- 2

cvdatasets <- GenerateLearningsets(y = y, method = "CV", fold = K, niter = niter)


geneselobj <- GeneSelection(X, y, learningsets = cvdatasets, method="t.test")

tunenestedcv <- tune(X, y, learningsets = cvdatasets, genesel=geneselobj, nbgene=1000, classifier = scdaCMA)

which.min(tunenestedcv@tuneres[[1]])

nestedcrossval <- classification(X, y, learningsets = cvdatasets, 
  classifier = scdaCMA, tuneres = tunenestedcv)
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 



nestedcrossval <- classification(X, y, learningsets = cvdatasets, 
  classifier = scdaCMA, gensel=geneselobj, delta=median(unlist(tunenestedcv@tuneres)))
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 



mean(errortunensc11K3addon)
min(c(mean(y==1), mean(y==2)))


source("./CVIIMCodeData/AddOnFunctionsetc/compplot.R")
compplot(data=X, groups=y, groupsy=y)



}





rm(list=ls());gc()





















datasetid <- "E-GEOD-33615"



library("ArrayExpress")
getAE(datasetid, path = paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, sep=""), type = "processed")



adf <- readLines(paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid,"/", datasetid, ".sdrf.txt", sep=""))
table(sapply(adf, function(x) length(strsplit(x, split="\t")[[1]])))

datainfo <- data.frame(matrix(nrow=0, ncol=length(strsplit(adf[1], split="\t")[[1]])))
names(datainfo) <- strsplit(adf[1], split="\t")[[1]]

for(i in 1:(length(adf)-1))
  datainfo[i,] <- strsplit(adf[i+1], split="\t")[[1]]
rownames(datainfo) <- datainfo$'Source Name'


table(datainfo$'Comment [Sample_description]')


set.seed(1234)
ranatlind <- sort(sample(which(datainfo$'Comment [Sample_description]'=="mRNA expression in ATL"), size=39))


datainfo <- datainfo[sort(c(which(datainfo$'Comment [Sample_description]'=="mRNA expression in healthy donor"), ranatlind)),]


files <- grep("_sample_table.txt", list.files(paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, sep=""), full.names=TRUE), value=TRUE)

datainfonames <- gsub(" 1", "", rownames(datainfo))

files.names2 <- sapply(files, function(x) strsplit(x, split=paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, "/", sep=""))[[1]][2])
filesnames <- sapply(files.names2, function(x) strsplit(x, split="_sample_table.txt")[[1]])
names(filesnames) <- NULL


files <- files[filesnames %in% datainfonames]


files.names2 <- sapply(files, function(x) strsplit(x, split=paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, "/", sep=""))[[1]][2])
filesnames <- sapply(files.names2, function(x) strsplit(x, split="_sample_table.txt")[[1]])
names(filesnames) <- NULL



all(filesnames==datainfonames[length(datainfonames):1])



datainfo <- datainfo[nrow(datainfo):1,]






head(readLines(files[1]))




sampletemp <- readLines(files[1])[-1]
datamat <- matrix(nrow=length(files), ncol=length(sampletemp))

nit <- nrow(datamat)
for(i in seq(along=files)) {
  sampletemp <- readLines(files[i])[-1]
  datamat[i,] <- sapply(sampletemp, function(x) as.numeric(strsplit(x, split="\t")[[1]][2]))
  cat(paste("Sample", i, "of", nit), "\n")
}



X <- as.matrix(datamat)


y <- factor(as.numeric(datainfo$'Comment [Sample_description]'=="mRNA expression in ATL")+1)



save(X, y, file="./CVIIMCodeData/DataRetrieval/DataSetsPCA/E-GEOD-33615.Rda")


rm(list=ls()); gc()

if(FALSE) {


load("./CVIIMCodeData/DataRetrieval/DataSetsPCA/E-GEOD-33615.Rda")

library("CMA")

K <- 5; niter <- 2

cvdatasets <- GenerateLearningsets(y = y, method = "CV", fold = K, niter = niter)


geneselobj <- GeneSelection(X, y, learningsets = cvdatasets, method="t.test")

tunenestedcv <- tune(X, y, learningsets = cvdatasets, genesel=geneselobj, nbgene=1000, classifier = scdaCMA)

which.min(tunenestedcv@tuneres[[1]])

nestedcrossval <- classification(X, y, learningsets = cvdatasets, 
  classifier = scdaCMA, tuneres = tunenestedcv)
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 



nestedcrossval <- classification(X, y, learningsets = cvdatasets, 
  classifier = scdaCMA, gensel=geneselobj, delta=median(unlist(tunenestedcv@tuneres)))
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 



mean(errortunensc11K3addon)
min(c(mean(y==1), mean(y==2)))


source("./CVIIMCodeData/AddOnFunctionsetc/compplot.R")
compplot(data=X, groups=y, groupsy=y)



}





rm(list=ls());gc()





















datasetid <- "E-GEOD-36769"



library("ArrayExpress")
getAE(datasetid, path = paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, sep=""), type = "processed")



adf <- readLines(paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid,"/", datasetid, ".sdrf.txt", sep=""))
table(sapply(adf, function(x) length(strsplit(x, split="\t")[[1]])))

datainfo <- data.frame(matrix(nrow=0, ncol=length(strsplit(adf[1], split="\t")[[1]])))
names(datainfo) <- strsplit(adf[1], split="\t")[[1]]

for(i in 1:(length(adf)-1))
  datainfo[i,] <- strsplit(adf[i+1], split="\t")[[1]]
rownames(datainfo) <- datainfo$'Source Name'



datainfo <- datainfo[datainfo$'Characteristics [source tissue]' %in% c("Breast Tumor", "Peripheral Blood"),]



files <- grep("_sample_table.txt", list.files(paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, sep=""), full.names=TRUE), value=TRUE)

datainfonames <- gsub(" 1", "", rownames(datainfo))

files.names2 <- sapply(files, function(x) strsplit(x, split=paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, "/", sep=""))[[1]][2])
filesnames <- sapply(files.names2, function(x) strsplit(x, split="_sample_table.txt")[[1]])
names(filesnames) <- NULL


files <- files[filesnames %in% datainfonames]


files.names2 <- sapply(files, function(x) strsplit(x, split=paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, "/", sep=""))[[1]][2])
filesnames <- sapply(files.names2, function(x) strsplit(x, split="_sample_table.txt")[[1]])
names(filesnames) <- NULL



all(filesnames==datainfonames[length(datainfonames):1])



datainfo <- datainfo[nrow(datainfo):1,]








try(sampletemp <- read.table(files[1], header=TRUE))


if(exists("sampletemp")) {


sampletemp <- read.table(files[1], header=TRUE)

IDmat <- as.data.frame(matrix(nrow=length(files), ncol=nrow(sampletemp)))
datamat <- as.data.frame(matrix(nrow=length(files), ncol=nrow(sampletemp)))

IDmat[1,] <- sampletemp$ID_REF
datamat[1,] <- sampletemp$VALUE

nit <- nrow(datamat)
for(i in seq(along=files)[-1]) {
  sampletemp <- read.table(files[i], header=TRUE)
  IDmat[i,] <- sampletemp$ID_REF
  datamat[i,] <- sampletemp$VALUE
  cat(paste("Sample", i, "of", nit), "\n")
}


allequalvec <- apply(IDmat, 2, function(x) length(unique(x))==1)
all(allequalvec)


X <- as.matrix(datamat)

}


y <- factor(as.numeric(datainfo$'Characteristics [source tissue]'=="Breast Tumor")+1)



save(X, y, file="./CVIIMCodeData/DataRetrieval/DataSetsPCA/E-GEOD-36769.Rda")


rm(list=ls()); gc()

if(FALSE) {


load("./CVIIMCodeData/DataRetrieval/DataSetsPCA/E-GEOD-36769.Rda")

library("CMA")

K <- 5; niter <- 2

cvdatasets <- GenerateLearningsets(y = y, method = "CV", fold = K, niter = niter)


geneselobj <- GeneSelection(X, y, learningsets = cvdatasets, method="t.test")

tunenestedcv <- tune(X, y, learningsets = cvdatasets, genesel=geneselobj, nbgene=1000, classifier = scdaCMA)

which.min(tunenestedcv@tuneres[[1]])

nestedcrossval <- classification(X, y, learningsets = cvdatasets, 
  classifier = scdaCMA, tuneres = tunenestedcv)
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 



nestedcrossval <- classification(X, y, learningsets = cvdatasets, 
  classifier = scdaCMA, gensel=geneselobj, delta=median(unlist(tunenestedcv@tuneres)))
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 



mean(errortunensc11K3addon)
min(c(mean(y==1), mean(y==2)))


source("./CVIIMCodeData/AddOnFunctionsetc/compplot.R")
compplot(data=X, groups=y, groupsy=y)



}





rm(list=ls());gc()





















datasetid <- "E-GEOD-37582"



library("ArrayExpress")
getAE(datasetid, path = paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, sep=""), type = "processed")



try(adf <- read.AnnotatedDataFrame(paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid,"/", datasetid, ".sdrf.txt", sep="")))
datainfo <- adf@data







files <- grep("_sample_table.txt", list.files(paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, sep=""), full.names=TRUE), value=TRUE)

datainfonames <- gsub(" 1", "", rownames(datainfo))

files.names2 <- sapply(files, function(x) strsplit(x, split=paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, "/", sep=""))[[1]][2])
filesnames <- sapply(files.names2, function(x) strsplit(x, split="_sample_table.txt")[[1]])
names(filesnames) <- NULL


files <- files[filesnames %in% datainfonames]


files.names2 <- sapply(files, function(x) strsplit(x, split=paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, "/", sep=""))[[1]][2])
filesnames <- sapply(files.names2, function(x) strsplit(x, split="_sample_table.txt")[[1]])
names(filesnames) <- NULL



all(filesnames==datainfonames[length(datainfonames):1])



datainfo <- datainfo[nrow(datainfo):1,]







head(readLines(files[1]))




sampletemp <- readLines(files[1])[-1]
datamat <- matrix(nrow=length(files), ncol=length(sampletemp))

nit <- nrow(datamat)
for(i in seq(along=files)) {
  sampletemp <- readLines(files[i])[-1]
  datamat[i,] <- sapply(sampletemp, function(x) as.numeric(strsplit(x, split="\t")[[1]][2]))
  cat(paste("Sample", i, "of", nit), "\n")
}



X <- as.matrix(datamat)


y <- factor(as.numeric(datainfo$'Characteristics..disease.state.'=="Ovarian Cancer")+1)



save(X, y, file="./CVIIMCodeData/DataRetrieval/DataSetsPCA/E-GEOD-37582.Rda")


rm(list=ls()); gc()

if(FALSE) {


load("./CVIIMCodeData/DataRetrieval/DataSetsPCA/E-GEOD-37582.Rda")

library("CMA")

K <- 5; niter <- 2

cvdatasets <- GenerateLearningsets(y = y, method = "CV", fold = K, niter = niter)


geneselobj <- GeneSelection(X, y, learningsets = cvdatasets, method="t.test")

tunenestedcv <- tune(X, y, learningsets = cvdatasets, genesel=geneselobj, nbgene=1000, classifier = scdaCMA)

which.min(tunenestedcv@tuneres[[1]])

nestedcrossval <- classification(X, y, learningsets = cvdatasets, 
  classifier = scdaCMA, tuneres = tunenestedcv)
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 



nestedcrossval <- classification(X, y, learningsets = cvdatasets, 
  classifier = scdaCMA, gensel=geneselobj, delta=median(unlist(tunenestedcv@tuneres)))
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 



mean(errortunensc11K3addon)
min(c(mean(y==1), mean(y==2)))


source("./CVIIMCodeData/AddOnFunctionsetc/compplot.R")
compplot(data=X, groups=y, groupsy=y)


}





rm(list=ls());gc()





















datasetid <- "E-GEOD-37965"



library("ArrayExpress")
getAE(datasetid, path = paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, sep=""), type = "processed")



adf <- readLines(paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid,"/", datasetid, ".sdrf.txt", sep=""))
table(sapply(adf, function(x) length(strsplit(x, split="\t")[[1]])))

datainfo <- data.frame(matrix(nrow=0, ncol=length(strsplit(adf[1], split="\t")[[1]])))
names(datainfo) <- strsplit(adf[1], split="\t")[[1]]

for(i in 1:(length(adf)-1))
  datainfo[i,] <- strsplit(adf[i+1], split="\t")[[1]]
rownames(datainfo) <- datainfo$'Source Name'



table(datainfo$'Characteristics [disease status]')



files <- grep("_sample_table.txt", list.files(paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, sep=""), full.names=TRUE), value=TRUE)

datainfonames <- gsub(" 1", "", rownames(datainfo))

files.names2 <- sapply(files, function(x) strsplit(x, split=paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, "/", sep=""))[[1]][2])
filesnames <- sapply(files.names2, function(x) strsplit(x, split="_sample_table.txt")[[1]])
names(filesnames) <- NULL


files <- files[filesnames %in% datainfonames]


files.names2 <- sapply(files, function(x) strsplit(x, split=paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, "/", sep=""))[[1]][2])
filesnames <- sapply(files.names2, function(x) strsplit(x, split="_sample_table.txt")[[1]])
names(filesnames) <- NULL



all(filesnames==datainfonames[length(datainfonames):1])



datainfo <- datainfo[nrow(datainfo):1,]






head(readLines(files[1]))




sampletemp <- readLines(files[1])[-1]
datamat <- matrix(nrow=length(files), ncol=length(sampletemp))

nit <- nrow(datamat)
for(i in seq(along=files)) {
  sampletemp <- readLines(files[i])[-1]
  datamat[i,] <- sapply(sampletemp, function(x) as.numeric(strsplit(x, split="\t")[[1]][2]))
  cat(paste("Sample", i, "of", nit), "\n")
}



X <- as.matrix(datamat)


navars <- which(apply(X, 2, function(x) sum(is.na(x)))>0)

table(apply(X[,navars], 2, function(x) sum(is.na(x))))


X <- X[,apply(X, 2, function(x) sum(is.na(x)))<=10]


navars <- which(apply(X, 2, function(x) sum(is.na(x)))>0)

for(i in seq(along=navars)) {
    X[,navars[i]][is.na(X[,navars[i]])] <- median(X[,navars[i]], na.rm=TRUE)
}


y <- factor(as.numeric(datainfo$'Characteristics [disease status]'=="breast cancer sample")+1)



save(X, y, file="./CVIIMCodeData/DataRetrieval/DataSetsPCA/E-GEOD-37965.Rda")


rm(list=ls()); gc()

if(FALSE) {


load("./CVIIMCodeData/DataRetrieval/DataSetsPCA/E-GEOD-37965.Rda")

library("CMA")

K <- 5; niter <- 2

cvdatasets <- GenerateLearningsets(y = y, method = "CV", fold = K, niter = niter)


geneselobj <- GeneSelection(X, y, learningsets = cvdatasets, method="t.test")

tunenestedcv <- tune(X, y, learningsets = cvdatasets, genesel=geneselobj, nbgene=1000, classifier = scdaCMA)

which.min(tunenestedcv@tuneres[[1]])

nestedcrossval <- classification(X, y, learningsets = cvdatasets, 
  classifier = scdaCMA, tuneres = tunenestedcv)
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 



nestedcrossval <- classification(X, y, learningsets = cvdatasets, 
  classifier = scdaCMA, gensel=geneselobj, delta=median(unlist(tunenestedcv@tuneres)))
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 



mean(errortunensc11K3addon)
min(c(mean(y==1), mean(y==2)))


source("./CVIIMCodeData/AddOnFunctionsetc/compplot.R")
compplot(data=X, groups=y, groupsy=y)



}





rm(list=ls());gc()





















datasetid <- "E-GEOD-39046"



library("ArrayExpress")
getAE(datasetid, path = paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, sep=""), type = "processed")



adf <- readLines(paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid,"/", datasetid, ".sdrf.txt", sep=""))
table(sapply(adf, function(x) length(strsplit(x, split="\t")[[1]])))

datainfo <- data.frame(matrix(nrow=0, ncol=length(strsplit(adf[1], split="\t")[[1]])))
names(datainfo) <- strsplit(adf[1], split="\t")[[1]]

for(i in 1:(length(adf)-1))
  datainfo[i,] <- strsplit(adf[i+1], split="\t")[[1]]
rownames(datainfo) <- datainfo$'Source Name'


table(datainfo$'Characteristics [phenotype]')

datainfo <- datainfo[datainfo$'Characteristics [phenotype]' %in% c("ET", "NO"),]



files <- grep("_sample_table.txt", list.files(paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, sep=""), full.names=TRUE), value=TRUE)

datainfonames <- gsub(" 1", "", rownames(datainfo))

files.names2 <- sapply(files, function(x) strsplit(x, split=paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, "/", sep=""))[[1]][2])
filesnames <- sapply(files.names2, function(x) strsplit(x, split="_sample_table.txt")[[1]])
names(filesnames) <- NULL


files <- files[filesnames %in% datainfonames]


files.names2 <- sapply(files, function(x) strsplit(x, split=paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, "/", sep=""))[[1]][2])
filesnames <- sapply(files.names2, function(x) strsplit(x, split="_sample_table.txt")[[1]])
names(filesnames) <- NULL



all(filesnames==datainfonames[length(datainfonames):1])



datainfo <- datainfo[nrow(datainfo):1,]






head(readLines(files[1]))




sampletemp <- readLines(files[1])[-1]
datamat <- matrix(nrow=length(files), ncol=length(sampletemp))

nit <- nrow(datamat)
for(i in seq(along=files)) {
  sampletemp <- readLines(files[i])[-1]
  datamat[i,] <- sapply(sampletemp, function(x) as.numeric(strsplit(x, split="\t")[[1]][2]))
  cat(paste("Sample", i, "of", nit), "\n")
}



X <- as.matrix(datamat)



y <- factor(as.numeric(datainfo$'Characteristics [phenotype]'=="ET")+1)



save(X, y, file="./CVIIMCodeData/DataRetrieval/DataSetsPCA/E-GEOD-39046.Rda")


rm(list=ls()); gc()

if(FALSE) {


load("./CVIIMCodeData/DataRetrieval/DataSetsPCA/E-GEOD-39046.Rda")

library("CMA")

K <- 5; niter <- 2

cvdatasets <- GenerateLearningsets(y = y, method = "CV", fold = K, niter = niter)




tunenestedcv <- tune(X, y, learningsets = cvdatasets, classifier = scdaCMA)

which.min(tunenestedcv@tuneres[[1]])

nestedcrossval <- classification(X, y, learningsets = cvdatasets, 
  classifier = scdaCMA, tuneres = tunenestedcv)
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 

mean(errortunensc11K3addon)
min(c(mean(y==1), mean(y==2)))


source("./CVIIMCodeData/AddOnFunctionsetc/compplot.R")
compplot(data=X, groups=y, groupsy=y)

}





rm(list=ls());gc()





















datasetid <- "E-GEOD-39345"



library("ArrayExpress")
getAE(datasetid, path = paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, sep=""), type = "processed")



adf <- readLines(paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid,"/", datasetid, ".sdrf.txt", sep=""))
table(sapply(adf, function(x) length(strsplit(x, split="\t")[[1]])))

datainfo <- data.frame(matrix(nrow=0, ncol=length(strsplit(adf[1], split="\t")[[1]])))
names(datainfo) <- strsplit(adf[1], split="\t")[[1]]

for(i in 1:(length(adf)-1))
  datainfo[i,] <- strsplit(adf[i+1], split="\t")[[1]]
rownames(datainfo) <- datainfo$'Source Name'



table(datainfo$'Characteristics[sample type]')

datainfo <- datainfo[datainfo$'Characteristics[sample type]' %in% c("before chemotherapy", "healthy"),]



files <- grep("_sample_table.txt", list.files(paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, sep=""), full.names=TRUE), value=TRUE)

datainfonames <- gsub(" 1", "", rownames(datainfo))

files.names2 <- sapply(files, function(x) strsplit(x, split=paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, "/", sep=""))[[1]][2])
filesnames <- sapply(files.names2, function(x) strsplit(x, split="_sample_table.txt")[[1]])
names(filesnames) <- NULL


files <- files[filesnames %in% datainfonames]


files.names2 <- sapply(files, function(x) strsplit(x, split=paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, "/", sep=""))[[1]][2])
filesnames <- sapply(files.names2, function(x) strsplit(x, split="_sample_table.txt")[[1]])
names(filesnames) <- NULL



all(filesnames==datainfonames[length(datainfonames):1])



datainfo <- datainfo[nrow(datainfo):1,]







head(readLines(files[1]))




sampletemp <- readLines(files[1])[-1]
datamat <- matrix(nrow=length(files), ncol=length(sampletemp))

nit <- nrow(datamat)
for(i in seq(along=files)) {
  sampletemp <- readLines(files[i])[-1]
  datamat[i,] <- sapply(sampletemp, function(x) as.numeric(strsplit(x, split="\t")[[1]][2]))
  cat(paste("Sample", i, "of", nit), "\n")
}



X <- as.matrix(datamat)


y <- factor(as.numeric(datainfo$'Characteristics[sample type]'=="before chemotherapy")+1)



save(X, y, file="./CVIIMCodeData/DataRetrieval/DataSetsPCA/E-GEOD-39345.Rda")


rm(list=ls()); gc()

if(FALSE) {


load("./CVIIMCodeData/DataRetrieval/DataSetsPCA/E-GEOD-39345.Rda")

library("CMA")

K <- 5; niter <- 2

cvdatasets <- GenerateLearningsets(y = y, method = "CV", fold = K, niter = niter)


geneselobj <- GeneSelection(X, y, learningsets = cvdatasets, method="t.test")

tunenestedcv <- tune(X, y, learningsets = cvdatasets, genesel=geneselobj, nbgene=1000, classifier = scdaCMA)

which.min(tunenestedcv@tuneres[[1]])

nestedcrossval <- classification(X, y, learningsets = cvdatasets, 
  classifier = scdaCMA, tuneres = tunenestedcv)
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 



nestedcrossval <- classification(X, y, learningsets = cvdatasets, 
  classifier = scdaCMA, gensel=geneselobj, delta=median(unlist(tunenestedcv@tuneres)))
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 



mean(errortunensc11K3addon)
min(c(mean(y==1), mean(y==2)))


source("./CVIIMCodeData/AddOnFunctionsetc/compplot.R")
compplot(data=X, groups=y, groupsy=y)



}





rm(list=ls());gc()





















datasetid <- "E-GEOD-42042"



library("ArrayExpress")
getAE(datasetid, path = paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, sep=""), type = "processed")



try(adf <- read.AnnotatedDataFrame(paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid,"/", datasetid, ".sdrf.txt", sep="")))
if(exists("adf"))
  datainfo <- adf@data


datainfo <- datainfo[datainfo$'Characteristics..disease.state.' %in% c("primary myelofibrosis", "essential thrombocythemia"),]






files <- grep("_sample_table.txt", list.files(paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, sep=""), full.names=TRUE), value=TRUE)

datainfonames <- gsub(" 1", "", rownames(datainfo))

files.names2 <- sapply(files, function(x) strsplit(x, split=paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, "/", sep=""))[[1]][2])
filesnames <- sapply(files.names2, function(x) strsplit(x, split="_sample_table.txt")[[1]])
names(filesnames) <- NULL


files <- files[filesnames %in% datainfonames]


files.names2 <- sapply(files, function(x) strsplit(x, split=paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, "/", sep=""))[[1]][2])
filesnames <- sapply(files.names2, function(x) strsplit(x, split="_sample_table.txt")[[1]])
names(filesnames) <- NULL



all(filesnames==datainfonames[length(datainfonames):1])



datainfo <- datainfo[nrow(datainfo):1,]





head(readLines(files[1]))




sampletemp <- readLines(files[1])[-1]
datamat <- matrix(nrow=length(files), ncol=length(sampletemp))

nit <- nrow(datamat)
for(i in seq(along=files)) {
  sampletemp <- readLines(files[i])[-1]
  datamat[i,] <- sapply(sampletemp, function(x) as.numeric(strsplit(x, split="\t")[[1]][2]))
  cat(paste("Sample", i, "of", nit), "\n")
}



X <- as.matrix(datamat)


navars <- which(apply(X, 2, function(x) sum(is.na(x)))>0)

for(i in seq(along=navars)) {
    X[,navars[i]][is.na(X[,navars[i]])] <- median(X[,navars[i]], na.rm=TRUE)
}


y <- factor(as.numeric(datainfo$'Characteristics..disease.state.'=="essential thrombocythemia")+1)



save(X, y, file="./CVIIMCodeData/DataRetrieval/DataSetsPCA/E-GEOD-42042.Rda")


rm(list=ls()); gc()

if(FALSE) {


load("./CVIIMCodeData/DataRetrieval/DataSetsPCA/E-GEOD-42042.Rda")

library("CMA")

K <- 5; niter <- 2

cvdatasets <- GenerateLearningsets(y = y, method = "CV", fold = K, niter = niter)


geneselobj <- GeneSelection(X, y, learningsets = cvdatasets, method="t.test")

tunenestedcv <- tune(X, y, learningsets = cvdatasets, genesel=geneselobj, nbgene=1000, classifier = scdaCMA)

which.min(tunenestedcv@tuneres[[1]])

nestedcrossval <- classification(X, y, learningsets = cvdatasets, 
  classifier = scdaCMA, tuneres = tunenestedcv)
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 



nestedcrossval <- classification(X, y, learningsets = cvdatasets, 
  classifier = scdaCMA, gensel=geneselobj, delta=median(unlist(tunenestedcv@tuneres)))
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 



mean(errortunensc11K3addon)
min(c(mean(y==1), mean(y==2)))


source("./CVIIMCodeData/AddOnFunctionsetc/compplot.R")
compplot(data=X, groups=y, groupsy=y)



}





rm(list=ls());gc()





















datasetid <- "E-GEOD-42826"



library("ArrayExpress")
getAE(datasetid, path = paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, sep=""), type = "processed")



try(adf <- read.AnnotatedDataFrame(paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid,"/", datasetid, ".sdrf.txt", sep="")))
datainfo <- adf@data



datainfo <- datainfo[datainfo$'Characteristics..disease.state.' %in% c("Active Sarcoid", "control"),]



files <- grep("_sample_table.txt", list.files(paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, sep=""), full.names=TRUE), value=TRUE)

datainfonames <- gsub(" 1", "", rownames(datainfo))

files.names2 <- sapply(files, function(x) strsplit(x, split=paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, "/", sep=""))[[1]][2])
filesnames <- sapply(files.names2, function(x) strsplit(x, split="_sample_table.txt")[[1]])
names(filesnames) <- NULL


files <- files[filesnames %in% datainfonames]


files.names2 <- sapply(files, function(x) strsplit(x, split=paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, "/", sep=""))[[1]][2])
filesnames <- sapply(files.names2, function(x) strsplit(x, split="_sample_table.txt")[[1]])
names(filesnames) <- NULL



all(filesnames==datainfonames[length(datainfonames):1])



datainfo <- datainfo[nrow(datainfo):1,]







head(readLines(files[1]))




sampletemp <- readLines(files[1])[-1]
datamat <- matrix(nrow=length(files), ncol=length(sampletemp))

nit <- nrow(datamat)
for(i in seq(along=files)) {
  sampletemp <- readLines(files[i])[-1]
  datamat[i,] <- sapply(sampletemp, function(x) as.numeric(strsplit(x, split="\t")[[1]][2]))
  cat(paste("Sample", i, "of", nit), "\n")
}



X <- as.matrix(datamat)


y <- factor(as.numeric(datainfo$'Characteristics..disease.state.'=="Active Sarcoid")+1)



save(X, y, file="./CVIIMCodeData/DataRetrieval/DataSetsPCA/E-GEOD-42826.Rda")


rm(list=ls()); gc()

if(FALSE) {


load("./CVIIMCodeData/DataRetrieval/DataSetsPCA/E-GEOD-42826.Rda")

library("CMA")

K <- 5; niter <- 2

cvdatasets <- GenerateLearningsets(y = y, method = "CV", fold = K, niter = niter)


geneselobj <- GeneSelection(X, y, learningsets = cvdatasets, method="t.test")

tunenestedcv <- tune(X, y, learningsets = cvdatasets, genesel=geneselobj, nbgene=1000, classifier = scdaCMA)

which.min(tunenestedcv@tuneres[[1]])

nestedcrossval <- classification(X, y, learningsets = cvdatasets, 
  classifier = scdaCMA, tuneres = tunenestedcv)
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 



nestedcrossval <- classification(X, y, learningsets = cvdatasets, 
  classifier = scdaCMA, gensel=geneselobj, delta=median(unlist(tunenestedcv@tuneres)))
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 



mean(errortunensc11K3addon)
min(c(mean(y==1), mean(y==2)))


source("./CVIIMCodeData/AddOnFunctionsetc/compplot.R")
compplot(data=X, groups=y, groupsy=y)



}





rm(list=ls());gc()





















datasetid <- "E-GEOD-42830"



library("ArrayExpress")
getAE(datasetid, path = paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, sep=""), type = "processed")



try(adf <- read.AnnotatedDataFrame(paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid,"/", datasetid, ".sdrf.txt", sep="")))
datainfo <- adf@data



datainfo <- datainfo[datainfo$'Characteristics..disease.state.' %in% c("Active Sarcoid", "control"),]





files <- grep("_sample_table.txt", list.files(paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, sep=""), full.names=TRUE), value=TRUE)

datainfonames <- gsub(" 1", "", rownames(datainfo))

files.names2 <- sapply(files, function(x) strsplit(x, split=paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, "/", sep=""))[[1]][2])
filesnames <- sapply(files.names2, function(x) strsplit(x, split="_sample_table.txt")[[1]])
names(filesnames) <- NULL


files <- files[filesnames %in% datainfonames]


files.names2 <- sapply(files, function(x) strsplit(x, split=paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, "/", sep=""))[[1]][2])
filesnames <- sapply(files.names2, function(x) strsplit(x, split="_sample_table.txt")[[1]])
names(filesnames) <- NULL



all(filesnames==datainfonames[length(datainfonames):1])



datainfo <- datainfo[nrow(datainfo):1,]








head(readLines(files[1]))




sampletemp <- readLines(files[1])[-1]
datamat <- matrix(nrow=length(files), ncol=length(sampletemp))

nit <- nrow(datamat)
for(i in seq(along=files)) {
  sampletemp <- readLines(files[i])[-1]
  datamat[i,] <- sapply(sampletemp, function(x) as.numeric(strsplit(x, split="\t")[[1]][2]))
  cat(paste("Sample", i, "of", nit), "\n")
}



X <- as.matrix(datamat)


y <- factor(as.numeric(datainfo$'Characteristics..disease.state.'=="Active Sarcoid")+1)



save(X, y, file="./CVIIMCodeData/DataRetrieval/DataSetsPCA/E-GEOD-42830.Rda")


rm(list=ls()); gc()

if(FALSE) {


load("./CVIIMCodeData/DataRetrieval/DataSetsPCA/E-GEOD-42830.Rda")

library("CMA")

K <- 5; niter <- 2

cvdatasets <- GenerateLearningsets(y = y, method = "CV", fold = K, niter = niter)


geneselobj <- GeneSelection(X, y, learningsets = cvdatasets, method="t.test")

tunenestedcv <- tune(X, y, learningsets = cvdatasets, genesel=geneselobj, nbgene=1000, classifier = scdaCMA)

which.min(tunenestedcv@tuneres[[1]])

nestedcrossval <- classification(X, y, learningsets = cvdatasets, 
  classifier = scdaCMA, tuneres = tunenestedcv)
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 



nestedcrossval <- classification(X, y, learningsets = cvdatasets, 
  classifier = scdaCMA, gensel=geneselobj, delta=median(unlist(tunenestedcv@tuneres)))
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 



mean(errortunensc11K3addon)
min(c(mean(y==1), mean(y==2)))


source("./CVIIMCodeData/AddOnFunctionsetc/compplot.R")
compplot(data=X, groups=y, groupsy=y)



}





rm(list=ls());gc()





















datasetid <- "E-GEOD-43329"



library("ArrayExpress")
getAE(datasetid, path = paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, sep=""), type = "processed")



try(adf <- read.AnnotatedDataFrame(paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid,"/", datasetid, ".sdrf.txt", sep="")))
datainfo <- adf@data




files <- grep("_sample_table.txt", list.files(paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, sep=""), full.names=TRUE), value=TRUE)

datainfonames <- gsub(" 1", "", rownames(datainfo))

files.names2 <- sapply(files, function(x) strsplit(x, split=paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, "/", sep=""))[[1]][2])
filesnames <- sapply(files.names2, function(x) strsplit(x, split="_sample_table.txt")[[1]])
names(filesnames) <- NULL


files <- files[filesnames %in% datainfonames]


files.names2 <- sapply(files, function(x) strsplit(x, split=paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, "/", sep=""))[[1]][2])
filesnames <- sapply(files.names2, function(x) strsplit(x, split="_sample_table.txt")[[1]])
names(filesnames) <- NULL



all(filesnames==datainfonames[length(datainfonames):1])



datainfo <- datainfo[nrow(datainfo):1,]







head(readLines(files[1]))




sampletemp <- readLines(files[1])[-1]
datamat <- matrix(nrow=length(files), ncol=length(sampletemp))

nit <- nrow(datamat)
for(i in seq(along=files)) {
  sampletemp <- readLines(files[i])[-1]
  datamat[i,] <- sapply(sampletemp, function(x) as.numeric(strsplit(x, split="\t")[[1]][2]))
  cat(paste("Sample", i, "of", nit), "\n")
}



X <- as.matrix(datamat)


y <- factor(as.numeric(datainfo$'Comment..Sample_source_name.'=="plasma from nasopharyngeal carcinoma patient")+1)



source("./CVIIMCodeData/AddOnFunctionsetc/compplot.R")
compplot(data=X, groups=y, groupsy=y)


plot(predict(prcomp(X))[,1:2])

notoutlier <- which(predict(prcomp(X))[,1] > -2e+05)

X <- X[notoutlier,]
y <- y[notoutlier]



save(X, y, file="./CVIIMCodeData/DataRetrieval/DataSetsPCA/E-GEOD-43329.Rda")


rm(list=ls()); gc()

if(FALSE) {


load("./CVIIMCodeData/DataRetrieval/DataSetsPCA/E-GEOD-43329.Rda")

library("CMA")

K <- 5; niter <- 2

cvdatasets <- GenerateLearningsets(y = y, method = "CV", fold = K, niter = niter)




tunenestedcv <- tune(X, y, learningsets = cvdatasets, classifier = scdaCMA)

which.min(tunenestedcv@tuneres[[1]])

nestedcrossval <- classification(X, y, learningsets = cvdatasets, 
  classifier = scdaCMA, tuneres = tunenestedcv)
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 

mean(errortunensc11K3addon)
min(c(mean(y==1), mean(y==2)))


source("./CVIIMCodeData/AddOnFunctionsetc/compplot.R")
compplot(data=X, groups=y, groupsy=y)


}





rm(list=ls());gc()





















datasetid <- "E-GEOD-48153"



library("ArrayExpress")
getAE(datasetid, path = paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, sep=""), type = "processed")



try(adf <- read.AnnotatedDataFrame(paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid,"/", datasetid, ".sdrf.txt", sep="")))
if(exists("adf"))
  datainfo <- adf@data


table(datainfo$'Characteristics..disease.state.')

datainfo <- datainfo[datainfo$'Characteristics..disease.state.' %in% c("healthy", "sMDS"),]





files <- grep("_sample_table.txt", list.files(paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, sep=""), full.names=TRUE), value=TRUE)

datainfonames <- gsub(" 1", "", rownames(datainfo))

files.names2 <- sapply(files, function(x) strsplit(x, split=paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, "/", sep=""))[[1]][2])
filesnames <- sapply(files.names2, function(x) strsplit(x, split="_sample_table.txt")[[1]])
names(filesnames) <- NULL


files <- files[filesnames %in% datainfonames]


files.names2 <- sapply(files, function(x) strsplit(x, split=paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, "/", sep=""))[[1]][2])
filesnames <- sapply(files.names2, function(x) strsplit(x, split="_sample_table.txt")[[1]])
names(filesnames) <- NULL



all(filesnames==datainfonames[length(datainfonames):1])



datainfo <- datainfo[nrow(datainfo):1,]






head(readLines(files[1]))




sampletemp <- readLines(files[1])[-1]
datamat <- matrix(nrow=length(files), ncol=length(sampletemp))

nit <- nrow(datamat)
for(i in seq(along=files)) {
  sampletemp <- readLines(files[i])[-1]
  datamat[i,] <- sapply(sampletemp, function(x) as.numeric(strsplit(x, split="\t")[[1]][2]))
  cat(paste("Sample", i, "of", nit), "\n")
}



X <- as.matrix(datamat)


y <- factor(as.numeric(datainfo$'Characteristics..disease.state.'=="sMDS") + 1)



save(X, y, file="./CVIIMCodeData/DataRetrieval/DataSetsPCA/E-GEOD-48153.Rda")


rm(list=ls()); gc()

if(FALSE) {


load("./CVIIMCodeData/DataRetrieval/DataSetsPCA/E-GEOD-48153.Rda")

library("CMA")

K <- 5; niter <- 2

cvdatasets <- GenerateLearningsets(y = y, method = "CV", fold = K, niter = niter)


geneselobj <- GeneSelection(X, y, learningsets = cvdatasets, method="t.test")

tunenestedcv <- tune(X, y, learningsets = cvdatasets, genesel=geneselobj, nbgene=1000, classifier = scdaCMA)

which.min(tunenestedcv@tuneres[[1]])

nestedcrossval <- classification(X, y, learningsets = cvdatasets, 
  classifier = scdaCMA, tuneres = tunenestedcv)
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 



nestedcrossval <- classification(X, y, learningsets = cvdatasets, 
  classifier = scdaCMA, gensel=geneselobj, delta=median(unlist(tunenestedcv@tuneres)))
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 



mean(errortunensc11K3addon)
min(c(mean(y==1), mean(y==2)))


source("./CVIIMCodeData/AddOnFunctionsetc/compplot.R")
compplot(data=X, groups=y, groupsy=y)


}





rm(list=ls());gc()





















datasetid <- "E-GEOD-49641"



library("ArrayExpress")
getAE(datasetid, path = paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, sep=""), type = "processed")



try(adf <- read.AnnotatedDataFrame(paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid,"/", datasetid, ".sdrf.txt", sep="")))
datainfo <- adf@data





files <- grep("_sample_table.txt", list.files(paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, sep=""), full.names=TRUE), value=TRUE)

datainfonames <- gsub(" 1", "", rownames(datainfo))

files.names2 <- sapply(files, function(x) strsplit(x, split=paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, "/", sep=""))[[1]][2])
filesnames <- sapply(files.names2, function(x) strsplit(x, split="_sample_table.txt")[[1]])
names(filesnames) <- NULL


files <- files[filesnames %in% datainfonames]


files.names2 <- sapply(files, function(x) strsplit(x, split=paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, "/", sep=""))[[1]][2])
filesnames <- sapply(files.names2, function(x) strsplit(x, split="_sample_table.txt")[[1]])
names(filesnames) <- NULL



all(filesnames==datainfonames[length(datainfonames):1])



datainfo <- datainfo[nrow(datainfo):1,]









try(sampletemp <- read.table(files[1], header=TRUE))


if(exists("sampletemp")) {


sampletemp <- read.table(files[1], header=TRUE)

IDmat <- as.data.frame(matrix(nrow=length(files), ncol=nrow(sampletemp)))
datamat <- as.data.frame(matrix(nrow=length(files), ncol=nrow(sampletemp)))

IDmat[1,] <- sampletemp$ID_REF
datamat[1,] <- sampletemp$VALUE

nit <- nrow(datamat)
for(i in seq(along=files)[-1]) {
  sampletemp <- read.table(files[i], header=TRUE)
  IDmat[i,] <- sampletemp$ID_REF
  datamat[i,] <- sampletemp$VALUE
  cat(paste("Sample", i, "of", nit), "\n")
}


allequalvec <- apply(IDmat, 2, function(x) length(unique(x))==1)
all(allequalvec)


X <- as.matrix(datamat)

}


y <- factor(as.numeric(datainfo$'Characteristics..disease.state.'=="PDAC")+1)



save(X, y, file="./CVIIMCodeData/DataRetrieval/DataSetsPCA/E-GEOD-49641.Rda")


rm(list=ls()); gc()

if(FALSE) {


load("./CVIIMCodeData/DataRetrieval/DataSetsPCA/E-GEOD-49641.Rda")

library("CMA")

K <- 5; niter <- 2

cvdatasets <- GenerateLearningsets(y = y, method = "CV", fold = K, niter = niter)


geneselobj <- GeneSelection(X, y, learningsets = cvdatasets, method="t.test")

tunenestedcv <- tune(X, y, learningsets = cvdatasets, genesel=geneselobj, nbgene=1000, classifier = scdaCMA)

which.min(tunenestedcv@tuneres[[1]])

nestedcrossval <- classification(X, y, learningsets = cvdatasets, 
  classifier = scdaCMA, tuneres = tunenestedcv)
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 



nestedcrossval <- classification(X, y, learningsets = cvdatasets, 
  classifier = scdaCMA, gensel=geneselobj, delta=median(unlist(tunenestedcv@tuneres)))
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 



mean(errortunensc11K3addon)
min(c(mean(y==1), mean(y==2)))


source("./CVIIMCodeData/AddOnFunctionsetc/compplot.R")
compplot(data=X, groups=y, groupsy=y)



}





rm(list=ls());gc()





















datasetid <- "E-GEOD-57285"



library("ArrayExpress")
getAE(datasetid, path = paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, sep=""), type = "processed")



try(adf <- read.AnnotatedDataFrame(paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid,"/", datasetid, ".sdrf.txt", sep="")))
datainfo <- adf@data



datainfo <- datainfo[datainfo$'Characteristics..subject.group.'!="BRCA1 mutants and healthy",]





files <- grep("_sample_table.txt", list.files(paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, sep=""), full.names=TRUE), value=TRUE)

datainfonames <- gsub(" 1", "", rownames(datainfo))

files.names2 <- sapply(files, function(x) strsplit(x, split=paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, "/", sep=""))[[1]][2])
filesnames <- sapply(files.names2, function(x) strsplit(x, split="_sample_table.txt")[[1]])
names(filesnames) <- NULL


files <- files[filesnames %in% datainfonames]


files.names2 <- sapply(files, function(x) strsplit(x, split=paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", datasetid, "/", sep=""))[[1]][2])
filesnames <- sapply(files.names2, function(x) strsplit(x, split="_sample_table.txt")[[1]])
names(filesnames) <- NULL



all(filesnames==datainfonames[length(datainfonames):1])



datainfo <- datainfo[nrow(datainfo):1,]




head(readLines(files[1]))




sampletemp <- readLines(files[1])[-1]
datamat <- matrix(nrow=length(files), ncol=length(sampletemp))

nit <- nrow(datamat)
for(i in seq(along=files)) {
  sampletemp <- readLines(files[i])[-1]
  datamat[i,] <- sapply(sampletemp, function(x) as.numeric(strsplit(x, split="\t")[[1]][2]))
  cat(paste("Sample", i, "of", nit), "\n")
}



X <- as.matrix(datamat)


navars <- which(apply(X, 2, function(x) sum(is.na(x)))>0)

for(i in seq(along=navars)) {
    X[,navars[i]][is.na(X[,navars[i]])] <- median(X[,navars[i]], na.rm=TRUE)
}


y <- factor(as.numeric(datainfo$'Characteristics..subject.group.'=="BRCA1 mutants with breast cancer")+1)



save(X, y, file="./CVIIMCodeData/DataRetrieval/DataSetsPCA/E-GEOD-57285.Rda")

rm(list=ls()); gc()


if(FALSE) {


load("./CVIIMCodeData/DataRetrieval/DataSetsPCA/E-GEOD-57285.Rda")

library("CMA")

K <- 5; niter <- 2

cvdatasets <- GenerateLearningsets(y = y, method = "CV", fold = K, niter = niter)


geneselobj <- GeneSelection(X, y, learningsets = cvdatasets, method="t.test")

tunenestedcv <- tune(X, y, learningsets = cvdatasets, genesel=geneselobj, nbgene=1000, classifier = scdaCMA)

which.min(tunenestedcv@tuneres[[1]])

nestedcrossval <- classification(X, y, learningsets = cvdatasets, 
  classifier = scdaCMA, tuneres = tunenestedcv)
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 



nestedcrossval <- classification(X, y, learningsets = cvdatasets, 
  classifier = scdaCMA, gensel=geneselobj, delta=median(unlist(tunenestedcv@tuneres)))
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

errortunensc11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)

errortunensc11K3addon 



mean(errortunensc11K3addon)
min(c(mean(y==1), mean(y==2)))


source("./CVIIMCodeData/AddOnFunctionsetc/compplot.R")
compplot(data=X, groups=y, groupsy=y)



}





rm(list=ls());gc()



















# Library to handle (microarray) data sets from GEO:
library("GEOquery")

# Download data:
download.file(url="ftp://ftp.ncbi.nlm.nih.gov/geo/series/GSE20nnn/GSE20189/matrix/GSE20189_series_matrix.txt.gz", destfile="./CVIIMCodeData/DataRetrieval/DataSetsPCA/GSE20189/GSE20189_series_matrix.txt.gz")

# Read in expression data:
X1 <- getGEO(file="./CVIIMCodeData/DataRetrieval/DataSetsPCA/GSE20189/GSE20189_series_matrix.txt.gz")

# p x n - expression matrix:
Xdata <- exprs(X1)

# Pheno data:
Xpheno <- phenoData(X1)
Xpheno2 <- pData(Xpheno)


# Check whether the samples have the same order in pheno and expression data:
all(Xpheno2$geo_accession==colnames(Xdata))

# --> Yes.


# Transpose expression data and extract target variable:
X <- t(Xdata)
y <- Xpheno2$description

# --> There are some samples, which are declared as excluded.
#  --> Remove these from the data set:

included <- which(!(y %in% c("Case Excluded" , "Non Case Excluded")))
X <- X[included,]
y <- y[included]

# Recode target variable:
ytemp <- y
y <- rep(1, length(ytemp))
y[ytemp == "Case"] <- 2
y <- as.factor(y)

# Because of the high computional burden, we only consider a subset of randomly selected
# 100 Patients:
set.seed(1234); subsetall <- sort(sample(1:length(y), size=100))
# result:
# subsetall <- c(2, 4, 5, 6, 7, 8, 9, 11, 14, 16, 17, 18, 21, 22, 24, 25, 26, 27, 29, 
#   30, 31, 32, 33, 34, 35, 36, 37, 39, 40, 41, 43, 44, 48, 50, 51, 52, 55, 56, 57,
#   58, 61, 62, 63, 65, 67, 68, 69, 71, 73, 74, 75, 77, 78, 79, 80, 81, 83, 87, 88,
#   90, 93, 94, 95, 97, 98, 100, 101, 103, 104, 107, 112, 113, 114, 115, 116, 118,
#   119, 123, 124, 125, 128, 129, 130, 131, 134, 135, 136, 137, 138, 139, 140, 141,
#   142, 145, 146, 147, 149, 151, 152, 153)


# Subset data:
X <- X[subsetall,]
y <- y[subsetall]


# Save data set 'GSE20189':
save(X, y, file="./CVIIMCodeData/DataRetrieval/DataSetsPCA/GSE20189.Rda")

# Clear the workspace:
rm(list=ls())





rm(list=ls());gc()




















library("GEOquery")

download.file(url="ftp://ftp.ncbi.nlm.nih.gov/geo/series/GSE33nnn/GSE33205/matrix/GSE33205_series_matrix.txt.gz", destfile="./CVIIMCodeData/DataRetrieval/DataSetsPCA/GSE33205/GSE33205_series_matrix.txt.gz")

X1 <- getGEO(file="./CVIIMCodeData/DataRetrieval/DataSetsPCA/GSE33205/GSE33205_series_matrix.txt.gz")


Xdata <- exprs(X1)

Xpheno <- phenoData(X1)
Xpheno2 <- pData(Xpheno)

table(Xpheno2$characteristics_ch1.1)



all(Xpheno2$geo_accession==colnames(Xdata))




X <- t(Xdata)
ytemp <- Xpheno2$characteristics_ch1.1
y <- rep(1, length(ytemp))
y[ytemp=="sample type: tumor"] <- 2
y <- as.factor(y)

set.seed(1234); subsettumor <- sort(sample(which(y==2), size=sum(y==1)))


subsetall <- sort(c(subsettumor, which(y==1)))

X <- X[subsetall,]
y <- y[subsetall]

save(X, y, file="./CVIIMCodeData/DataRetrieval/DataSetsPCA/GSE33205.Rda")

rm(list=ls())





rm(list=ls());gc()




















library("GEOquery")

download.file(url="ftp://ftp.ncbi.nlm.nih.gov/geo/series/GSE37nnn/GSE37356/matrix/GSE37356_series_matrix.txt.gz", destfile="./CVIIMCodeData/DataRetrieval/DataSetsPCA/GSE37356/GSE37356_series_matrix.txt.gz")

X1 <- getGEO(file="./CVIIMCodeData/DataRetrieval/DataSetsPCA/GSE37356/GSE37356_series_matrix.txt.gz")

Xdata <- exprs(X1)



Xpheno <- phenoData(X1)
Xpheno2 <- pData(Xpheno)


all(Xpheno2$geo_accession==colnames(Xdata))



X <- t(Xdata)
ytemp <- Xpheno2$characteristics_ch1.2
y <- rep(1, length(ytemp))
y[ytemp=="lupus status: case"] <- 2
y <- as.factor(y)

subsetall <- sort(which(Xpheno2$characteristics_ch1.1 == "cell type: monocyte"))
X <- X[subsetall,]
y <- y[subsetall]

save(X, y, file="./CVIIMCodeData/DataRetrieval/DataSetsPCA/GSE37356.Rda")

rm(list=ls())
