#######################################################################################
#######################################################################################
#
# This data set appeared in the following paper:
#
# Singh, D., Febbo, P.G., Ross, K., Jackson, D.G., Manola, J.,Ladd, C., Tamayo, P., 
# Renshaw, A.A, D'Amico, A.V., Richie, J.P., Lander, E.s., Loda, M., Kantoff, P.W., 
# Golub, T.R. and Sellers, W.R. (2002). Gene  expression correlates of clinical prostate 
# cancer behavior. Cancer Cell 1, 203-209.
#
# It was available to us in the form of two Rdata-files - RMA.RData and y.RData, found
# in the zip-folder for reproducing results 'reproduce_results.zip' from the paper:
# Bernau, C., Augustin, T., and Boulesteix, A.-L. (2013). Correcting the Optimal 
# Resampling-Based Error Rate by Estimating the Error Rate of Wrapper Algorithms. 
# Biometrics 69, 693-702.
# The folder can be downloaded from the following webpage:
# http://www.ibe.med.uni-muenchen.de/organisation/mitarbeiter/090_ehemalige/20130630_bernau/cvbias/index.html
# 
# NOTE: The purpose of this script is merely to inform the reader on how the 
# form of the dataset 'ProstatecTranscr.Rda' available in './CVIIMCodeData/DataRetrieval/DataSetsPCA/' 
# was produced. Because other than in the cases of the other datasets this dataset is
# already available, it is not necessary to run this script (and also possible without 
# having downloaded 'RMA.RData' and 'y.RData' beforehand).
#
#######################################################################################
#######################################################################################

# Read in the two RData-files:
load("RMA.RData")

load("y.RData")
# y is already a factor with levels 1 and 2 in this RData-file.

# Transpose and rename the expression matrix:
library("affy")
X <- t(exprs(RMA))
y <- factor(as.numeric(y))

# Save data set 'ProstatecTranscr':
save(X, y, file="./CVIIMCodeData/DataRetrieval/DataSetsPCA/ProstatecTranscr.Rda")

# Clear the workspace:
rm(list=ls())