# Normalization:
#################

normdatafolder <- "./CVIIMCodeData/DataRetrieval/DataSetsNormalization/"
labels <- list.files(normdatafolder)[file.info(paste(normdatafolder, list.files(normdatafolder), sep=""))$isdir]

datasetsfolder <- paste("./CVIIMCodeData/DataRetrieval/DataSetsNormalization/", labels, sep="")

nsamples <- nvars <- classimbs <- 0

for(i in seq(along=datasetsfolder)) {
  load(paste(datasetsfolder[i], "/XnormwholeRMA.Rda", sep=""))
  load(paste(datasetsfolder[i], "/target_variable.Rda", sep=""))

  nsamples[i] <- nrow(XnormwholeRMA)
  nvars[i] <- ncol(XnormwholeRMA)
  classimbs[i] <- min(c(mean(y==1), mean(y==2)))

  rm(XnormwholeRMA, y)
}

# labels
datatype <- c("transcription",
  "transcription",
  "transcription",
  "transcription",
  "transcription",
  "transcription",
  "transcription",
  "transcription",
  "transcription",
  "transcription",
  "transcription",
  "transcription")  


datainfonorm <- data.frame(label=labels, nsample=nsamples, 
  nvar=nvars, classimb=classimbs, 
  datatype=datatype)





# Principal Component Analysis:
###############################

labels <- c("ProstatecTranscr", "GSE33205", "GSE20189", "GSE37356", 
"E-GEOD-25609", "E-GEOD-31629", "E-GEOD-32393", "E-GEOD-33615", 
"E-GEOD-36769", "E-GEOD-37582", "E-GEOD-37965", "E-GEOD-39046", 
"E-GEOD-39345", "E-GEOD-42042", "E-GEOD-42826", "E-GEOD-42830", 
"E-GEOD-43329", "E-GEOD-48153", "E-GEOD-49641", "E-GEOD-57285")

datasets <- paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", labels, ".Rda", sep="")

nsamples <- nvars <- classimbs <- 0

for(i in seq(along=datasets)) {
  load(datasets[i])

  nsamples[i] <- nrow(X)
  nvars[i] <- ncol(X)
  classimbs[i] <- min(c(mean(y==1), mean(y==2)))

  rm(X, y)
}


datatype <- c("transcription",
  "transcription",
  "transcription",
  "transcription",
  "transcription",
  "transcription",
  "DNA methylation",
  "transcription",
  "transcription",
  "transcription",
  "DNA methylation",
  "transcription",
  "transcription",
  "DNA methylation",
  "transcription",
  "transcription",
  "transcription",
  "proteomic",
  "transcription",
  "DNA methylation")  


datainfopca <- data.frame(label=labels, nsample=nsamples, 
  nvar=nvars, classimb=classimbs, 
  datatype=datatype)



datainfo <- rbind(datainfonorm, datainfopca)
datainfo$study <- rep(c("Normalization", "PCA"), times=c(nrow(datainfonorm), nrow(datainfopca)))
datainfo <- datainfo[,c(which(names(datainfo)=="study"), which(names(datainfo)!="study"))]

save(datainfo, file="./CVIIMCodeData/DataRetrieval/datainfoNormPCA.Rda")



load("./CVIIMCodeData/DataRetrieval/datainfoNormPCA.Rda")

datainfo <- datainfo[order(as.numeric(datainfo$study=="Normalization"), datainfo$nsample, decreasing=TRUE),]
datainfo$classimb <- format(round(datainfo$classimb, 2), nsmall=2)
rownames(datainfo) <- NULL

datainfo$id <- 1:nrow(datainfo)


tablecontent <- as.vector(apply(datainfo, 1, function(x) {
  c(paste(paste(x, collapse=" & "), "\\\\[2pt]"), "\\hline")
}))
tablecontent <- tablecontent[-length(tablecontent)]
tablecontent[length(tablecontent)] <- gsub("\\\\[2pt]", "", tablecontent[length(tablecontent)])
tablecontent <- gsub("methylation", "methyl.", tablecontent)


tablelatex <- c("\\begin{table}",
"\\begin{tabular}{ c | c | c | c | c | c | c }",
"Study & Label & Num. of & Num. of & Prop. with & Data type & ID\\\\", 
" & & observ. & variables & y = 2 & \\\\[2pt]",
"\\hline",
tablecontent,
"\\end{tabular}", 
"\\caption{Datasets}", 
"\\label{table:datasets}",
"\\end{table}")


for(i in seq(along=tablelatex))
  cat(tablelatex[i], "\n")
