# NOTE: In order to understand this code it is required to be familiar
# with the functionality of the 'BatchExperiments'-package.

# Set working directory and path to store results to:
savepath <- "./CVIIMCodeData/NormalizationStudy/NormalizationNSC/"

# Load 'BatchExperiments'-package:
library("BatchExperiments")

# Number of replications:
numberrep <- 1


# Source the required code:
source(paste(savepath, "NormalizationfunctionsforBatchExperimentsNSC.R", sep=""))


# Make the registry:

if(!file.exists(paste(savepath, "ResultsNSC", sep="")))
  dir.create(paste(savepath, "ResultsNSC", sep=""))
reg <- makeExperimentRegistry(id="NormExtensiveStudy", file.dir=paste(savepath, "ResultsNSC/", sep=""),
  work.dir=savepath, seed=1234)


# Save the registry:
save(reg, file=paste(savepath, "currentregistryNSC.Rda", sep=""))


# Define data set part:
addProblem(reg, id="getscenario", dynamic=getscenario, overwrite=TRUE)

# Define algorithm part:
addAlgorithm(reg, id="splittingfun", fun=splittingfun, overwrite=TRUE)



# Design for data sets:

pars <- list(dataset=c("E-GEOD-30174", "E-GEOD-34465", "E-GEOD-39683", "E-GEOD-40744", "E-GEOD-46053", 
  "E-MTAB-57"))

# Generate and store splittings for the repeated CV:  
numit <- 300
Kseq <- c(3,5,10)

set.seed(1234)
library("CMA")
for(i in seq(along=pars$dataset)) {

  datasetfolder <- paste("./CVIIMCodeData/DataRetrieval/DataSetsNormalization/", pars$dataset[i], sep="")
  load(paste(datasetfolder, "/target_variable.Rda", sep=""))
  
  for(j in seq(along=Kseq)) {
    eval(parse(text=paste("learninds", Kseq[j], " <- GenerateLearningsets(y=y, method='CV',fold=", Kseq[j], ", niter=numit)@learnmatrix", sep="")))
    eval(parse(text=paste("save(learninds", Kseq[j], ", file=paste(datasetfolder, \"/learninds", Kseq[j], ".Rda\", sep=\"\"))", sep="")))
  }
  
}

splittingit <- unlist(sapply(numit*Kseq, function(x) 1:x))
Kit <- rep(Kseq, times=numit*Kseq)
splittings <- data.frame(splitting=splittingit, K=Kit)

getscenario.design <- makeDesign("getscenario", design=splittings, exhaustive=pars)



# Define algorithms:
pars <- list(method=c("RMA", "RMAglobalVSN"))
splittingfun.design <- makeDesign("splittingfun", exhaustive=pars)


# Define analysis:
addExperiments(reg, prob.designs=getscenario.design, algo.designs=splittingfun.design, repls=numberrep, skip.defined=TRUE)

# Submit the jobs:
submitJobs(reg, ids=1:summarizeExperiments(reg)$.count, wait=function(retries) 100, max.retries=10)

# Clear the workspace:
rm(list=ls()); gc()
