# Function to perform the normalization on the whole dataset for
# one of the two normalization techniques on a specific dataset.
# 'scenind' is the index of the scenario, see 'NormalizationWholeDatasetCluster.R':

prenormfun <- function(scenind) {

  # Get dataset and method:
  dataset <- scenariogrid[scenind,]$dataset
  method <- scenariogrid[scenind,]$method
  
  # Load respective CEL files:  
  require("affy")
  datasetfolder <- paste(savepath, dataset, sep="")

  wdsafe <- getwd()
  setwd(datasetfolder)
  aboall <- ReadAffy()
  setwd(wdsafe)

  # Load values of the target variable:
  load(paste(datasetfolder, "/target_variable.Rda", sep=""))
  # --> y
  
  # Perform normalization with 'RMA' or 'RMAglobalVSN' (depending on 'scenind'),
  # the result is saved:
  require("CMA")
  require("docval")

  functionfolder <- "./CVIIMCodeData/AddOnFunctionsetc/KostkaFunctions/"

  allrscripts <- list.files(paste(functionfolder, "Rpack", sep=""), full.names = TRUE)
  for(i in seq(along=allrscripts))
    source(allrscripts[i])

  source(paste(functionfolder, "summarize_val.R",sep=''))
  source(paste(functionfolder, "summarize_add.R",sep=''))
  source(paste(functionfolder,'extractAffybatch.r',sep=''))

  source("./CVIIMCodeData/AddOnFunctionsetc/Normalization_functions.R")

  if(method=="RMA") {
    XnormwholeRMA <- RMAparam(1:length(y), aboall)$normdata
    save(XnormwholeRMA, file=paste(datasetfolder, "/XnormwholeRMA.Rda", sep=""))
  }
  if(method=="RMAglobalVSN") {
    XnormwholeRMAglobalVSN <- RMAVSNparam(1:length(y), aboall)$normdata
    save(XnormwholeRMAglobalVSN, file=paste(datasetfolder, "/XnormwholeRMAglobalVSN.Rda", sep=""))
  }
  
}











loaddatafun <- function(dataset) {

  require("CMA")
  require("affy")
  
  datasetfolder <- paste(savepath, dataset, sep="")

  wdsafe <- getwd()
  setwd(datasetfolder)
  aboall <- ReadAffy()
  setwd(wdsafe)

  load(paste(savepath, dataset, "/target_variable.Rda", sep=""))
  # --> y

  return(list(aboall=aboall, y=y))
  
}


splittingfun <- function(scenind) {

  dataset <- scenariogrid[scenind,]$dataset
  method <- scenariogrid[scenind,]$method
  K <- scenariogrid[scenind,]$K
  splitting <- scenariogrid[scenind,]$splitting 
  seed <- scenariogrid[scenind,]$seed 

  set.seed(seed)
  
  require("CMA")
  require("affy")
   
  datasetfolder <- paste(savepath, dataset, sep="")  
  
  aboall <- affydatasets[[which(datasets==dataset)]]$aboall
  y <- affydatasets[[which(datasets==dataset)]]$y
    

  require("docval")

  functionfolder <- "./CVIIMCodeData/AddOnFunctionsetc/KostkaFunctions/"

  allrscripts <- list.files(paste(functionfolder, "Rpack", sep=""), full.names = TRUE)
  for(i in seq(along=allrscripts))
    source(allrscripts[i])

  source(paste(functionfolder, "summarize_val.R",sep=''))
  source(paste(functionfolder, "summarize_add.R",sep=''))
  source(paste(functionfolder,'extractAffybatch.r',sep=''))

  source("./CVIIMCodeData/AddOnFunctionsetc/Normalization_functions.R")


  if(K==3) { 
    load(paste(datasetfolder, "/learninds3.Rda", sep=""))
    learninds <- learninds3[splitting,] 
  }
  if(K==5) { 
    load(paste(datasetfolder, "/learninds5.Rda", sep=""))
    learninds <- learninds5[splitting,] 
  }
  if(K==10) { 
    load(paste(datasetfolder, "/learninds10.Rda", sep=""))
    learninds <- learninds10[splitting,] 
  }  

  
  
  if(method=="RMA") {
  
  load(paste(datasetfolder, "/XnormwholeRMA.Rda", sep=""))
  

  delta.grid <- c(0.05, 0.1, 0.25, 0.5, 1, 1.5)

  ytrain <- y[learninds]
  ytest <- y[-learninds]


  normparam <- RMAparam(learninds, aboall)
  Xnorm <- normparam$normdata
  Xtest <- RMAaddon(setdiff(1:length(y), learninds), aboall, normparam)

  tunecv <- try(0 + "0")
  counti <- 0
  while((class(tunecv)=="try-error") & (counti<20)) {
    tunecv <- try(tune(Xnorm, ytrain, classifier = scdaCMA, grids = list(delta = delta.grid)))
    counti <- counti+1
  }
  if(counti==20)
    stop("There seems to be no valid splitting for CV-based tuning parameter optimization possible.")
	
  delta.opt <- delta.grid[which.min(tunecv@tuneres[[1]])]
  classifier <- scdaCMApred(Xnorm, ytrain, delta = delta.opt, models=TRUE)

  yhat <- classifier(Xtest)

  errornormaddon <- mean(yhat != ytest)



  Xnorm <- XnormwholeRMA[learninds,]
  Xtest <- XnormwholeRMA[setdiff(1:length(y), learninds),]


  tunecv <- try(0 + "0")
  counti <- 0
  while((class(tunecv)=="try-error") & (counti<20)) {  
    tunecv <- try(tune(Xnorm, ytrain, classifier = scdaCMA, grids = list(delta = delta.grid)))
    counti <- counti+1
  }
  if(counti==20)
    stop("There seems to be no valid splitting for CV-based tuning parameter optimization possible.")
	
  delta.opt <- delta.grid[which.min(tunecv@tuneres[[1]])]
  classifier <- scdaCMApred(Xnorm, ytrain, delta = delta.opt, models=TRUE)

  yhat <- classifier(Xtest)

  errornormfull <- mean(yhat != ytest)

  return(list(dataset=dataset, method=method, K=K, splitting=splitting, 
    errornormfull=errornormfull, errornormaddon=errornormaddon, VSNfailed=NULL))

  }
  
  
  
  if(method=="RMAglobalVSN") {
  
  load(paste(datasetfolder, "/XnormwholeRMAglobalVSN.Rda", sep=""))
  

  delta.grid <- c(0.05, 0.1, 0.25, 0.5, 1, 1.5)

  ytrain <- y[learninds]
  ytest <- y[-learninds]

  
  normparam <- RMAVSNparam(learninds, aboall)
  Xnorm <- normparam$normdata
  Xtest <- RMAVSNaddon(setdiff(1:length(y), learninds), aboall, normparam)

  tunecv <- try(0 + "0")
  counti <- 0
  while((class(tunecv)=="try-error") & (counti<20)) {
    tunecv <- try(tune(Xnorm, ytrain, classifier = scdaCMA, grids = list(delta = delta.grid)))
    counti <- counti+1
  }
  if(counti==20)
    stop("There seems to be no valid splitting for CV-based tuning parameter optimization possible.")
	
  delta.opt <- delta.grid[which.min(tunecv@tuneres[[1]])]
  classifier <- scdaCMApred(Xnorm, ytrain, delta = delta.opt, models=TRUE)

  yhat <- classifier(Xtest)

  errornormaddon <- mean(yhat != ytest)



  Xnorm <- XnormwholeRMAglobalVSN[learninds,]
  Xtest <- XnormwholeRMAglobalVSN[setdiff(1:length(y), learninds),]


  tunecv <- try(0 + "0")
  counti <- 0
  while((class(tunecv)=="try-error") & (counti<20)) {  
    tunecv <- try(tune(Xnorm, ytrain, classifier = scdaCMA, grids = list(delta = delta.grid)))
    counti <- counti+1
  }
  if(counti==20)
    stop("There seems to be no valid splitting for CV-based tuning parameter optimization possible.")
	
  delta.opt <- delta.grid[which.min(tunecv@tuneres[[1]])]
  classifier <- scdaCMApred(Xnorm, ytrain, delta = delta.opt, models=TRUE)

  yhat <- classifier(Xtest)

  errornormfull <- mean(yhat != ytest)

  return(list(dataset=dataset, method=method, K=K, splitting=splitting, 
    errornormfull=errornormfull, errornormaddon=errornormaddon, VSNfailed=is.null(normparam$vsncoefficients)))

  }
  
  
}
