# Set working directory and path to store results to:
savepath <- "./CVIIMCodeData/DataRetrieval/DataSetsNormalization/"

# Load 'BatchExperiments'-package:
library("parallel")

numit <- 300
njobs <- 10
Kseq <- c(3,5,10)

splittingit <- unlist(sapply(numit*Kseq, function(x) 1:x))
Kit <- rep(Kseq, times=numit*Kseq)



scenariogrid <- expand.grid(K=Kit, method=c("RMA", "RMAglobalVSN"), dataset=c("E-GEOD-25639", "E-GEOD-47552", "E-GEOD-29044", 
"E-MEXP-3756", "E-GEOD-19722", "E-GEOD-10320"), stringsAsFactors = FALSE)
scenariogrid <- scenariogrid[,ncol(scenariogrid):1]
scenariogrid$splitting <- splittingit



set.seed(1234)
scenariogrid <- scenariogrid[sample(1:nrow(scenariogrid)),]

set.seed(1234)
seeds <- sample(1000:10000000, size=nrow(scenariogrid))
scenariogrid$seed <- seeds


###
scenariogrid <- scenariogrid[scenariogrid$method=="RMA",]
###


nitertotal <- nrow(scenariogrid)

iterationsperjob <- rep(floor(nitertotal/njobs), times=njobs)
iterationsperjob[1:(nitertotal - floor(nitertotal/njobs)*njobs)] <- iterationsperjob[1:(nitertotal - floor(nitertotal/njobs)*njobs)] + 1

endinds <- cumsum(iterationsperjob)
startinds <- c(1, (endinds+1)[-length(endinds)])


datasets <- unique(scenariogrid$dataset)

set.seed(1234)
library("CMA")
for(i in seq(along=datasets)) {

  datasetfolder <- paste(savepath, datasets[i], sep="")
  load(paste(datasetfolder, "/target_variable.Rda", sep=""))
  
  for(j in seq(along=Kseq)) {
    eval(parse(text=paste("learninds", Kseq[j], " <- GenerateLearningsets(y=y, method='CV',fold=", Kseq[j], ", niter=numit)@learnmatrix", sep="")))
    eval(parse(text=paste("save(learninds", Kseq[j], ", file=paste(datasetfolder, \"/learninds", Kseq[j], ".Rda\", sep=\"\"))", sep="")))
  }
  
}

save(scenariogrid, startinds, endinds, file="./CVIIMCodeData/NormalizationStudy/NormalizationPLSLDA/ScenarioSpecificationPLSLDARMA.Rda")






for(i in 1:njobs) {

fileConn <- file(paste("./CVIIMCodeData/NormalizationStudy/NormalizationPLSLDA/NormalizationScriptPLSLDARMA", i, ".R", sep=""))

writeLines(paste(c(paste("jobid <- ", i, sep=""),
" ",
"# Set working directory and path to store results to: ",
"savepath <- \"./CVIIMCodeData/DataRetrieval/DataSetsNormalization/\" ",
" ",
"# Load 'BatchExperiments'-package: ",
"library(\"parallel\") ",
"",
"",
"load(\"./CVIIMCodeData/NormalizationStudy/NormalizationPLSLDA/ScenarioSpecificationPLSLDARMA.Rda\") ",
"datasets <- unique(scenariogrid$dataset)",  
"  ",
"  ",
"source(\"./CVIIMCodeData/NormalizationStudy/NormalizationPLSLDA/NormalizationFunctionsClusterPLSLDA.R\") ",
"",
"RNGkind(\"L'Ecuyer-CMRG\")",
"set.seed(1234)",
"",
"affydatasets <- mclapply(datasets, loaddatafun, mc.silent=TRUE, mc.cores = length(datasets)) ",
"",
"results <- mclapply((1:nrow(scenariogrid))[startinds[jobid]:endinds[jobid]], splittingfun, ",
"  mc.silent=TRUE, mc.preschedule = FALSE, mc.cores = 20) ",
" ",
"save(results, file=paste(\"./CVIIMCodeData/NormalizationStudy/ResultsNormalization/resultsPLSLDARMA\", jobid, \".Rda\", sep=\"\")) ",
" ",
"rm(list=ls());gc()"), collapse="\n"), sep="", fileConn)

close(fileConn)

}

