getscenario <- function(dataset, K, splitting) {

  require("CMA")
  require("affy")
  
  datasetfolder <- paste("./CVIIMCodeData/DataRetrieval/DataSetsNormalization/", dataset, sep="")

  wdsafe <- getwd()
  setwd(datasetfolder)
  aboall <- ReadAffy()
  setwd(wdsafe)

  load(paste("./CVIIMCodeData/DataRetrieval/DataSetsNormalization/", dataset, "/target_variable.Rda", sep=""))
  # --> y

  return(list(aboall=aboall, y=y, K=K, splitting=splitting, datasetfolder=datasetfolder))  

}


splittingfun <- function(static, dynamic, method) {

  y <- dynamic$y
  K <- dynamic$K
  datasetfolder <- dynamic$datasetfolder
  splitting <- dynamic$splitting
  
  require("CMA")
  require("affy")
  require("docval")

  functionfolder <- "./CVIIMCodeData/AddOnFunctionsetc/KostkaFunctions/"

  allrscripts <- list.files(paste(functionfolder, "Rpack", sep=""), full.names = TRUE)
  for(i in seq(along=allrscripts))
    source(allrscripts[i])

  source(paste(functionfolder, "summarize_val.R",sep=''))
  source(paste(functionfolder, "summarize_add.R",sep=''))
  source(paste(functionfolder,'extractAffybatch.r',sep=''))

  source("./CVIIMCodeData/AddOnFunctionsetc/Normalization_functions.R")


  if(K==3) { 
    load(paste(datasetfolder, "/learninds3.Rda", sep=""))
    learninds <- learninds3[splitting,] 
  }
  if(K==5) { 
    load(paste(datasetfolder, "/learninds5.Rda", sep=""))
    learninds <- learninds5[splitting,] 
  }
  if(K==10) { 
    load(paste(datasetfolder, "/learninds10.Rda", sep=""))
    learninds <- learninds10[splitting,] 
  }  

  
  
  if(method=="RMA") {
  
  load(paste(datasetfolder, "/XnormwholeRMA.Rda", sep=""))
  

  comp.grid <- 1:10

  ytrain <- y[learninds]
  ytest <- y[-learninds]


  normparam <- RMAparam(learninds, dynamic$aboall)
  Xnorm <- normparam$normdata
  Xtest <- RMAaddon(setdiff(1:length(y), learninds), dynamic$aboall, normparam)

  tunecv <- try(0 + "0")
  counti <- 0
  while((class(tunecv)=="try-error") & (counti<20)) {
    tunecv <- try(tune(Xnorm, ytrain, classifier = pls_ldaCMA, grids = list(comp = comp.grid)))
    counti <- counti+1
  }
  if(counti==20)
    stop("There seems to be no valid splitting for CV-based tuning parameter optimization possible.")
	
  comp.opt <- comp.grid[which.min(tunecv@tuneres[[1]])]
  classifier <- pls_ldaCMA(rbind(Xnorm, Xtest), c(ytrain, ytest), learnind=1:length(ytrain), comp = comp.opt, models=TRUE)

  yhat <- classifier@yhat + 1

  errornormaddon <- mean(yhat != ytest)



  Xnorm <- XnormwholeRMA[learninds,]
  Xtest <- XnormwholeRMA[setdiff(1:length(y), learninds),]


  tunecv <- try(0 + "0")
  counti <- 0
  while((class(tunecv)=="try-error") & (counti<20)) {  
    tunecv <- try(tune(Xnorm, ytrain, classifier = pls_ldaCMA, grids = list(comp = comp.grid)))
    counti <- counti+1
  }
  if(counti==20)
    stop("There seems to be no valid splitting for CV-based tuning parameter optimization possible.")
	
  comp.opt <- comp.grid[which.min(tunecv@tuneres[[1]])]
  classifier <- pls_ldaCMA(rbind(Xnorm, Xtest), c(ytrain, ytest), learnind=1:length(ytrain), comp = comp.opt)

  yhat <- classifier@yhat + 1

  errornormfull <- mean(yhat != ytest)

  return(list(errornormfull=errornormfull, errornormaddon=errornormaddon, VSNfailed=NULL))

  }
  
  
  
  if(method=="RMAglobalVSN") {
  
  load(paste(datasetfolder, "/XnormwholeRMAglobalVSN.Rda", sep=""))
  

  comp.grid <- 1:10

  ytrain <- y[learninds]
  ytest <- y[-learninds]

  
  normparam <- RMAVSNparam(learninds, dynamic$aboall)
  Xnorm <- normparam$normdata
  Xtest <- RMAVSNaddon(setdiff(1:length(y), learninds), dynamic$aboall, normparam)

  tunecv <- try(0 + "0")
  counti <- 0
  while((class(tunecv)=="try-error") & (counti<20)) {
    tunecv <- try(tune(Xnorm, ytrain, classifier = pls_ldaCMA, grids = list(comp = comp.grid)))
    counti <- counti+1
  }
  if(counti==20)
    stop("There seems to be no valid splitting for CV-based tuning parameter optimization possible.")
	
  comp.opt <- comp.grid[which.min(tunecv@tuneres[[1]])]
  classifier <- pls_ldaCMA(rbind(Xnorm, Xtest), c(ytrain, ytest), learnind=1:length(ytrain), comp = comp.opt)

  yhat <- classifier@yhat + 1

  errornormaddon <- mean(yhat != ytest)



  Xnorm <- XnormwholeRMAglobalVSN[learninds,]
  Xtest <- XnormwholeRMAglobalVSN[setdiff(1:length(y), learninds),]


  tunecv <- try(0 + "0")
  counti <- 0
  while((class(tunecv)=="try-error") & (counti<20)) {  
    tunecv <- try(tune(Xnorm, ytrain, classifier = pls_ldaCMA, grids = list(comp = comp.grid)))
    counti <- counti+1
  }
  if(counti==20)
    stop("There seems to be no valid splitting for CV-based tuning parameter optimization possible.")
	
  comp.opt <- comp.grid[which.min(tunecv@tuneres[[1]])]
  classifier <- pls_ldaCMA(rbind(Xnorm, Xtest), c(ytrain, ytest), learnind=1:length(ytrain), comp = comp.opt)

  yhat <- classifier@yhat + 1

  errornormfull <- mean(yhat != ytest)

  return(list(errornormfull=errornormfull, errornormaddon=errornormaddon, VSNfailed=is.null(normparam$vsncoefficients)))

  }
  
  
  
}
