# NOTE: In order to understand this code it is required to be familiar
# with the functionality of the 'BatchExperiments'-package.

# Set working directory and path to store results to:
savepath <- "./CVIIMCodeData/NormalizationStudy/NormalizationWholeDataset/"

# Load 'BatchExperiments'-package:
library("BatchExperiments")


# Source the required code:
source("./CVIIMCodeData/NormalizationStudy/NormalizationNSC/NormalizationfunctionsforBatchExperimentsNSC.R")


# Make the registry:

if(!file.exists(paste(savepath, "ResultsPreNorm", sep="")))
  dir.create(paste(savepath, "ResultsPreNorm", sep=""))
regprenorm <- makeExperimentRegistry(id="NormExtensiveStudyPreNorm", file.dir=paste(savepath, "ResultsPreNorm/", sep=""),
  work.dir=savepath, seed=1234)

# Save the registry:
save(regprenorm, file=paste(savepath, "currentregistryprenorm.Rda", sep=""))


# Define data set part:
addProblem(regprenorm, id="dataload", dynamic=dataload, overwrite=TRUE)

# Define algorithm part:
addAlgorithm(regprenorm, id="normalizewholedataset", fun=normalizewholedataset, overwrite=TRUE)



# Design for data sets:
pars <- list(dataset=c("E-GEOD-30174", "E-GEOD-34465", "E-GEOD-39683", "E-GEOD-40744", "E-GEOD-46053", 
  "E-MTAB-57"))
dataload.design <- makeDesign("dataload", exhaustive=pars)

# Define algorithms:
pars <- list(method=c("RMA", "RMAglobalVSN"))
normalizewholedataset.design <- makeDesign("normalizewholedataset", exhaustive=pars)


# Define analysis:
addExperiments(regprenorm, prob.designs=dataload.design, algo.designs=normalizewholedataset.design, repls=1, skip.defined=TRUE)

# Submit the jobs:
submitJobs(regprenorm, ids=1:summarizeExperiments(regprenorm)$.count, wait=function(retries) 100, max.retries=10)

# Clear the workspace:
rm(list=ls()); gc()
