
# Loading and integration of the results:
#########################################


# If 'fromscratch' is set to TRUE the Rda-files "ResultsNSC.Rda" and "ResultsPLSLDA.Rda" containing
# the summarized results from the analyses with the package "BatchExperiments" are
# generated first using functions from "BatchExperiments".
# Can only be TRUE, when the analyses with "BatchExperiments" have been reproduced
# by the reader (time-consuming and computationally expensive).
# If set to FALSE the files "ResultsNSC.Rda" and "ResultsPLSLDA.Rda" are loaded.

fromscratch <- FALSE




# Load the results with classification method "Nearest Shrunken Centroids":


# Load and integrate the NSC results obtained on the huge memory server:

resultsall <- list()

for(i in 1:10) {
  load(paste("./CVIIMCodeData/NormalizationStudy/ResultsNormalization/resultsNSC", i, ".Rda", sep=""))
  resultsall <- c(resultsall, results)
}

datasets <- sapply(resultsall[-length(resultsall)], function(x) x$dataset) 
methods <- sapply(resultsall[-length(resultsall)], function(x) x$method) 
Ks <- sapply(resultsall[-length(resultsall)], function(x) x$K) 
splittings <- sapply(resultsall[-length(resultsall)], function(x) x$splitting) 
errornormfulls <- sapply(resultsall[-length(resultsall)], function(x) x$errornormfull) 
errornormaddons <- sapply(resultsall[-length(resultsall)], function(x) x$errornormaddon)
VSNfaileds <- sapply(resultsall[-length(resultsall)], function(x) x$VSNfailed)
VSNfaileds[sapply(VSNfaileds, is.null)] <- NA
VSNfaileds <- unlist(VSNfaileds)
names(VSNfaileds) <- NULL

resultsnormld <- data.frame(method=methods, dataset=datasets, K=Ks, splitting=splittings, VSNfailed=VSNfaileds, 
  errorfull=errornormfulls, erroraddon=errornormaddons)

resultsnormld$method <- factor(resultsnormld$method, levels=c("RMA", "RMAglobalVSN"))
resultsnormld$K <- factor(resultsnormld$K, levels=c(3, 5, 10))

resultsnormld <- resultsnormld[order(resultsnormld$method, resultsnormld$dataset, resultsnormld$K, resultsnormld$splitting),]


cattomet <- function(x)
  as.numeric(levels(x)[as.numeric(x)])

Kseq <- unique(resultsnormld$K)
niter <- max(resultsnormld$splitting)/max(cattomet(Kseq))
datasetun <- unique(resultsnormld$dataset)
methodun <- unique(resultsnormld$method)


ncrossvs <- length(datasetun)*niter*length(cattomet(Kseq))*length(methodun)
nfolds <- rep(rep(rep(cattomet(Kseq), each=niter), times=length(datasetun)), times=length(methodun))

resultsnormld$indcrossv <- rep(1:ncrossvs, times=nfolds)




# Load and integrate the NSC results obtained in the MPI environment:

if(fromscratch) {

library("BatchExperiments")

load("./CVIIMCodeData/NormalizationStudy/NormalizationNSC/currentregistryNSC.Rda")

resultdata <- reduceResultsList(reg)

methods <- sapply(getJobs(reg, findDone(reg)), function(x) x$algo.pars$method)
datasets <- sapply(getJobs(reg, findDone(reg)), function(x) x$prob.pars$dataset)
Kvalues <- sapply(getJobs(reg, findDone(reg)), function(x) x$prob.pars$K)
splittingvalues <- sapply(getJobs(reg, findDone(reg)), function(x) x$prob.pars$splitting)
errorfull <- sapply(resultdata, function(x) x$errornormfull)
erroraddon <- sapply(resultdata, function(x) x$errornormaddon)
VSNfailed <- sapply(resultdata, function(x) x$VSNfailed)
VSNfailed[sapply(VSNfailed, is.null)] <- NA
VSNfailed <- unlist(VSNfailed)
names(VSNfailed) <- NULL

resultsnorm <- data.frame(method=methods, dataset=datasets, K=Kvalues, splitting=splittingvalues, VSNfailed=VSNfailed, 
  errorfull=errorfull, erroraddon=erroraddon)

resultsnorm$method <- factor(resultsnorm$method, levels=c("RMA", "RMAglobalVSN"))
resultsnorm$dataset <- factor(resultsnorm$dataset, levels=c("E-GEOD-30174", "E-GEOD-34465", "E-GEOD-39683", "E-GEOD-40744", "E-GEOD-46053", "E-MTAB-57"))
resultsnorm$K <- factor(resultsnorm$K, levels=c(3, 5, 10))

resultsnorm <- resultsnorm[order(resultsnorm$method, resultsnorm$dataset, resultsnorm$K, resultsnorm$splitting),]

save(resultsnorm, file="./CVIIMCodeData/NormalizationStudy/ResultsNormalization/ResultsNSC.Rda")  
  
} else {
  load("./CVIIMCodeData/NormalizationStudy/ResultsNormalization/ResultsNSC.Rda")
}

cattomet <- function(x)
  as.numeric(levels(x)[as.numeric(x)])

Kseq <- unique(resultsnorm$K)
niter <- max(resultsnorm$splitting)/max(cattomet(Kseq))
datasetun <- unique(resultsnorm$dataset)
methodun <- unique(resultsnorm$method)

ncrossvs <- length(datasetun)*niter*length(cattomet(Kseq))*length(methodun)
nfolds <- rep(rep(rep(cattomet(Kseq), each=niter), times=length(datasetun)), times=length(methodun))

resultsnorm$indcrossv <- rep(1:ncrossvs, times=nfolds)
resultsnorm$indcrossv <- resultsnorm$indcrossv + max(resultsnormld$indcrossv)




# Combine the NSC results out of MPI environment and huge memory server:

resultsnorm <- rbind(resultsnormld, resultsnorm)






# Load the results with classification method "PLS followed by LDA":


# Load and integrate the PLS-LDA results obtained on the huge memory server:

resultsall <- list()

for(i in 1:10) {
  load(paste("./CVIIMCodeData/NormalizationStudy/ResultsNormalization/resultsPLSLDARMA", i, ".Rda", sep=""))
  results <- results[sapply(results, class)!="try-error"]
  results1 <- results
  load(paste("./CVIIMCodeData/NormalizationStudy/ResultsNormalization/resultsPLSLDARMAglobalVSN", i, ".Rda", sep=""))
  results <- results[sapply(results, class)!="try-error"]
  results <- c(results, results1)
  resultsall <- c(resultsall, results)
}

datasets <- sapply(resultsall, function(x) x$dataset) 
methods <- sapply(resultsall, function(x) x$method) 
Ks <- sapply(resultsall, function(x) x$K) 
splittings <- sapply(resultsall, function(x) x$splitting) 
errornormfulls <- sapply(resultsall, function(x) x$errornormfull) 
errornormaddons <- sapply(resultsall, function(x) x$errornormaddon)
VSNfaileds <- sapply(resultsall, function(x) x$VSNfailed)
VSNfaileds[sapply(VSNfaileds, is.null)] <- NA
VSNfaileds <- unlist(VSNfaileds)
names(VSNfaileds) <- NULL


resultsnormPLSLDAld <- data.frame(method=methods, dataset=datasets, K=Ks, splitting=splittings, VSNfailed=VSNfaileds, 
  errorfull=errornormfulls, erroraddon=errornormaddons)


resultsnormPLSLDAld$method <- factor(resultsnormPLSLDAld$method, levels=c("RMA", "RMAglobalVSN"))
resultsnormPLSLDAld$K <- factor(resultsnormPLSLDAld$K, levels=c(3, 5, 10))

resultsnormPLSLDAld <- resultsnormPLSLDAld[order(resultsnormPLSLDAld$method, resultsnormPLSLDAld$dataset, resultsnormPLSLDAld$K, resultsnormPLSLDAld$splitting),]


cattomet <- function(x)
  as.numeric(levels(x)[as.numeric(x)])

Kseq <- unique(resultsnormPLSLDAld$K)
niter <- max(resultsnormPLSLDAld$splitting)/max(cattomet(Kseq))
datasetun <- unique(resultsnormPLSLDAld$dataset)
methodun <- unique(resultsnormPLSLDAld$method)

ncrossvs <- length(datasetun)*niter*length(cattomet(Kseq))*length(methodun)
nfolds <- rep(rep(rep(cattomet(Kseq), each=niter), times=length(datasetun)), times=length(methodun))

resultsnormPLSLDAld$indcrossv <- rep(1:ncrossvs, times=nfolds)




# Load and integrate the PLS-LDA results obtained in the MPI environment:


if(fromscratch) {

library("BatchExperiments")

load("./CVIIMCodeData/NormalizationStudy/NormalizationPLSLDA/currentregistryPLSLDA.Rda")

doneids <- findDone(reg)
resultdata <- reduceResultsList(reg, doneids)

methods <- sapply(getJobs(reg, doneids), function(x) x$algo.pars$method)
datasets <- sapply(getJobs(reg, doneids), function(x) x$prob.pars$dataset)
Kvalues <- sapply(getJobs(reg, doneids), function(x) x$prob.pars$K)
splittingvalues <- sapply(getJobs(reg, doneids), function(x) x$prob.pars$splitting)
errorfull <- sapply(resultdata, function(x) x$errornormfull)
erroraddon <- sapply(resultdata, function(x) x$errornormaddon)
VSNfailed <- sapply(resultdata, function(x) x$VSNfailed)
VSNfailed[sapply(VSNfailed, is.null)] <- NA
VSNfailed <- unlist(VSNfailed)
names(VSNfailed) <- NULL

resultsnormPLSLDA <- data.frame(method=methods, dataset=datasets, K=Kvalues, splitting=splittingvalues, VSNfailed=VSNfailed, 
  errorfull=errorfull, erroraddon=erroraddon)

resultsnormPLSLDA$method <- factor(resultsnormPLSLDA$method, levels=c("RMA", "RMAglobalVSN"))
resultsnormPLSLDA$dataset <- factor(resultsnormPLSLDA$dataset, levels=c("E-GEOD-30174", "E-GEOD-34465", "E-GEOD-39683", "E-GEOD-40744", "E-GEOD-46053", "E-MTAB-57"))
resultsnormPLSLDA$K <- factor(resultsnormPLSLDA$K, levels=c(3, 5, 10))

resultsnormPLSLDA <- resultsnormPLSLDA[order(resultsnormPLSLDA$method, resultsnormPLSLDA$dataset, resultsnormPLSLDA$K, resultsnormPLSLDA$splitting),]

save(resultsnormPLSLDA, file="./CVIIMCodeData/NormalizationStudy/ResultsNormalization/ResultsPLSLDA.Rda")  

} else {
  load("./CVIIMCodeData/NormalizationStudy/ResultsNormalization/ResultsPLSLDA.Rda")
}


cattomet <- function(x)
  as.numeric(levels(x)[as.numeric(x)])

Kseq <- unique(resultsnormPLSLDA$K)
niter <- max(resultsnormPLSLDA$splitting)/max(cattomet(Kseq))
datasetun <- unique(resultsnormPLSLDA$dataset)
methodun <- unique(resultsnormPLSLDA$method)


ncrossvs <- length(datasetun)*niter*length(cattomet(Kseq))*length(methodun)
nfolds <- rep(rep(rep(cattomet(Kseq), each=niter), times=length(datasetun)), times=length(methodun))

resultsnormPLSLDA$indcrossv <- rep(1:ncrossvs, times=nfolds)
resultsnormPLSLDA$indcrossv <- resultsnormPLSLDA$indcrossv + max(resultsnormPLSLDAld$indcrossv)



# Combine the NSC results out of MPI environment and huge memory server:

resultsnormPLSLDA <- rbind(resultsnormPLSLDAld, resultsnormPLSLDA)








# Combine the NSC results and PLS-LDA results:

resultsnormPLSLDA$indcrossv <- resultsnormPLSLDA$indcrossv + max(resultsnorm$indcrossv)

results <- rbind(resultsnorm, resultsnormPLSLDA)
results$classifier <- rep(c("NSC", "PLSLDA"), 
  times=c(nrow(resultsnorm), nrow(resultsnormPLSLDA)))




  
  





# Plot: Normalization study - CVIIM_s,n,K-values versus e_full,K(s)-values and 
# zero-truncated differences of e_full,K(s)- and e_incompl,K(s)-values versus e_full,K(s)-values
################################################################################################


# CVIIM_s,n,K-values:

library("plyr")
resultsum <- ddply(results, .variables=c("method", "classifier", "dataset", "K", "indcrossv"), .fun=summarise, errorfull=mean(errorfull, na.rm=TRUE), erroraddon=mean(erroraddon, na.rm=TRUE))

resultsum2 <- ddply(resultsum, .variables=c("method", "classifier", "dataset", "K"), .fun=summarise, errorfull=mean(errorfull, na.rm=TRUE), erroraddon=mean(erroraddon, na.rm=TRUE))

# errorfull: mean error of repeated incomplete CV,
# erroraddon: mean error of repeated full CV
measure <- function(errorfull, erroraddon) {
  meas <- sapply(1 - errorfull/erroraddon, function(x) max(c(0, x)))
  meas[is.na(meas)] <- 0
  return(meas)
}

resultsum2$measure <- apply(resultsum2, 1, function(x) measure(as.numeric(x[5]), as.numeric(x[6])))



# Each data set in 'results' will be mapped to its corresponding ID in the data description
# table in the paper, because in the plot the data sets will be identifiable by their ID:

dataids <- data.frame(dataset=c("E-GEOD-10320", "E-GEOD-47552", 
  "E-GEOD-25639", "E-GEOD-29044", "E-MTAB-57", "E-GEOD-19722", 
  "E-MEXP-3756", "E-GEOD-34465", "E-GEOD-30174", "E-GEOD-39683", 
  "E-GEOD-40744", "E-GEOD-46053"), ID=1:12)


# Zero-truncated differences:
results2 <- resultsum2
results2$diffmeasure <- ifelse(results2$erroraddon - results2$errorfull>0, results2$erroraddon - results2$errorfull, 0)


# Calculate dataset-specific means of the e_{full, K}(s)-values, the measure-values and the zero-truncated differences:
library("plyr")
resultdatasets <- ddply(results2, .variables=c("dataset"), .fun=summarise, dataseterror=mean(erroraddon, na.rm=TRUE), datasetmeasure=mean(measure, na.rm=TRUE),
  datasetdiffmeasure=mean(diffmeasure, na.rm=TRUE))

# Map these values to the result data frame:
reorderind <- as.numeric(factor(results2$dataset, levels=resultdatasets$dataset))
results2$dataseterror <- resultdatasets$dataseterror[reorderind]
results2$datasetmeasure <- resultdatasets$datasetmeasure[reorderind]
results2$datasetdiffmeasure <- resultdatasets$datasetdiffmeasure[reorderind]

# Map the IDs to the corresponding data sets in the result data frame:
results2$dataID <- dataids$ID[as.numeric(factor(results2$dataset, levels=dataids$dataset))]

# For the lines connecting the individual values to their dataset-specific means we need
# to reshape the result data frame (because we use 'ggplot'):
library("reshape")
resultslong <- reshape(results2, varying=list(c("erroraddon", "dataseterror"), c("measure", "datasetmeasure"),
  c("diffmeasure", "datasetdiffmeasure")), v.names=c("erroraddonboth", "measureboth", "diffmeasureboth"),
  direction="long")

  
# Generate the plots:

library("ggplot2")
p1 <- ggplot(data=results2, aes(x=erroraddon, y=measure)) +
  geom_text(label=as.character(as.numeric(results2$dataID)), aes(colour=dataset), size=3) + 
  geom_point(shape=1, aes(colour=dataset), size=7) + 
  geom_line(data=resultslong, aes(x=erroraddonboth, y=measureboth, group=id, color=dataset)) + 
  geom_point(data=resultdatasets, aes(x=dataseterror, y=datasetmeasure), size=3) + 
  labs(x=expression(e["full, K"](bold(s))), y=expression(CVIIM[paste(bold(s), ",n,K", sep="")])) + 
  theme(legend.position="none")
p1

p2 <- ggplot(data=results2, aes(x=erroraddon, y=diffmeasure)) +
  geom_text(label=as.character(as.numeric(results2$dataID)), aes(colour=dataset), size=3) + 
  geom_point(shape=1, aes(colour=dataset), size=7) + 
  geom_line(data=resultslong, aes(x=erroraddonboth, y=diffmeasureboth, group=id, color=dataset)) + 
  geom_point(data=resultdatasets, aes(x=dataseterror, y=datasetdiffmeasure), size=3) + 
  labs(x=expression(e["full, K"](bold(s))), y=expression(paste("max( ", e["full, K"](bold(s)) ~~ - ~~ e["incompl, K"](bold(s)), ",   0 )", sep=""))) + 
  theme(legend.position="none")
p2

library("gridExtra")
grobframe <- arrangeGrob(p1, p2, ncol=1, nrow=2) 
grobframe  

ggsave(file="./CVIIMCodeData/Plots/Supplementary Figure 6.eps", plot=grobframe, width=9, height=13)








# Plot: Normalization study - Dataset-specific means of the CVIIM_s,n,K- and e_full,K(s)-values 
# plotted against the sample sizes of the datasets
################################################################################################

# Map the sample sizes of the datasets to the results:
load("./CVIIMCodeData/DataRetrieval/datainfoNormPCA.Rda")
datainfonorm <- datainfo[datainfo$study=="Normalization",]
datainfonorm$label <- factor(datainfonorm$label, levels=levels(results2$dataset))

results2$nsample <- sapply(results2$dataset, function(x) datainfonorm$nsample[datainfonorm$label==x])

# Take the means over the scenarios:
resultdatasets <- ddply(results2, .variables=c("dataset", "dataID", "nsample"), .fun=summarise, dataseterror=mean(erroraddon, na.rm=TRUE), datasetCVIIM=mean(measure, na.rm=TRUE))

# Generate the plots:

p1 <- ggplot(data=resultdatasets, aes(x=nsample, y=dataseterror)) +
  geom_text(label=as.character(as.numeric(resultdatasets$dataID)), size=4) + stat_smooth(size = 1, se = FALSE) + geom_hline(yintercept=0, linetype=2) + 
  labs(x="n", y=expression(paste("Mean over ", e["full, K"](bold(s)), "-values", sep="")))
p1

p2 <- ggplot(data=resultdatasets, aes(x=nsample, y=datasetCVIIM)) +
  geom_text(label=as.character(as.numeric(resultdatasets$dataID)), size=4) + stat_smooth(size = 1, se = FALSE) + geom_hline(yintercept=0, linetype=2) + 
  labs(x="n", y=expression(paste("Mean over ", CVIIM[paste(bold(s), ",n,K", sep="")], "-values", sep="")))
p2

library("gridExtra")
grobframe <- arrangeGrob(p2, p1, ncol=2, nrow=1) 
grobframe 

ggsave(file="./CVIIMCodeData/Plots/Supplementary Figure 10.eps", plot=grobframe, width=10, height=5)









# Calculation of the global CVIIM-estimates for the respective table in the main paper
######################################################################################

resultsum3 <- ddply(resultsum2, .variables=c("method", "classifier", "K"), .fun=summarise, errorfull=mean(errorfull, na.rm=TRUE), erroraddon=mean(erroraddon, na.rm=TRUE))

resultsum3$globalmeasure <- apply(resultsum3, 1, function(x) measure(as.numeric(x[4]), as.numeric(x[5])))

resultsum3

globalcviimvals <- resultsum3$globalmeasure
smallglobalcviim <- (globalcviimvals <= 0.00005) & (globalcviimvals != 0)

globalcviims <- format(round(globalcviimvals, 4), nsmall=4)
globalcviims[smallglobalcviim] <- "< 0.0001"

resultsum3$globalmeasureformatted <- globalcviims

library(reshape2)
globaltable <- dcast(resultsum3, method + classifier ~ K, value.var="globalmeasureformatted")
globaltable


# LaTeX-table:

tablelatex <- c("\\begin{table}",
"\\begin{tabular}{l | l | r | r | r }",
"Normalization & Classification & $K = 3$ & $K = 5$ & $K = 10$\\\\",
"method & method & & & \\\\",
"\\hline",
paste("RMA & NSC & ", paste(globaltable[1,3:5], collapse=" & "), "\\\\", sep=""), 
paste("& PLS-LDA & ", paste(globaltable[2,3:5], collapse=" & "), "\\\\", sep=""), 
"\\hline",
paste("RMAglobalVSN & NSC & ", paste(globaltable[3,3:5], collapse=" & "), "\\\\", sep=""), 
paste("& PLS-LDA & ", paste(globaltable[4,3:5], collapse=" & "), "\\\\", sep=""), 
"\\end{tabular}",
"\\caption{}", 
"\\label{t:normalizglobalcviim}",
"\\end{table}")

for(i in seq(along=tablelatex))
  cat(tablelatex[i], "\n")






# Plot: CVIIM_s,n,K-values from normalization study
####################################################

# The green diamonds are depicted with 'geom_polygon' for which reason we have
# to generate a data.frame describing the corners of the polygons:

sizex <- 0.15; sizey <- 0.0008

nplots <- length(unique(resultsum3$method))*length(unique(resultsum3$classifier))
xdiamonds <- rep(as.vector(sapply(1:3, function(x) x + c(-sizex, 0, sizex, 0))), times=nplots)
ydiamonds <- as.vector(sapply(1:nrow(resultsum3), function(x) resultsum3$globalmeasure[x] + c(0, sizey, 0, -sizey)))
Krep <- rep(rep(Kseq, each=4), times=nplots)
methodrep <- rep(resultsum3$method, each=4)
classifierrep <- rep(resultsum3$classifier, each=4)

datatemp <- data.frame(x=xdiamonds, y=ydiamonds, K=Krep, method=methodrep, classifier=classifierrep)


# Generate the plot:

p <- ggplot(data=resultsum2, aes(x=as.factor(as.numeric(as.factor(K))), y=measure)) +
  geom_boxplot() + geom_line(aes(x=as.numeric(as.factor(K)), y=measure, group=dataset), color="grey") + geom_boxplot(fill="transparent") + facet_wrap(~ method + classifier, nrow=2, ncol=2) + scale_x_discrete(breaks=1:3, labels=paste("K = ", Kseq, sep="")) + 
  labs(x="", y=expression(CVIIM[paste(bold(s), ",n,K", sep="")]))  + 
  geom_polygon(data=datatemp, aes(x,y, group=K), fill="green3")

p

ggsave(file="./CVIIMCodeData/Plots/Figure 2.eps", width=7, height=7)
