# Set a seed for reproducibility purposes:
set.seed(23851)

# Load the data set 'GSE33205':
load("./CVIIMCodeData/DataRetrieval/DataSetsPCA/GSE33205.Rda")

# Number of folds and number of repetitions:
K <- 3
niter <- 300

# Load the CMA-package used for Tuning:
library("CMA")


# Other than e.g. in the case of imputation, here there is no possibility of
# non-admissible splittings for CV.
# Therefore we can already generate the random splittings for all CV repetitions
# beforehand:
cvdatasets <- GenerateLearningsets(y = y, method = "CV", fold = K, niter = niter)


# Grid used for tuning the number mtry of variables randomly sampled as
# candidates at each split:
mtry.grid <- c(0.1, 1, 5, 10, 50, 100, 500)




# Incomplete CV:

# Matrix in which the fold errors from each incomplete CV repetition will be stored:
errortunerandfor11K3full <- matrix(nrow=K, ncol=niter)

# Perform the repeated incomplete cross validation:

for(i in 1:niter) {

# The 'cvdatasets'-object containing the training indices for ALL CV repititions
# has to be subsetted to correspond only to the i-th CV:
cvdatasets1 <- cvdatasets
cvdatasets1@iter <- K
cvdatasets1@learnmatrix <- cvdatasets@learnmatrix[(1 + (i-1)*K):(K + (i-1)*K),]

# Tune on the whole data set:
tunecv <- tune(X, y, classifier = rfCMA, grids = list(mtry = mtry.grid), nodesize = 1)

# Perform the i-th CV with the tuning parameter optimized on the whole data set:
crossval <- classification(X, y, learningsets = cvdatasets1, 
  classifier = rfCMA, mtry = mtry.grid[which.min(tunecv@tuneres[[1]])], nodesize = 1)
misclasscv <- evaluation(crossval, measure = "misclassification")

# Store the fold errors from the i-th CV:
errortunerandfor11K3full[,i] <- misclasscv@score

}



# Full CV:

# Tune on each training set anew:
tunenestedcv <- tune(X, y, learningsets = cvdatasets, classifier = rfCMA, 
  grids = list(mtry = mtry.grid), nodesize = 1)

# Perform the repeated full CV thereby passing the 'tuningresult'-object from above over to 
# the 'classification'-function:  
nestedcrossval <- classification(X, y, learningsets = cvdatasets, 
  classifier = rfCMA, tuneres = tunenestedcv, nodesize = 1)
misclassnestedcv <- evaluation(nestedcrossval, measure = "misclassification")

# Store the fold errors of the full CV in a matrix:
errortunerandfor11K3addon <- matrix(misclassnestedcv@score, nrow=K, ncol=niter)


# Save all calculated fold errors belonging to full and incomplete CV:
save(errortunerandfor11K3full, errortunerandfor11K3addon, 
  file="./CVIIMCodeData/OtherStepsAndVariableSelection/ResultsOtherStepsAndVariableSelection/tunerandfor1_1errorK3.Rda")

# Clear the workspace:   
rm(list=ls())
