# Set a seed for reproducibility purposes:
set.seed(1569413)

# Load the CMA-package used for classification and (incomplete) CV:
library("CMA")

# Load the data set 'ProstatecTranscr':
load("./CVIIMCodeData/DataRetrieval/DataSetsPCA/ProstatecTranscr.Rda")
#y is already there after loading

# Number of variables to select:
nvar <- 5

# Number of folds and number of repetitions:
K <- 3
niter <- 300

# Generate the random splittings for all CV repetitions:
cvdatasets <- GenerateLearningsets(y = y, method = "CV", fold = K, niter=niter)



# Full CV:

# Perform the full CV, selecting the variables with the smallest p-values in each iteration on the training sets
# only and using Linear Discriminant Analysis as classification method:
nestedcrossval <- classification(X, y, learningsets = cvdatasets, 
  classifier = ldaCMA, nbgene = nvar, genesellist = list(method = "t.test"))

# Extract the fold errors and store them in a matrix:  
errornvar5K3addon <- matrix(nrow=K, ncol=niter, data=evaluation(nestedcrossval, measure = "misclassification")@score)



# Incomplete CV:

# Perform the variable selection on the whole data set: 
varinds <- GeneSelection(X, y, method = "t.test")@rankings[[1]][1, 1:nvar]
Xsub <- X[, varinds]

# Perform the CV after variable selection (using Linear Discriminant Analysis as classification method):
nestedcrossval <- classification(Xsub, y, learningsets = cvdatasets, 
  classifier = ldaCMA)

# Extract the fold errors and store them in a matrix: 
errornvar5K3full <- matrix(nrow=K, ncol=niter, data=evaluation(nestedcrossval, measure = "misclassification")@score)


# Save all calculated fold errors belonging to full and incomplete CV:
save(errornvar5K3addon, errornvar5K3full, file="./CVIIMCodeData/OtherStepsAndVariableSelection/ResultsOtherStepsAndVariableSelection/varselerrornvar5K3.Rda")

# Clear the workspace:
rm(list=ls())