# Set a seed for reproducibility purposes:
set.seed(6341113)

# Load the CMA-package used for classification and (incomplete) CV:
library("CMA")

# Load the data set 'ProstatecTranscr':
load("./CVIIMCodeData/DataRetrieval/DataSetsPCA/ProstatecTranscr.Rda")
#y is already there after loading

# Number of variables to select is equal to the largest integer less or equal to ncol(X)/2:
nvar <- floor(ncol(X)/2)

# Number of folds and number of repetitions:
K <- 3
niter <- 300

# Generate the random splittings for all CV repetitions:
cvdatasets <- GenerateLearningsets(y = y, method = "CV", fold = K, niter=niter)



# Full CV:

# Perform the full CV, selecting the variables with the smaller p-values in each iteration on the training sets
# only and using Diagonal Linear Discriminant Analysis by setting the shrinkage parameter in Nearest Shrunken
# Centroids to zero:
nestedcrossval <- classification(X, y, learningsets = cvdatasets, 
  classifier = scdaCMA, nbgene = nvar, genesellist = list(method = "t.test"), delta = 0)
  
# Extract the fold errors and store them in a matrix:  
errornvarbigK3addon <- matrix(nrow=K, ncol=niter, data=evaluation(nestedcrossval, measure = "misclassification")@score)



# Incomplete CV:

# Perform the variable selection on the whole data set: 
varinds <- GeneSelection(X, y, method = "t.test")@rankings[[1]][1, 1:nvar]
Xsub <- X[, varinds]

# Perform the CV after variable selection (using Diagonal Linear Discriminant Analysis 
# as classification method):
nestedcrossval <- classification(Xsub, y, learningsets = cvdatasets, 
  classifier = scdaCMA, delta=0)

# Extract the fold errors and store them in a matrix: 
errornvarbigK3full <- matrix(nrow=K, ncol=niter, data=evaluation(nestedcrossval, measure = "misclassification")@score)


# Save all calculated fold errors belonging to full and incomplete CV:
save(errornvarbigK3addon, errornvarbigK3full, file="./CVIIMCodeData/OtherStepsAndVariableSelection/ResultsOtherStepsAndVariableSelection/varselerrornvarbigK3.Rda")

# Clear the workspace:
rm(list=ls())
