

# Variable filtering by variance:
######################################


# Read in fold errors of repeated full and incomplete CV:
########################################################

workspacesafe <- getwd()
setwd("./CVIIMCodeData/OtherStepsAndVariableSelection/ResultsOtherStepsAndVariableSelection/")

load("varfiltererrorK3.Rda") 
load("varfiltererrorK5.Rda") 
load("varfiltererrorK10.Rda") 

load("varfiltererror2K3.Rda") 
load("varfiltererror2K5.Rda") 
load("varfiltererror2K10.Rda") 

load("varfiltererror3K3.Rda") 
load("varfiltererror3K5.Rda") 
load("varfiltererror3K10.Rda") 

load("varfiltererror4K3.Rda") 
load("varfiltererror4K5.Rda") 
load("varfiltererror4K10.Rda") 

setwd(workspacesafe)





# CVIIM-related functions:
###########################

# Function to compute the CVIIM_s,n,K,b-values:

# errorfull: errors of incomplete CV,
# erroraddon: errors of full CV
measureb <- function(errorfull, erroraddon) {
  meas <- 1 - errorfull/erroraddon
  return(meas)
}


# Function to compute the CVIIM_s,n,K-values:

# errorfull: mean error of repeated incomplete CV,
# erroraddon: mean error of repeated full CV
measure <- function(errorfull, erroraddon) {
  meas <- sapply(1 - errorfull/erroraddon, function(x) max(c(0, x)))
  meas[is.na(meas)] <- 0
  return(meas)
}


# Function to compute CVIIM_s,n,K together with
# 25%- and 75%-quartile of the CVIIM_s,n,K,b-values:

# errorfull: K x B matrix of fold errors of repeated incomplete CV,
# erroraddon: K x B matrix of fold errors of repeated full CV
measurewithquart <- function(errorfull, erroraddon) {

  measurei <- mapply(function(x, y) measureb(mean(x), mean(y)), data.frame(errorfull), data.frame(erroraddon))
  quartiles <- quantile(measurei, c(0.25, 0.75))
  measureval <- measure(mean(errorfull), mean(erroraddon))
  return(list(cvim=measureval, quartiles=quartiles))

}



# Figure on variable filtering in paper:
#########################################

# The results are stored in a dataset for usage in 'ggplot':

cviimwithquartiles <- list(measurewithquart(errorvarfilterK3full, errorvarfilterK3addon),
measurewithquart(errorvarfilterK5full, errorvarfilterK5addon),
measurewithquart(errorvarfilterK10full, errorvarfilterK10addon),

measurewithquart(errorvarfilter3K3full, errorvarfilter3K3addon),
measurewithquart(errorvarfilter3K5full, errorvarfilter3K5addon),
measurewithquart(errorvarfilter3K10full, errorvarfilter3K10addon),

measurewithquart(errorvarfilter4K3full, errorvarfilter4K3addon),
measurewithquart(errorvarfilter4K5full, errorvarfilter4K5addon),
measurewithquart(errorvarfilter4K10full, errorvarfilter4K10addon),

measurewithquart(errorvarfilter2K3full, errorvarfilter2K3addon),
measurewithquart(errorvarfilter2K5full, errorvarfilter2K5addon),
measurewithquart(errorvarfilter2K10full, errorvarfilter2K10addon))



# In Additional file 2 there is a plot of the dataset-specific means of the 
# CVIIM_s,n,K- and e_full,K(s)-values plotted against the sample sizes of the datasets.
# This plot includes all other steps than normalization and PCA (for the latter two
# there are own plots).
# Hereto we first make individual plots for each step and at the end of the script
# combine them using 'arrangeGrob'.


# e_full,K(s)- and e_incompl,K(s)-values:

errorsaddon <- c(mean(errorvarfilterK3addon),
mean(errorvarfilterK5addon),
mean(errorvarfilterK10addon),

mean(errorvarfilter3K3addon),
mean(errorvarfilter3K5addon),
mean(errorvarfilter3K10addon),

mean(errorvarfilter4K3addon),
mean(errorvarfilter4K5addon),
mean(errorvarfilter4K10addon),

mean(errorvarfilter2K3addon),
mean(errorvarfilter2K5addon),
mean(errorvarfilter2K10addon))


errorsfull <- c(mean(errorvarfilterK3full),
mean(errorvarfilterK5full),
mean(errorvarfilterK10full),

mean(errorvarfilter3K3full),
mean(errorvarfilter3K5full),
mean(errorvarfilter3K10full),

mean(errorvarfilter4K3full),
mean(errorvarfilter4K5full),
mean(errorvarfilter4K10full),

mean(errorvarfilter2K3full),
mean(errorvarfilter2K5full),
mean(errorvarfilter2K10full))



# Data.frame tailored for plot problem:

labsnvars <- c("psel = p/2 − filtering by variance")

results <- data.frame(nvars=factor(rep(labsnvars, each=3*4), levels=labsnvars),
dataset=rep(rep(c("ProstatecTranscr", "GSE33205", "GSE20189", "GSE37356"), each=3), times=length(labsnvars)),
K=rep(c(3,5,10), times=length(cviimwithquartiles)/3),
CVIIM=sapply(cviimwithquartiles, function(x) x$cvim),
CVIIM25=sapply(cviimwithquartiles, function(x) x$quartiles[1]),
CVIIM75=sapply(cviimwithquartiles, function(x) x$quartiles[2]), errorsaddon=errorsaddon,
errorsfull=errorsfull)

results$dataID <- NA
results$dataID[results$dataset=="ProstatecTranscr"] <- 14
results$dataID[results$dataset=="GSE33205"] <- 25
results$dataID[results$dataset=="GSE20189"] <- 15
results$dataID[results$dataset=="GSE37356"] <- 30

spacingbars1 <- 0.14
spacingnumbers1 <- 0.05

results$x <- as.numeric(as.factor(results$K)) + rep(rep(c(-1.5, -0.5, 0.5, 1.5), each=3), times=length(labsnvars))*spacingbars1 - spacingnumbers1


library("ggplot2")

p <- ggplot(data=results, aes(x=factor(K), y=CVIIM)) + 
  geom_text(aes(x=x, label=as.character(results$dataID), colour=dataset), size=3) +
  geom_line(aes(x=x, y=CVIIM, color=dataset)) +
  theme(legend.position="none") + 
  geom_errorbar(aes(x=x+spacingnumbers1, ymin=CVIIM25, ymax=CVIIM75, colour=dataset)) +
  geom_hline(yintercept=0, linetype=2) + 
  labs(x="", y=expression(CVIIM[paste(bold(s), ",n,K", sep="")])) + 
  scale_x_discrete(breaks=1:3, labels=paste("K =", c(3,5,10)), expand=c(0.07,-2))
p

ggsave(file="./CVIIMCodeData/Plots/Supplementary Figure 8.eps", width=6, height=4)



# Get sample sizes of data sets:

datanames <- c("ProstatecTranscr", "GSE33205", "GSE20189", "GSE37356")

if(file.exists("./CVIIMCodeData/DataRetrieval/DataSetsPCA/ProstatecTranscr.Rda") &
  file.exists("./CVIIMCodeData/DataRetrieval/DataSetsPCA/GSE33205.Rda") & 
  file.exists("./CVIIMCodeData/DataRetrieval/DataSetsPCA/GSE20189.Rda") & 
  file.exists("./CVIIMCodeData/DataRetrieval/DataSetsPCA/GSE37356.Rda")) {
  
nsamples <- 0
load("./CVIIMCodeData/DataRetrieval/DataSetsPCA/ProstatecTranscr.Rda")
nsamples[1] <- length(y)
load("./CVIIMCodeData/DataRetrieval/DataSetsPCA/GSE33205.Rda")
nsamples[2] <- length(y)
load("./CVIIMCodeData/DataRetrieval/DataSetsPCA/GSE20189.Rda")
nsamples[3] <- length(y)
load("./CVIIMCodeData/DataRetrieval/DataSetsPCA/GSE37356.Rda")
nsamples[4] <- length(y)

} else {
  nsamples <- c(102, 50, 100, 36)
}

results$nsample <- sapply(results$dataset, function(x) nsamples[datanames==x]) 
results$diffmeasure <- ifelse(results$errorsaddon - results$errorsfull>0, results$errorsaddon - results$errorsfull, 0)



# Sub-Plot: average CVIIM_s,n,K- and e_full,K(s)-values against sample sizes:

library("plyr")
resultsum2 <- ddply(results, .variables=c("dataset", "dataID", "nsample"), .fun=summarise, dataseterror=mean(errorsaddon, na.rm=TRUE), datasetCVIIM=mean(CVIIM, na.rm=TRUE))

lwdths <- 1

p1 <- ggplot(data=resultsum2, aes(x=nsample, y=dataseterror)) +
  geom_text(label=as.character(as.numeric(resultsum2$dataID)), size=4) + geom_hline(yintercept=0, linetype=2) + 
  labs(x="n", y="", title="Est. error")
p1

p2 <- ggplot(data=resultsum2, aes(x=nsample, y=datasetCVIIM)) +
  geom_text(label=as.character(as.numeric(resultsum2$dataID)), size=4) + geom_hline(yintercept=0, linetype=2) + 
  labs(x="n", y="", title="CVIIM")
p2

library("gridExtra")
grobframe1 <- arrangeGrob(p2, p1, ncol=2, nrow=1, main=textGrob("Variable filtering by variance", gp=gpar(fontsize=20)))
grobframe1 




# Calculation of the global CVIIM-estimates
################################################

measure(mean(c(mean(errorvarfilterK3full), mean(errorvarfilter2K3full), mean(errorvarfilter3K3full), mean(errorvarfilter4K3full))), mean(c(mean(errorvarfilterK3addon), mean(errorvarfilter2K3addon), mean(errorvarfilter3K3addon), mean(errorvarfilter4K3addon)))) 
measure(mean(c(mean(errorvarfilterK5full), mean(errorvarfilter2K5full), mean(errorvarfilter3K5full), mean(errorvarfilter4K5full))), mean(c(mean(errorvarfilterK5addon), mean(errorvarfilter2K5addon), mean(errorvarfilter3K5addon), mean(errorvarfilter4K5addon)))) 
measure(mean(c(mean(errorvarfilterK10full), mean(errorvarfilter2K10full), mean(errorvarfilter3K10full), mean(errorvarfilter4K10full))), mean(c(mean(errorvarfilterK10addon), mean(errorvarfilter2K10addon), mean(errorvarfilter3K10addon), mean(errorvarfilter4K10addon)))) 

















#                  Imputation:
####################################################



# Read in fold errors of repeated full and incomplete CV:
########################################################

workspacesafe <- getwd()
setwd("./CVIIMCodeData/OtherStepsAndVariableSelection/ResultsOtherStepsAndVariableSelection/")

load("impute1_1errorK3.Rda")
load("impute1_1errorK5.Rda")
load("impute1_1errorK10.Rda")

load("impute2_1errorK3.Rda")
load("impute2_1errorK5.Rda")
load("impute2_1errorK10.Rda")

load("impute3_1errorK3.Rda")
load("impute3_1errorK5.Rda")
load("impute3_1errorK10.Rda")

load("impute4_1errorK3.Rda")
load("impute4_1errorK5.Rda")
load("impute4_1errorK10.Rda")

load("impute5_1errorK3.Rda")
load("impute5_1errorK5.Rda")
load("impute5_1errorK10.Rda")

load("impute6_1errorK3.Rda")
load("impute6_1errorK5.Rda")
load("impute6_1errorK10.Rda")

setwd(workspacesafe)




# CVIIM-related functions:
###########################

# Function to compute the CVIIM_s,n,K,b-values:

# errorfull: errors of incomplete CV,
# erroraddon: errors of full CV
measureb <- function(errorfull, erroraddon) {
  meas <- 1 - errorfull/erroraddon
  return(meas)
}


# Function to compute the CVIIM_s,n,K-values:

# errorfull: mean error of repeated incomplete CV,
# erroraddon: mean error of repeated full CV
measure <- function(errorfull, erroraddon) {
  meas <- sapply(1 - errorfull/erroraddon, function(x) max(c(0, x)))
  meas[is.na(meas)] <- 0
  return(meas)
}


# Function to compute CVIIM_s,n,K together with
# 25%- and 75%-quartile of the CVIIM_s,n,K,b-values:

# errorfull: K x B matrix of fold errors of repeated incomplete CV,
# erroraddon: K x B matrix of fold errors of repeated full CV
measurewithquart <- function(errorfull, erroraddon) {

  measurei <- mapply(function(x, y) measureb(mean(x), mean(y)), data.frame(errorfull), data.frame(erroraddon))
  quartiles <- quantile(measurei, c(0.25, 0.75))
  measureval <- measure(mean(errorfull), mean(erroraddon))
  return(list(cvim=measureval, quartiles=quartiles))

}



# Figure on imputation in paper:
#########################################

# The results are stored in a dataset for usage in 'ggplot':

cviimwithquartiles <- list(measurewithquart(errorimpute2K3full, errorimpute2K3addon),
measurewithquart(errorimpute2K5full, errorimpute2K5addon),
measurewithquart(errorimpute2K10full, errorimpute2K10addon),

measurewithquart(errorimpute3K3full, errorimpute3K3addon),
measurewithquart(errorimpute3K5full, errorimpute3K5addon),
measurewithquart(errorimpute3K10full, errorimpute3K10addon),

measurewithquart(errorimpute4K3full, errorimpute4K3addon),
measurewithquart(errorimpute4K5full, errorimpute4K5addon),
measurewithquart(errorimpute4K10full, errorimpute4K10addon),

measurewithquart(errorimpute5K3full, errorimpute5K3addon),
measurewithquart(errorimpute5K5full, errorimpute5K5addon),
measurewithquart(errorimpute5K10full, errorimpute5K10addon),

measurewithquart(errorimpute6K3full, errorimpute6K3addon),
measurewithquart(errorimpute6K5full, errorimpute6K5addon),
measurewithquart(errorimpute6K10full, errorimpute6K10addon),

measurewithquart(errorimpute1K3full, errorimpute1K3addon),
measurewithquart(errorimpute1K5full, errorimpute1K5addon),
measurewithquart(errorimpute1K10full, errorimpute1K10addon))




# e_full,K(s)- and e_incompl,K(s)-value:

errorsaddon <- c(mean(errorimpute2K3addon), 
mean(errorimpute2K5addon), 
mean(errorimpute2K10addon), 
mean(errorimpute3K3addon), 
mean(errorimpute3K5addon), 
mean(errorimpute3K10addon), 
mean(errorimpute4K3addon), 
mean(errorimpute4K5addon), 
mean(errorimpute4K10addon), 
mean(errorimpute5K3addon), 
mean(errorimpute5K5addon), 
mean(errorimpute5K10addon), 
mean(errorimpute6K3addon), 
mean(errorimpute6K5addon), 
mean(errorimpute6K10addon), 
mean(errorimpute1K3addon), 
mean(errorimpute1K5addon), 
mean(errorimpute1K10addon))


errorsfull <- c(mean(errorimpute2K3full), 
mean(errorimpute2K5full), 
mean(errorimpute2K10full), 
mean(errorimpute3K3full), 
mean(errorimpute3K5full), 
mean(errorimpute3K10full), 
mean(errorimpute4K3full), 
mean(errorimpute4K5full), 
mean(errorimpute4K10full), 
mean(errorimpute5K3full), 
mean(errorimpute5K5full), 
mean(errorimpute5K10full), 
mean(errorimpute6K3full), 
mean(errorimpute6K5full), 
mean(errorimpute6K10full), 
mean(errorimpute1K3full), 
mean(errorimpute1K5full), 
mean(errorimpute1K10full))



# Data.frame tailored for plot problem:

labsnvars <- c("knnimputation")
datasets <- c("GenitInfCoww0", "GenitInfCoww1", "GenitInfCoww2", "GenitInfCoww3", "GenitInfCoww4", "ProstatecMethyl")

results <- data.frame(method=factor(rep(labsnvars, each=3*length(datasets)), levels=labsnvars),
dataset=rep(rep(datasets, each=3), times=length(labsnvars)),
K=rep(c(3,5,10), times=length(cviimwithquartiles)/3),
CVIIM=sapply(cviimwithquartiles, function(x) x$cvim),
CVIIM25=sapply(cviimwithquartiles, function(x) x$quartiles[1]),
CVIIM75=sapply(cviimwithquartiles, function(x) x$quartiles[2]),
errorsaddon=errorsaddon,
errorsfull=errorsfull)

results$dataID <- NA
results$dataID[results$dataset=="GenitInfCoww0"] <- 33
results$dataID[results$dataset=="GenitInfCoww1"] <- 34
results$dataID[results$dataset=="GenitInfCoww2"] <- 35
results$dataID[results$dataset=="GenitInfCoww3"] <- 36
results$dataID[results$dataset=="GenitInfCoww4"] <- 37
results$dataID[results$dataset=="ProstatecMethyl"] <- 38


# The results corresponding to the 'GenitInfCow'-datasets are depicted in a common colours:
results$color <- factor(as.numeric(results$dataset=="ProstatecMethyl")+1)

spacingbars1 <- 0.20
spacingnumbers1 <- 0.05

results$x <- as.numeric(as.factor(results$K)) + rep(rep(seq(-1.5, 1.5, length=length(datasets)), each=3), times=length(labsnvars))*spacingbars1 - spacingnumbers1


library("ggplot2")

p <- ggplot(data=results, aes(x=factor(K), y=CVIIM)) + 
  geom_text(aes(x=x, label=as.character(results$dataID), colour=color), size=3) +
  geom_line(aes(x=x, y=CVIIM, group=dataset, color=color)) +
  theme(legend.position="none") + 
  geom_errorbar(aes(x=x+spacingnumbers1, ymin=CVIIM25, ymax=CVIIM75, colour=color)) +
  geom_hline(yintercept=0, linetype=2) + 
  labs(x="", y=expression(CVIIM[paste(bold(s), ",n,K", sep="")])) + 
  scale_x_discrete(breaks=1:3, labels=paste("K =", c(3,5,10)), expand=c(0.05,-2))
p

ggsave(file="./CVIIMCodeData/Plots/Supplementary Figure 9.eps", width=6, height=4)



# Get sample sizes of data sets:

datanames <- c("GenitInfCoww0", "GenitInfCoww1", "GenitInfCoww2", "GenitInfCoww3",
  "GenitInfCoww4", "ProstatecMethyl")

nsamples <- 0

for(i in 1:5) {

load("./CVIIMCodeData/DataSets_GenitInfCow_and_ProstatecMethyl/GenitInfCow.Rda")

GenitInfCow <- GenitInfCow[GenitInfCow$Wo==i-1,]
GenitInfCow$Kuh <- NULL
GenitInfCow$Wo <- NULL
rownames(GenitInfCow) <- NULL

GenitInfCow <- GenitInfCow[,apply(GenitInfCow, 2, function(x) sum(!is.na(x)))>14]

X <- as.matrix(GenitInfCow[,-1])
y <- GenitInfCow$y

nsamples[i] <- length(y)

}

load("./CVIIMCodeData/DataSets_GenitInfCow_and_ProstatecMethyl/ProstatecMethyl.Rda")
nsamples[6] <- length(y)


results$nsample <- sapply(results$dataset, function(x) nsamples[datanames==x]) 
results$diffmeasure <- ifelse(results$errorsaddon - results$errorsfull>0, results$errorsaddon - results$errorsfull, 0)



# Sub-Plot: average CVIIM_s,n,K- and e_full,K(s)-values against sample sizes:

resultsum2 <- ddply(results, .variables=c("dataset", "dataID", "nsample"), .fun=summarise, dataseterror=mean(errorsaddon, na.rm=TRUE), datasetCVIIM=mean(CVIIM, na.rm=TRUE),
  datasetdiffmeasure=mean(diffmeasure, na.rm=TRUE))
  
lwdths <- 1

p1 <- ggplot(data=resultsum2, aes(x=nsample, y=dataseterror)) +
  geom_text(label=as.character(as.numeric(resultsum2$dataID)), size=4) + geom_hline(yintercept=0, linetype=2) + 
  labs(x="n", y="", title="Est. error")
p1

p2 <- ggplot(data=resultsum2, aes(x=nsample, y=datasetCVIIM)) +
  geom_text(label=as.character(as.numeric(resultsum2$dataID)), size=4) + geom_hline(yintercept=0, linetype=2) + 
  labs(x="n", y="", title="CVIIM")
p2

library("gridExtra")
grobframe2 <- arrangeGrob(p2, p1, ncol=2, nrow=1, main=textGrob("Imputation of missing values", gp=gpar(fontsize=20)))
grobframe2 





# Calculation of the global CVIIM-estimates (Note the aberrant calculation
# due to the dependency of the cow datasets, described in the main paper):
#############################################################################

measure(mean(c(mean(errorimpute1K3full), mean(c(mean(errorimpute2K3full), mean(errorimpute3K3full), mean(errorimpute4K3full), mean(errorimpute5K3full), mean(errorimpute6K3full))))), mean(c(mean(errorimpute1K3addon), mean(c(mean(errorimpute2K3addon), mean(errorimpute3K3addon), mean(errorimpute4K3addon), mean(errorimpute5K3addon), mean(errorimpute6K3addon))))))
measure(mean(c(mean(errorimpute1K5full), mean(c(mean(errorimpute2K5full), mean(errorimpute3K5full), mean(errorimpute4K5full), mean(errorimpute5K5full), mean(errorimpute6K5full))))), mean(c(mean(errorimpute1K5addon), mean(c(mean(errorimpute2K5addon), mean(errorimpute3K5addon), mean(errorimpute4K5addon), mean(errorimpute5K5addon), mean(errorimpute6K5addon))))))
measure(mean(c(mean(errorimpute1K10full), mean(c(mean(errorimpute2K10full), mean(errorimpute3K10full), mean(errorimpute4K10full), mean(errorimpute5K10full), mean(errorimpute6K10full))))), mean(c(mean(errorimpute1K10addon), mean(c(mean(errorimpute2K10addon), mean(errorimpute3K10addon), mean(errorimpute4K10addon), mean(errorimpute5K10addon), mean(errorimpute6K10addon))))))






















# Optimization of tuning parameters:
######################################


# Read in fold errors of repeated full and incomplete CV:
########################################################

workspacesafe <- getwd()
setwd("./CVIIMCodeData/OtherStepsAndVariableSelection/ResultsOtherStepsAndVariableSelection/")

# Relevant Rda-files:
tuneerrors <- list.files()[intersect(intersect(grep("tune", list.files()), grep("\\.Rda", 
  list.files())), grep("error", list.files()))]

# Read in all relevant Rda-files:
for(i in seq(along=tuneerrors))
  load(tuneerrors[i])


# Combine results:

errortunesvm11K3addon <- cbind(errortunesvm11K3addon, errortunesvm12K3addon, errortunesvm13K3addon)
errortunesvm11K3full <- cbind(errortunesvm11K3full, errortunesvm12K3full, errortunesvm13K3full)

errortunesvm11K5addon <- cbind(errortunesvm11K5addon, errortunesvm12K5addon, errortunesvm13K5addon)
errortunesvm11K5full <- cbind(errortunesvm11K5full, errortunesvm12K5full, errortunesvm13K5full)

errortunesvm11K10addon <- cbind(errortunesvm11K10addon, errortunesvm12K10addon, errortunesvm13K10addon, 
  errortunesvm14K10addon, errortunesvm15K10addon, errortunesvm16K10addon)
errortunesvm11K10full <- cbind(errortunesvm11K10full, errortunesvm12K10full, errortunesvm13K10full, 
  errortunesvm14K10full, errortunesvm15K10full, errortunesvm16K10full)



errortunerandfor11K5addon <- cbind(errortunerandfor11K5addon, errortunerandfor12K5addon)
errortunerandfor11K5full <- cbind(errortunerandfor11K5full, errortunerandfor12K5full)

errortunerandfor11K10addon <- cbind(errortunerandfor11K10addon, errortunerandfor12K10addon,
  errortunerandfor13K10addon, errortunerandfor14K10addon)
errortunerandfor11K10full <- cbind(errortunerandfor11K10full, errortunerandfor12K10full,
  errortunerandfor13K10full, errortunerandfor14K10full)



errortuneboost11K3addon <- cbind(errortuneboost11K3addon, errortuneboost12K3addon)
errortuneboost11K3full <- cbind(errortuneboost11K3full, errortuneboost12K3full)

errortuneboost11K5addon <- cbind(errortuneboost11K5addon, errortuneboost12K5addon, errortuneboost13K5addon,
  errortuneboost14K5addon)
errortuneboost11K5full <- cbind(errortuneboost11K5full, errortuneboost12K5full, errortuneboost13K5full,
  errortuneboost14K5full)

errortuneboost11K10addon <- cbind(errortuneboost11K10addon, errortuneboost12K10addon, errortuneboost13K10addon,
  errortuneboost14K10addon, errortuneboost15K10addon, errortuneboost16K10addon, errortuneboost17K10addon,
  errortuneboost18K10addon, errortuneboost19K10addon, errortuneboost110K10addon)
errortuneboost11K10full <- cbind(errortuneboost11K10full, errortuneboost12K10full, errortuneboost13K10full,
  errortuneboost14K10full, errortuneboost15K10full, errortuneboost16K10full, errortuneboost17K10full,
  errortuneboost18K10full, errortuneboost19K10full, errortuneboost110K10full)



errortunesvm21K3addon <- cbind(errortunesvm21K3addon, errortunesvm22K3addon, errortunesvm23K3addon)
errortunesvm21K3full <- cbind(errortunesvm21K3full, errortunesvm22K3full, errortunesvm23K3full)

errortunesvm21K5addon <- cbind(errortunesvm21K5addon, errortunesvm22K5addon, errortunesvm23K5addon,
  errortunesvm24K5addon, errortunesvm25K5addon)
errortunesvm21K5full <- cbind(errortunesvm21K5full, errortunesvm22K5full, errortunesvm23K5full,
  errortunesvm24K5full, errortunesvm25K5full)

errortunesvm21K10addon <- cbind(errortunesvm21K10addon, errortunesvm22K10addon, errortunesvm23K10addon, 
  errortunesvm24K10addon, errortunesvm25K10addon, errortunesvm26K10addon)
errortunesvm21K10full <- cbind(errortunesvm21K10full, errortunesvm22K10full, errortunesvm23K10full, 
  errortunesvm24K10full, errortunesvm25K10full, errortunesvm26K10full)



errortunerandfor21K3addon <- cbind(errortunerandfor21K3addon, errortunerandfor22K3addon,
  errortunerandfor23K3addon)
errortunerandfor21K3full <- cbind(errortunerandfor21K3full, errortunerandfor22K3full,
  errortunerandfor23K3full)

errortunerandfor21K5addon <- cbind(errortunerandfor21K5addon, errortunerandfor22K5addon,
  errortunerandfor23K5addon, errortunerandfor24K5addon, 
  errortunerandfor25K5addon, errortunerandfor26K5addon)
errortunerandfor21K5full <- cbind(errortunerandfor21K5full, errortunerandfor22K5full,
  errortunerandfor23K5full, errortunerandfor24K5full, 
  errortunerandfor25K5full, errortunerandfor26K5full)

errortunerandfor21K10addon <- cbind(errortunerandfor21K10addon, errortunerandfor22K10addon,
  errortunerandfor23K10addon, errortunerandfor24K10addon, 
  errortunerandfor25K10addon, errortunerandfor26K10addon,
  errortunerandfor27K10addon, errortunerandfor28K10addon,
  errortunerandfor29K10addon, errortunerandfor210K10addon, 
  errortunerandfor211K10addon, errortunerandfor212K10addon)
errortunerandfor21K10full <- cbind(errortunerandfor21K10full, errortunerandfor22K10full,
  errortunerandfor23K10full, errortunerandfor24K10full, 
  errortunerandfor25K10full, errortunerandfor26K10full,
  errortunerandfor27K10full, errortunerandfor28K10full,
  errortunerandfor29K10full, errortunerandfor210K10full, 
  errortunerandfor211K10full, errortunerandfor212K10full)



errortuneboost21K3addon <- cbind(errortuneboost21K3addon, errortuneboost22K3addon)
errortuneboost21K3full <- cbind(errortuneboost21K3full, errortuneboost22K3full)

errortuneboost21K5addon <- cbind(errortuneboost21K5addon, errortuneboost22K5addon, errortuneboost23K5addon,
  errortuneboost24K5addon)
errortuneboost21K5full <- cbind(errortuneboost21K5full, errortuneboost22K5full, errortuneboost23K5full,
  errortuneboost24K5full)

errortuneboost21K10addon <- cbind(errortuneboost21K10addon, errortuneboost22K10addon, errortuneboost23K10addon,
  errortuneboost24K10addon, errortuneboost25K10addon, errortuneboost26K10addon, errortuneboost27K10addon,
  errortuneboost28K10addon, errortuneboost29K10addon, errortuneboost210K10addon)
errortuneboost21K10full <- cbind(errortuneboost21K10full, errortuneboost22K10full, errortuneboost23K10full,
  errortuneboost24K10full, errortuneboost25K10full, errortuneboost26K10full, errortuneboost27K10full,
  errortuneboost28K10full, errortuneboost29K10full, errortuneboost210K10full)



errortunelasso21K3addon <- cbind(errortunelasso21K3addon, errortunelasso22K3addon)
errortunelasso21K3full <- cbind(errortunelasso21K3full, errortunelasso22K3full)

errortunelasso21K5addon <- cbind(errortunelasso21K5addon, errortunelasso22K5addon)
errortunelasso21K5full <- cbind(errortunelasso21K5full, errortunelasso22K5full)

errortunelasso21K10addon <- cbind(errortunelasso21K10addon, errortunelasso22K10addon)
errortunelasso21K10full <- cbind(errortunelasso21K10full, errortunelasso22K10full)





errortunesvm31K3addon <- cbind(errortunesvm31K3addon, errortunesvm32K3addon, errortunesvm33K3addon,
  errortunesvm31K3addon, errortunesvm35K3addon, errortunesvm36K3addon)
errortunesvm31K3full <- cbind(errortunesvm31K3full, errortunesvm32K3full, errortunesvm33K3full,
  errortunesvm31K3full, errortunesvm35K3full, errortunesvm36K3full)

errortunesvm31K5addon <- cbind(errortunesvm31K5addon, errortunesvm32K5addon, errortunesvm33K5addon,
  errortunesvm31K5addon, errortunesvm35K5addon, errortunesvm36K5addon)
errortunesvm31K5full <- cbind(errortunesvm31K5full, errortunesvm32K5full, errortunesvm33K5full,
  errortunesvm31K5full, errortunesvm35K5full, errortunesvm36K5full)

errortunesvm31K10addon <- cbind(errortunesvm31K10addon, errortunesvm32K10addon, errortunesvm33K10addon, 
  errortunesvm34K10addon, errortunesvm35K10addon, errortunesvm36K10addon,
  errortunesvm37K10addon, errortunesvm38K10addon, errortunesvm39K10addon, 
  errortunesvm310K10addon, errortunesvm311K10addon, errortunesvm312K10addon)
errortunesvm31K10full <- cbind(errortunesvm31K10full, errortunesvm32K10full, errortunesvm33K10full, 
  errortunesvm34K10full, errortunesvm35K10full, errortunesvm36K10full,
  errortunesvm37K10full, errortunesvm38K10full, errortunesvm39K10full, 
  errortunesvm310K10full, errortunesvm311K10full, errortunesvm312K10full)



errortunerandfor31K3addon <- cbind(errortunerandfor31K3addon, errortunerandfor32K3addon,
  errortunerandfor33K3addon)
errortunerandfor31K3full <- cbind(errortunerandfor31K3full, errortunerandfor32K3full,
  errortunerandfor33K3full)

errortunerandfor31K5addon <- cbind(errortunerandfor31K5addon, errortunerandfor32K5addon,
  errortunerandfor33K5addon, errortunerandfor34K5addon, 
  errortunerandfor35K5addon, errortunerandfor36K5addon)
errortunerandfor31K5full <- cbind(errortunerandfor31K5full, errortunerandfor32K5full,
  errortunerandfor33K5full, errortunerandfor34K5full, 
  errortunerandfor35K5full, errortunerandfor36K5full)

errortunerandfor31K10addon <- cbind(errortunerandfor31K10addon, errortunerandfor32K10addon,
  errortunerandfor33K10addon, errortunerandfor34K10addon, 
  errortunerandfor35K10addon, errortunerandfor36K10addon,
  errortunerandfor37K10addon, errortunerandfor38K10addon,
  errortunerandfor39K10addon, errortunerandfor310K10addon, 
  errortunerandfor311K10addon, errortunerandfor312K10addon)
errortunerandfor31K10full <- cbind(errortunerandfor31K10full, errortunerandfor32K10full,
  errortunerandfor33K10full, errortunerandfor34K10full, 
  errortunerandfor35K10full, errortunerandfor36K10full,
  errortunerandfor37K10full, errortunerandfor38K10full,
  errortunerandfor39K10full, errortunerandfor310K10full, 
  errortunerandfor311K10full, errortunerandfor312K10full)



errortuneboost31K3addon <- cbind(errortuneboost31K3addon, errortuneboost32K3addon)
errortuneboost31K3full <- cbind(errortuneboost31K3full, errortuneboost32K3full)

errortuneboost31K5addon <- cbind(errortuneboost31K5addon, errortuneboost32K5addon, errortuneboost33K5addon,
  errortuneboost34K5addon)
errortuneboost31K5full <- cbind(errortuneboost31K5full, errortuneboost32K5full, errortuneboost33K5full,
  errortuneboost34K5full)

errortuneboost31K10addon <- cbind(errortuneboost31K10addon, errortuneboost32K10addon, errortuneboost33K10addon,
  errortuneboost34K10addon, errortuneboost35K10addon, errortuneboost36K10addon, errortuneboost37K10addon,
  errortuneboost38K10addon, errortuneboost39K10addon, errortuneboost310K10addon)
errortuneboost31K10full <- cbind(errortuneboost31K10full, errortuneboost32K10full, errortuneboost33K10full,
  errortuneboost34K10full, errortuneboost35K10full, errortuneboost36K10full, errortuneboost37K10full,
  errortuneboost38K10full, errortuneboost39K10full, errortuneboost310K10full)



errortunelasso31K3addon <- cbind(errortunelasso31K3addon, errortunelasso32K3addon)
errortunelasso31K3full <- cbind(errortunelasso31K3full, errortunelasso32K3full)

errortunelasso31K5addon <- cbind(errortunelasso31K5addon, errortunelasso32K5addon)
errortunelasso31K5full <- cbind(errortunelasso31K5full, errortunelasso32K5full)

errortunelasso31K10addon <- cbind(errortunelasso31K10addon, errortunelasso32K10addon)
errortunelasso31K10full <- cbind(errortunelasso31K10full, errortunelasso32K10full)






errortunesvm41K3addon <- cbind(errortunesvm41K3addon, errortunesvm42K3addon, errortunesvm43K3addon,
  errortunesvm41K3addon, errortunesvm45K3addon, errortunesvm46K3addon)
errortunesvm41K3full <- cbind(errortunesvm41K3full, errortunesvm42K3full, errortunesvm43K3full,
  errortunesvm41K3full, errortunesvm45K3full, errortunesvm46K3full)

errortunesvm41K5addon <- cbind(errortunesvm41K5addon, errortunesvm42K5addon, errortunesvm43K5addon,
  errortunesvm41K5addon, errortunesvm45K5addon, errortunesvm46K5addon)
errortunesvm41K5full <- cbind(errortunesvm41K5full, errortunesvm42K5full, errortunesvm43K5full,
  errortunesvm41K5full, errortunesvm45K5full, errortunesvm46K5full)

errortunesvm41K10addon <- cbind(errortunesvm41K10addon, errortunesvm42K10addon, errortunesvm43K10addon, 
  errortunesvm44K10addon, errortunesvm45K10addon, errortunesvm46K10addon,
  errortunesvm47K10addon, errortunesvm48K10addon, errortunesvm49K10addon, 
  errortunesvm410K10addon, errortunesvm411K10addon, errortunesvm412K10addon)
errortunesvm41K10full <- cbind(errortunesvm41K10full, errortunesvm42K10full, errortunesvm43K10full, 
  errortunesvm44K10full, errortunesvm45K10full, errortunesvm46K10full,
  errortunesvm47K10full, errortunesvm48K10full, errortunesvm49K10full, 
  errortunesvm410K10full, errortunesvm411K10full, errortunesvm412K10full)



errortunerandfor41K3addon <- cbind(errortunerandfor41K3addon, errortunerandfor42K3addon,
  errortunerandfor43K3addon)
errortunerandfor41K3full <- cbind(errortunerandfor41K3full, errortunerandfor42K3full,
  errortunerandfor43K3full)

errortunerandfor41K5addon <- cbind(errortunerandfor41K5addon, errortunerandfor42K5addon,
  errortunerandfor43K5addon, errortunerandfor44K5addon, 
  errortunerandfor45K5addon, errortunerandfor46K5addon)
errortunerandfor41K5full <- cbind(errortunerandfor41K5full, errortunerandfor42K5full,
  errortunerandfor43K5full, errortunerandfor44K5full, 
  errortunerandfor45K5full, errortunerandfor46K5full)

errortunerandfor41K10addon <- cbind(errortunerandfor41K10addon, errortunerandfor42K10addon,
  errortunerandfor43K10addon, errortunerandfor44K10addon, 
  errortunerandfor45K10addon, errortunerandfor46K10addon,
  errortunerandfor47K10addon, errortunerandfor48K10addon,
  errortunerandfor49K10addon, errortunerandfor410K10addon, 
  errortunerandfor411K10addon, errortunerandfor412K10addon)
errortunerandfor41K10full <- cbind(errortunerandfor41K10full, errortunerandfor42K10full,
  errortunerandfor43K10full, errortunerandfor44K10full, 
  errortunerandfor45K10full, errortunerandfor46K10full,
  errortunerandfor47K10full, errortunerandfor48K10full,
  errortunerandfor49K10full, errortunerandfor410K10full, 
  errortunerandfor411K10full, errortunerandfor412K10full)



errortuneboost41K3addon <- cbind(errortuneboost41K3addon, errortuneboost42K3addon)
errortuneboost41K3full <- cbind(errortuneboost41K3full, errortuneboost42K3full)

errortuneboost41K5addon <- cbind(errortuneboost41K5addon, errortuneboost42K5addon, errortuneboost43K5addon,
  errortuneboost44K5addon)
errortuneboost41K5full <- cbind(errortuneboost41K5full, errortuneboost42K5full, errortuneboost43K5full,
  errortuneboost44K5full)

errortuneboost41K10addon <- cbind(errortuneboost41K10addon, errortuneboost42K10addon, errortuneboost43K10addon,
  errortuneboost44K10addon, errortuneboost45K10addon, errortuneboost46K10addon, errortuneboost47K10addon,
  errortuneboost48K10addon, errortuneboost49K10addon, errortuneboost410K10addon)
errortuneboost41K10full <- cbind(errortuneboost41K10full, errortuneboost42K10full, errortuneboost43K10full,
  errortuneboost44K10full, errortuneboost45K10full, errortuneboost46K10full, errortuneboost47K10full,
  errortuneboost48K10full, errortuneboost49K10full, errortuneboost410K10full)



errortunelasso41K3addon <- cbind(errortunelasso41K3addon, errortunelasso42K3addon)
errortunelasso41K3full <- cbind(errortunelasso41K3full, errortunelasso42K3full)

errortunelasso41K5addon <- cbind(errortunelasso41K5addon, errortunelasso42K5addon)
errortunelasso41K5full <- cbind(errortunelasso41K5full, errortunelasso42K5full)

errortunelasso41K10addon <- cbind(errortunelasso41K10addon, errortunelasso42K10addon)
errortunelasso41K10full <- cbind(errortunelasso41K10full, errortunelasso42K10full)


setwd(workspacesafe)





# CVIIM-related functions:
###########################

# Function to compute the CVIIM_s,n,K,b-values:

# errorfull: errors of incomplete CV,
# erroraddon: errors of full CV
measureb <- function(errorfull, erroraddon) {
  meas <- 1 - errorfull/erroraddon
  return(meas)
}


# Function to compute the CVIIM_s,n,K-values:

# errorfull: mean error of repeated incomplete CV,
# erroraddon: mean error of repeated full CV
measure <- function(errorfull, erroraddon) {
  meas <- sapply(1 - errorfull/erroraddon, function(x) max(c(0, x)))
  meas[is.na(meas)] <- 0
  return(meas)
}


# Function to compute CVIIM_s,n,K together with
# 25%- and 75%-quartile of the CVIIM_s,n,K,b-values:

# errorfull: K x B matrix of fold errors of repeated incomplete CV,
# erroraddon: K x B matrix of fold errors of repeated full CV
measurewithquart <- function(errorfull, erroraddon) {

  measurei <- mapply(function(x, y) measureb(mean(x), mean(y)), data.frame(errorfull), data.frame(erroraddon))
  quartiles <- quantile(measurei, c(0.25, 0.75))
  measureval <- measure(mean(errorfull), mean(erroraddon))
  return(list(cvim=measureval, quartiles=quartiles))

}



# Figure on optimization of tuning parameters in paper:
########################################################

# The results are stored in a dataset for usage in 'ggplot':

cviimwithquartiles <- list(measurewithquart(errortuneboost31K3full, errortuneboost31K3addon),
measurewithquart(errortuneboost31K5full, errortuneboost31K5addon),
measurewithquart(errortuneboost31K10full, errortuneboost31K10addon),

measurewithquart(errortuneboost11K3full, errortuneboost11K3addon),
measurewithquart(errortuneboost11K5full, errortuneboost11K5addon),
measurewithquart(errortuneboost11K10full, errortuneboost11K10addon),

measurewithquart(errortuneboost21K3full, errortuneboost21K3addon),
measurewithquart(errortuneboost21K5full, errortuneboost21K5addon),
measurewithquart(errortuneboost21K10full, errortuneboost21K10addon),

measurewithquart(errortuneboost41K3full, errortuneboost41K3addon),
measurewithquart(errortuneboost41K5full, errortuneboost41K5addon),
measurewithquart(errortuneboost41K10full, errortuneboost41K10addon),


measurewithquart(errortunenearnei31K3full, errortunenearnei31K3addon),
measurewithquart(errortunenearnei31K5full, errortunenearnei31K5addon),
measurewithquart(errortunenearnei31K10full, errortunenearnei31K10addon),

measurewithquart(errortunenearnei11K3full, errortunenearnei11K3addon),
measurewithquart(errortunenearnei11K5full, errortunenearnei11K5addon),
measurewithquart(errortunenearnei11K10full, errortunenearnei11K10addon),

measurewithquart(errortunenearnei21K3full, errortunenearnei21K3addon),
measurewithquart(errortunenearnei21K5full, errortunenearnei21K5addon),
measurewithquart(errortunenearnei21K10full, errortunenearnei21K10addon),

measurewithquart(errortunenearnei41K3full, errortunenearnei41K3addon),
measurewithquart(errortunenearnei41K5full, errortunenearnei41K5addon),
measurewithquart(errortunenearnei41K10full, errortunenearnei41K10addon),


measurewithquart(errortunelasso31K3full, errortunelasso31K3addon),
measurewithquart(errortunelasso31K5full, errortunelasso31K5addon),
measurewithquart(errortunelasso31K10full, errortunelasso31K10addon),

measurewithquart(errortunelasso11K3full, errortunelasso11K3addon),
measurewithquart(errortunelasso11K5full, errortunelasso11K5addon),
measurewithquart(errortunelasso11K10full, errortunelasso11K10addon),

measurewithquart(errortunelasso21K3full, errortunelasso21K3addon),
measurewithquart(errortunelasso21K5full, errortunelasso21K5addon),
measurewithquart(errortunelasso21K10full, errortunelasso21K10addon),

measurewithquart(errortunelasso41K3full, errortunelasso41K3addon),
measurewithquart(errortunelasso41K5full, errortunelasso41K5addon),
measurewithquart(errortunelasso41K10full, errortunelasso41K10addon),


measurewithquart(errortunensc31K3full, errortunensc31K3addon),
measurewithquart(errortunensc31K5full, errortunensc31K5addon),
measurewithquart(errortunensc31K10full, errortunensc31K10addon),

measurewithquart(errortunensc11K3full, errortunensc11K3addon),
measurewithquart(errortunensc11K5full, errortunensc11K5addon),
measurewithquart(errortunensc11K10full, errortunensc11K10addon),

measurewithquart(errortunensc21K3full, errortunensc21K3addon),
measurewithquart(errortunensc21K5full, errortunensc21K5addon),
measurewithquart(errortunensc21K10full, errortunensc21K10addon),

measurewithquart(errortunensc41K3full, errortunensc41K3addon),
measurewithquart(errortunensc41K5full, errortunensc41K5addon),
measurewithquart(errortunensc41K10full, errortunensc41K10addon),


measurewithquart(errortuneplslda31K3full, errortuneplslda31K3addon),
measurewithquart(errortuneplslda31K5full, errortuneplslda31K5addon),
measurewithquart(errortuneplslda31K10full, errortuneplslda31K10addon),

measurewithquart(errortuneplslda11K3full, errortuneplslda11K3addon),
measurewithquart(errortuneplslda11K5full, errortuneplslda11K5addon),
measurewithquart(errortuneplslda11K10full, errortuneplslda11K10addon),

measurewithquart(errortuneplslda21K3full, errortuneplslda21K3addon),
measurewithquart(errortuneplslda21K5full, errortuneplslda21K5addon),
measurewithquart(errortuneplslda21K10full, errortuneplslda21K10addon),

measurewithquart(errortuneplslda41K3full, errortuneplslda41K3addon),
measurewithquart(errortuneplslda41K5full, errortuneplslda41K5addon),
measurewithquart(errortuneplslda41K10full, errortuneplslda41K10addon),


measurewithquart(errortunerandfor31K3full, errortunerandfor31K3addon),
measurewithquart(errortunerandfor31K5full, errortunerandfor31K5addon),
measurewithquart(errortunerandfor31K10full, errortunerandfor31K10addon),

measurewithquart(errortunerandfor11K3full, errortunerandfor11K3addon),
measurewithquart(errortunerandfor11K5full, errortunerandfor11K5addon),
measurewithquart(errortunerandfor11K10full, errortunerandfor11K10addon),

measurewithquart(errortunerandfor21K3full, errortunerandfor21K3addon),
measurewithquart(errortunerandfor21K5full, errortunerandfor21K5addon),
measurewithquart(errortunerandfor21K10full, errortunerandfor21K10addon),

measurewithquart(errortunerandfor41K3full, errortunerandfor41K3addon),
measurewithquart(errortunerandfor41K5full, errortunerandfor41K5addon),
measurewithquart(errortunerandfor41K10full, errortunerandfor41K10addon),


measurewithquart(errortunesvm31K3full, errortunesvm31K3addon),
measurewithquart(errortunesvm31K5full, errortunesvm31K5addon),
measurewithquart(errortunesvm31K10full, errortunesvm31K10addon),

measurewithquart(errortunesvm11K3full, errortunesvm11K3addon),
measurewithquart(errortunesvm11K5full, errortunesvm11K5addon),
measurewithquart(errortunesvm11K10full, errortunesvm11K10addon),

measurewithquart(errortunesvm21K3full, errortunesvm21K3addon),
measurewithquart(errortunesvm21K5full, errortunesvm21K5addon),
measurewithquart(errortunesvm21K10full, errortunesvm21K10addon),

measurewithquart(errortunesvm41K3full, errortunesvm41K3addon),
measurewithquart(errortunesvm41K5full, errortunesvm41K5addon),
measurewithquart(errortunesvm41K10full, errortunesvm41K10addon))





# e_full,K(s)- and e_incompl,K(s)-value:

errorsaddon <- c(mean(errortuneboost31K3addon), 
mean(errortuneboost31K5addon), 
mean(errortuneboost31K10addon), 
mean(errortuneboost11K3addon), 
mean(errortuneboost11K5addon), 
mean(errortuneboost11K10addon), 
mean(errortuneboost21K3addon), 
mean(errortuneboost21K5addon), 
mean(errortuneboost21K10addon), 
mean(errortuneboost41K3addon), 
mean(errortuneboost41K5addon), 
mean(errortuneboost41K10addon), 
mean(errortunenearnei31K3addon), 
mean(errortunenearnei31K5addon), 
mean(errortunenearnei31K10addon), 
mean(errortunenearnei11K3addon), 
mean(errortunenearnei11K5addon), 
mean(errortunenearnei11K10addon), 
mean(errortunenearnei21K3addon), 
mean(errortunenearnei21K5addon), 
mean(errortunenearnei21K10addon), 
mean(errortunenearnei41K3addon), 
mean(errortunenearnei41K5addon), 
mean(errortunenearnei41K10addon), 
mean(errortunelasso31K3addon), 
mean(errortunelasso31K5addon), 
mean(errortunelasso31K10addon), 
mean(errortunelasso11K3addon), 
mean(errortunelasso11K5addon), 
mean(errortunelasso11K10addon), 
mean(errortunelasso21K3addon), 
mean(errortunelasso21K5addon), 
mean(errortunelasso21K10addon), 
mean(errortunelasso41K3addon), 
mean(errortunelasso41K5addon), 
mean(errortunelasso41K10addon), 
mean(errortunensc31K3addon), 
mean(errortunensc31K5addon), 
mean(errortunensc31K10addon), 
mean(errortunensc11K3addon), 
mean(errortunensc11K5addon), 
mean(errortunensc11K10addon), 
mean(errortunensc21K3addon), 
mean(errortunensc21K5addon), 
mean(errortunensc21K10addon), 
mean(errortunensc41K3addon), 
mean(errortunensc41K5addon), 
mean(errortunensc41K10addon), 
mean(errortuneplslda31K3addon), 
mean(errortuneplslda31K5addon), 
mean(errortuneplslda31K10addon), 
mean(errortuneplslda11K3addon), 
mean(errortuneplslda11K5addon), 
mean(errortuneplslda11K10addon), 
mean(errortuneplslda21K3addon), 
mean(errortuneplslda21K5addon), 
mean(errortuneplslda21K10addon), 
mean(errortuneplslda41K3addon), 
mean(errortuneplslda41K5addon), 
mean(errortuneplslda41K10addon), 
mean(errortunerandfor31K3addon), 
mean(errortunerandfor31K5addon), 
mean(errortunerandfor31K10addon), 
mean(errortunerandfor11K3addon), 
mean(errortunerandfor11K5addon), 
mean(errortunerandfor11K10addon), 
mean(errortunerandfor21K3addon), 
mean(errortunerandfor21K5addon), 
mean(errortunerandfor21K10addon), 
mean(errortunerandfor41K3addon), 
mean(errortunerandfor41K5addon), 
mean(errortunerandfor41K10addon), 
mean(errortunesvm31K3addon), 
mean(errortunesvm31K5addon), 
mean(errortunesvm31K10addon), 
mean(errortunesvm11K3addon), 
mean(errortunesvm11K5addon), 
mean(errortunesvm11K10addon), 
mean(errortunesvm21K3addon), 
mean(errortunesvm21K5addon), 
mean(errortunesvm21K10addon), 
mean(errortunesvm41K3addon), 
mean(errortunesvm41K5addon), 
mean(errortunesvm41K10addon))





errorsfull <- c(mean(errortuneboost31K3full), 
mean(errortuneboost31K5full), 
mean(errortuneboost31K10full), 
mean(errortuneboost11K3full), 
mean(errortuneboost11K5full), 
mean(errortuneboost11K10full), 
mean(errortuneboost21K3full), 
mean(errortuneboost21K5full), 
mean(errortuneboost21K10full), 
mean(errortuneboost41K3full), 
mean(errortuneboost41K5full), 
mean(errortuneboost41K10full), 
mean(errortunenearnei31K3full), 
mean(errortunenearnei31K5full), 
mean(errortunenearnei31K10full), 
mean(errortunenearnei11K3full), 
mean(errortunenearnei11K5full), 
mean(errortunenearnei11K10full), 
mean(errortunenearnei21K3full), 
mean(errortunenearnei21K5full), 
mean(errortunenearnei21K10full), 
mean(errortunenearnei41K3full), 
mean(errortunenearnei41K5full), 
mean(errortunenearnei41K10full), 
mean(errortunelasso31K3full), 
mean(errortunelasso31K5full), 
mean(errortunelasso31K10full), 
mean(errortunelasso11K3full), 
mean(errortunelasso11K5full), 
mean(errortunelasso11K10full), 
mean(errortunelasso21K3full), 
mean(errortunelasso21K5full), 
mean(errortunelasso21K10full), 
mean(errortunelasso41K3full), 
mean(errortunelasso41K5full), 
mean(errortunelasso41K10full), 
mean(errortunensc31K3full), 
mean(errortunensc31K5full), 
mean(errortunensc31K10full), 
mean(errortunensc11K3full), 
mean(errortunensc11K5full), 
mean(errortunensc11K10full), 
mean(errortunensc21K3full), 
mean(errortunensc21K5full), 
mean(errortunensc21K10full), 
mean(errortunensc41K3full), 
mean(errortunensc41K5full), 
mean(errortunensc41K10full), 
mean(errortuneplslda31K3full), 
mean(errortuneplslda31K5full), 
mean(errortuneplslda31K10full), 
mean(errortuneplslda11K3full), 
mean(errortuneplslda11K5full), 
mean(errortuneplslda11K10full), 
mean(errortuneplslda21K3full), 
mean(errortuneplslda21K5full), 
mean(errortuneplslda21K10full), 
mean(errortuneplslda41K3full), 
mean(errortuneplslda41K5full), 
mean(errortuneplslda41K10full), 
mean(errortunerandfor31K3full), 
mean(errortunerandfor31K5full), 
mean(errortunerandfor31K10full), 
mean(errortunerandfor11K3full), 
mean(errortunerandfor11K5full), 
mean(errortunerandfor11K10full), 
mean(errortunerandfor21K3full), 
mean(errortunerandfor21K5full), 
mean(errortunerandfor21K10full), 
mean(errortunerandfor41K3full), 
mean(errortunerandfor41K5full), 
mean(errortunerandfor41K10full), 
mean(errortunesvm31K3full), 
mean(errortunesvm31K5full), 
mean(errortunesvm31K10full), 
mean(errortunesvm11K3full), 
mean(errortunesvm11K5full), 
mean(errortunesvm11K10full), 
mean(errortunesvm21K3full), 
mean(errortunesvm21K5full), 
mean(errortunesvm21K10full), 
mean(errortunesvm41K3full), 
mean(errortunesvm41K5full), 
mean(errortunesvm41K10full))






# Data.frame tailored for plot problem:

labsnvars <- c("Boosting", "kNN", "Lasso", "NSC", "PLS-LDA", "Random Forest", "SVM")

results <- data.frame(nvars=factor(rep(labsnvars, each=3*4), levels=labsnvars),
dataset=rep(rep(c("ProstatecTranscr", "GSE33205", "GSE20189", "GSE37356"), each=3), times=length(labsnvars)),
K=rep(c(3,5,10), times=length(cviimwithquartiles)/3),
CVIIM=sapply(cviimwithquartiles, function(x) x$cvim),
CVIIM25=sapply(cviimwithquartiles, function(x) x$quartiles[1]),
CVIIM75=sapply(cviimwithquartiles, function(x) x$quartiles[2]),
errorsaddon=errorsaddon,
errorsfull=errorsfull)

results$dataID <- NA
results$dataID[results$dataset=="ProstatecTranscr"] <- 14
results$dataID[results$dataset=="GSE33205"] <- 25
results$dataID[results$dataset=="GSE20189"] <- 15
results$dataID[results$dataset=="GSE37356"] <- 30

spacingbars1 <- 0.17
spacingnumbers1 <- 0.08

results$x <- as.numeric(as.factor(results$K)) + rep(rep(c(-1.5, -0.5, 0.5, 1.5), each=3), times=length(labsnvars))*spacingbars1 - spacingnumbers1


library("ggplot2")

p <- ggplot(data=results, aes(x=factor(K), y=CVIIM)) + 
  geom_text(aes(x=x,label=as.character(results$dataID), colour=dataset), size=3) + facet_wrap(~ nvars, nrow=4, ncol=2) +
  geom_line(aes(x=x, y=CVIIM, color=dataset)) +
  theme(legend.position="none") + 
  geom_errorbar(aes(x=x+spacingnumbers1, ymin=CVIIM25, ymax=CVIIM75, colour=dataset)) +
  geom_hline(yintercept=0, linetype=2) + 
  labs(x="", y=expression(CVIIM[paste(bold(s), ",n,K", sep="")])) + 
  scale_x_discrete(breaks=1:3, labels=paste("K =", c(3,5,10)), expand=c(0.05,-2))
p

ggsave(file="./CVIIMCodeData/Plots/Supplementary Figure 7.eps", width=6, height=9)



# Get sample sizes of data sets:

datanames <- c("ProstatecTranscr", "GSE33205", "GSE20189", "GSE37356")

if(file.exists("./CVIIMCodeData/DataRetrieval/DataSetsPCA/ProstatecTranscr.Rda") &
  file.exists("./CVIIMCodeData/DataRetrieval/DataSetsPCA/GSE33205.Rda") & 
  file.exists("./CVIIMCodeData/DataRetrieval/DataSetsPCA/GSE20189.Rda") & 
  file.exists("./CVIIMCodeData/DataRetrieval/DataSetsPCA/GSE37356.Rda")) {
  
nsamples <- 0
load("./CVIIMCodeData/DataRetrieval/DataSetsPCA/ProstatecTranscr.Rda")
nsamples[1] <- length(y)
load("./CVIIMCodeData/DataRetrieval/DataSetsPCA/GSE33205.Rda")
nsamples[2] <- length(y)
load("./CVIIMCodeData/DataRetrieval/DataSetsPCA/GSE20189.Rda")
nsamples[3] <- length(y)
load("./CVIIMCodeData/DataRetrieval/DataSetsPCA/GSE37356.Rda")
nsamples[4] <- length(y)

} else {
  nsamples <- c(102, 50, 100, 36)
}

results$nsample <- sapply(results$dataset, function(x) nsamples[datanames==x]) 
results$diffmeasure <- ifelse(results$errorsaddon - results$errorsfull>0, results$errorsaddon - results$errorsfull, 0)



# Sub-Plot: average CVIIM_s,n,K- and e_full,K(s)-values against sample sizes:

resultsum2 <- ddply(results, .variables=c("dataset", "dataID", "nsample"), .fun=summarise, dataseterror=mean(errorsaddon, na.rm=TRUE), datasetCVIIM=mean(CVIIM, na.rm=TRUE),
  datasetdiffmeasure=mean(diffmeasure, na.rm=TRUE))

lwdths <- 1

p1 <- ggplot(data=resultsum2, aes(x=nsample, y=dataseterror)) +
  geom_text(label=as.character(as.numeric(resultsum2$dataID)), size=4) + geom_hline(yintercept=0, linetype=2) + 
  labs(x="n", y="", title="Est. error")
p1

p2 <- ggplot(data=resultsum2, aes(x=nsample, y=datasetCVIIM)) +
  geom_text(label=as.character(as.numeric(resultsum2$dataID)), size=4) + geom_hline(yintercept=0, linetype=2) + 
  labs(x="n", y="", title="CVIIM")
p2

library("gridExtra")
grobframe3 <- arrangeGrob(p2, p1, ncol=2, nrow=1, main=textGrob("Optimization of tuning parameters", gp=gpar(fontsize=20)))
grobframe3 





# Calculation of the global CVIIM-estimates
################################################

globalCVIIMmat <- rbind(c(measure(mean(c(mean(errortuneboost11K3full), mean(errortuneboost21K3full), mean(errortuneboost31K3full), mean(errortuneboost41K3full))), mean(c(mean(errortuneboost11K3addon), mean(errortuneboost21K3addon), mean(errortuneboost31K3addon), mean(errortuneboost41K3addon)))), 
measure(mean(c(mean(errortuneboost11K5full), mean(errortuneboost21K5full), mean(errortuneboost31K5full), mean(errortuneboost41K5full))), mean(c(mean(errortuneboost11K5addon), mean(errortuneboost21K5addon), mean(errortuneboost31K5addon), mean(errortuneboost41K5addon)))), 
measure(mean(c(mean(errortuneboost11K10full), mean(errortuneboost21K10full), mean(errortuneboost31K10full), mean(errortuneboost41K10full))), mean(c(mean(errortuneboost11K10addon), mean(errortuneboost21K10addon), mean(errortuneboost31K10addon), mean(errortuneboost41K10addon))))),

c(measure(mean(c(mean(errortunenearnei11K3full), mean(errortunenearnei21K3full), mean(errortunenearnei31K3full), mean(errortunenearnei41K3full))), mean(c(mean(errortunenearnei11K3addon), mean(errortunenearnei21K3addon), mean(errortunenearnei31K3addon), mean(errortunenearnei41K3addon)))), 
measure(mean(c(mean(errortunenearnei11K5full), mean(errortunenearnei21K5full), mean(errortunenearnei31K5full), mean(errortunenearnei41K5full))), mean(c(mean(errortunenearnei11K5addon), mean(errortunenearnei21K5addon), mean(errortunenearnei31K5addon), mean(errortunenearnei41K5addon)))), 
measure(mean(c(mean(errortunenearnei11K10full), mean(errortunenearnei21K10full), mean(errortunenearnei31K10full), mean(errortunenearnei41K10full))), mean(c(mean(errortunenearnei11K10addon), mean(errortunenearnei21K10addon), mean(errortunenearnei31K10addon), mean(errortunenearnei41K10addon))))), 

c(measure(mean(c(mean(errortunelasso11K3full), mean(errortunelasso21K3full), mean(errortunelasso31K3full), mean(errortunelasso41K3full))), mean(c(mean(errortunelasso11K3addon), mean(errortunelasso21K3addon), mean(errortunelasso31K3addon), mean(errortunelasso41K3addon)))), 
measure(mean(c(mean(errortunelasso11K5full), mean(errortunelasso21K5full), mean(errortunelasso31K5full), mean(errortunelasso41K5full))), mean(c(mean(errortunelasso11K5addon), mean(errortunelasso21K5addon), mean(errortunelasso31K5addon), mean(errortunelasso41K5addon)))), 
measure(mean(c(mean(errortunelasso11K10full), mean(errortunelasso21K10full), mean(errortunelasso31K10full), mean(errortunelasso41K10full))), mean(c(mean(errortunelasso11K10addon), mean(errortunelasso21K10addon), mean(errortunelasso31K10addon), mean(errortunelasso41K10addon))))), 

c(measure(mean(c(mean(errortunensc11K3full), mean(errortunensc21K3full), mean(errortunensc31K3full), mean(errortunensc41K3full))), mean(c(mean(errortunensc11K3addon), mean(errortunensc21K3addon), mean(errortunensc31K3addon), mean(errortunensc41K3addon)))), 
measure(mean(c(mean(errortunensc11K5full), mean(errortunensc21K5full), mean(errortunensc31K5full), mean(errortunensc41K5full))), mean(c(mean(errortunensc11K5addon), mean(errortunensc21K5addon), mean(errortunensc31K5addon), mean(errortunensc41K5addon)))), 
measure(mean(c(mean(errortunensc11K10full), mean(errortunensc21K10full), mean(errortunensc31K10full), mean(errortunensc41K10full))), mean(c(mean(errortunensc11K10addon), mean(errortunensc21K10addon), mean(errortunensc31K10addon), mean(errortunensc41K10addon))))), 

c(measure(mean(c(mean(errortuneplslda11K3full), mean(errortuneplslda21K3full), mean(errortuneplslda31K3full), mean(errortuneplslda41K3full))), mean(c(mean(errortuneplslda11K3addon), mean(errortuneplslda21K3addon), mean(errortuneplslda31K3addon), mean(errortuneplslda41K3addon)))), 
measure(mean(c(mean(errortuneplslda11K5full), mean(errortuneplslda21K5full), mean(errortuneplslda31K5full), mean(errortuneplslda41K5full))), mean(c(mean(errortuneplslda11K5addon), mean(errortuneplslda21K5addon), mean(errortuneplslda31K5addon), mean(errortuneplslda41K5addon)))), 
measure(mean(c(mean(errortuneplslda11K10full), mean(errortuneplslda21K10full), mean(errortuneplslda31K10full), mean(errortuneplslda41K10full))), mean(c(mean(errortuneplslda11K10addon), mean(errortuneplslda21K10addon), mean(errortuneplslda31K10addon), mean(errortuneplslda41K10addon))))), 

c(measure(mean(c(mean(errortunerandfor11K3full), mean(errortunerandfor21K3full), mean(errortunerandfor31K3full), mean(errortunerandfor41K3full))), mean(c(mean(errortunerandfor11K3addon), mean(errortunerandfor21K3addon), mean(errortunerandfor31K3addon), mean(errortunerandfor41K3addon)))), 
measure(mean(c(mean(errortunerandfor11K5full), mean(errortunerandfor21K5full), mean(errortunerandfor31K5full), mean(errortunerandfor41K5full))), mean(c(mean(errortunerandfor11K5addon), mean(errortunerandfor21K5addon), mean(errortunerandfor31K5addon), mean(errortunerandfor41K5addon)))), 
measure(mean(c(mean(errortunerandfor11K10full), mean(errortunerandfor21K10full), mean(errortunerandfor31K10full), mean(errortunerandfor41K10full))), mean(c(mean(errortunerandfor11K10addon), mean(errortunerandfor21K10addon), mean(errortunerandfor31K10addon), mean(errortunerandfor41K10addon))))),

c(measure(mean(c(mean(errortunesvm11K3full), mean(errortunesvm21K3full), mean(errortunesvm31K3full), mean(errortunesvm41K3full))), mean(c(mean(errortunesvm11K3addon), mean(errortunesvm21K3addon), mean(errortunesvm31K3addon), mean(errortunesvm41K3addon)))), 
measure(mean(c(mean(errortunesvm11K5full), mean(errortunesvm21K5full), mean(errortunesvm31K5full), mean(errortunesvm41K5full))), mean(c(mean(errortunesvm11K5addon), mean(errortunesvm21K5addon), mean(errortunesvm31K5addon), mean(errortunesvm41K5addon)))), 
measure(mean(c(mean(errortunesvm11K10full), mean(errortunesvm21K10full), mean(errortunesvm31K10full), mean(errortunesvm41K10full))), mean(c(mean(errortunesvm11K10addon), mean(errortunesvm21K10addon), mean(errortunesvm31K10addon), mean(errortunesvm41K10addon))))))


globalcviimvals <- as.vector(globalCVIIMmat)
smallglobalcviim <- (globalcviimvals <= 0.00005) & (globalcviimvals != 0)

globalcviims <- format(round(globalcviimvals, 4), nsmall=4)
globalcviims[smallglobalcviim] <- "< 0.0001"

globalCVIIMmat <- matrix(nrow=nrow(globalCVIIMmat), ncol=ncol(globalCVIIMmat),
  data=globalcviims)

rownames(globalCVIIMmat) <- labsnvars
colnames(globalCVIIMmat) <- paste("K = ", c(3,5,10), sep="")

globalCVIIMmat



# LaTeX-Table:

tabcontents <- sapply(1:nrow(globalCVIIMmat), function(x) paste(paste(c(labsnvars[x], globalCVIIMmat[x,]), collapse=" & "), "\\\\", sep=""))

tablelatex <- c("\\begin{table}",
"\\begin{tabular}{l | r | r | r }",
"number of sel. & $K = 3$ & $K = 5$ & $K = 10$\\\\",
"variables & & \\\\",
"\\hline", 
tabcontents[1],
"\\hline",
tabcontents[2],
"\\hline",
tabcontents[3],
"\\hline",
tabcontents[4],
"\\hline",
tabcontents[5],
"\\hline",
tabcontents[6],
"\\hline",
tabcontents[7],
"\\end{tabular}",
"\\caption{Estimates of global CVIIM from tuning study}",
"\\label{t:tuningglobalcviim}", 
"\\end{table}")

for(i in seq(along=tablelatex))
  cat(tablelatex[i], "\n")
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  


# Variable selection:
#
#  NOTE: This is only included here, because variable selection is 
#  also taken in in the plot of the average CVIIM_s,n,K- and e_full,K(s)-values against 
#  sample sizes generated at the end of this script.
#  For the evaluations with respect to the impact of CV incompleteness see
#  "VariableSelection_EVALUATION.R".
#
######################################  


# Read in fold errors of repeated full and incomplete CV:
########################################################

workspacesafe <- getwd()
setwd("./CVIIMCodeData/OtherStepsAndVariableSelection/ResultsOtherStepsAndVariableSelection/")

load("varselerrornvar10K10.Rda") 
load("varselerrornvar10K3.Rda") 
load("varselerrornvar10K5.Rda") 
load("varselerrornvar20K10.Rda") 
load("varselerrornvar20K3.Rda") 
load("varselerrornvar20K5.Rda") 
load("varselerrornvar5K10.Rda") 
load("varselerrornvar5K3.Rda") 
load("varselerrornvar5K5.Rda") 

load("varselerrornvarbigK3.Rda")
load("varselerrornvarbigK5.Rda")
load("varselerrornvarbigK10.Rda")


load("varselerrornvar102K10.Rda") 
load("varselerrornvar102K3.Rda") 
load("varselerrornvar102K5.Rda") 
load("varselerrornvar202K10.Rda") 
load("varselerrornvar202K3.Rda") 
load("varselerrornvar202K5.Rda") 
load("varselerrornvar52K10.Rda") 
load("varselerrornvar52K3.Rda") 
load("varselerrornvar52K5.Rda") 

load("varselerrornvarbig2K3.Rda")
load("varselerrornvarbig2K5.Rda")
load("varselerrornvarbig2K10.Rda")



load("varselerrornvar103K10.Rda") 
load("varselerrornvar103K3.Rda") 
load("varselerrornvar103K5.Rda") 
load("varselerrornvar203K10.Rda") 
load("varselerrornvar203K3.Rda") 
load("varselerrornvar203K5.Rda") 
load("varselerrornvar53K10.Rda") 
load("varselerrornvar53K3.Rda") 
load("varselerrornvar53K5.Rda") 

load("varselerrornvarbig3K3.Rda")
load("varselerrornvarbig3K5.Rda")
load("varselerrornvarbig3K10.Rda")
 


load("varselerrornvar104K10.Rda") 
load("varselerrornvar104K3.Rda") 
load("varselerrornvar104K5.Rda") 
load("varselerrornvar204K10.Rda") 
load("varselerrornvar204K3.Rda") 
load("varselerrornvar204K5.Rda") 
load("varselerrornvar54K10.Rda") 
load("varselerrornvar54K3.Rda") 
load("varselerrornvar54K5.Rda") 

load("varselerrornvarbig4K3.Rda")
load("varselerrornvarbig4K5.Rda")
load("varselerrornvarbig4K10.Rda")

setwd(workspacesafe)





# CVIIM-related functions:
###########################

# Function to compute the CVIIM_s,n,K,b-values:

# errorfull: errors of incomplete CV,
# erroraddon: errors of full CV
measureb <- function(errorfull, erroraddon) {
  meas <- 1 - errorfull/erroraddon
  return(meas)
}


# Function to compute the CVIIM_s,n,K-values:

# errorfull: mean error of repeated incomplete CV,
# erroraddon: mean error of repeated full CV
measure <- function(errorfull, erroraddon) {
  meas <- sapply(1 - errorfull/erroraddon, function(x) max(c(0, x)))
  meas[is.na(meas)] <- 0
  return(meas)
}


# Function to compute CVIIM_s,n,K together with
# 25%- and 75%-quartile of the CVIIM_s,n,K,b-values:

# errorfull: K x B matrix of fold errors of repeated incomplete CV,
# erroraddon: K x B matrix of fold errors of repeated full CV
measurewithquart <- function(errorfull, erroraddon) {

  measurei <- mapply(function(x, y) measureb(mean(x), mean(y)), data.frame(errorfull), data.frame(erroraddon))
  quartiles <- quantile(measurei, c(0.25, 0.75))
  measureval <- measure(mean(errorfull), mean(erroraddon))
  return(list(cvim=measureval, quartiles=quartiles))

}





# The results are stored in a dataset for usage in 'ggplot':

cviimwithquartiles <- list(measurewithquart(errornvar5K3full, errornvar5K3addon),
measurewithquart(errornvar5K5full, errornvar5K5addon),
measurewithquart(errornvar5K10full, errornvar5K10addon),

measurewithquart(errornvar53K3full, errornvar53K3addon),
measurewithquart(errornvar53K5full, errornvar53K5addon),
measurewithquart(errornvar53K10full, errornvar53K10addon),

measurewithquart(errornvar54K3full, errornvar54K3addon),
measurewithquart(errornvar54K5full, errornvar54K5addon),
measurewithquart(errornvar54K10full, errornvar54K10addon),

measurewithquart(errornvar52K3full, errornvar52K3addon),
measurewithquart(errornvar52K5full, errornvar52K5addon),
measurewithquart(errornvar52K10full, errornvar52K10addon),


measurewithquart(errornvar10K3full, errornvar10K3addon),
measurewithquart(errornvar10K5full, errornvar10K5addon),
measurewithquart(errornvar10K10full, errornvar10K10addon),

measurewithquart(errornvar103K3full, errornvar103K3addon),
measurewithquart(errornvar103K5full, errornvar103K5addon),
measurewithquart(errornvar103K10full, errornvar103K10addon),

measurewithquart(errornvar104K3full, errornvar104K3addon),
measurewithquart(errornvar104K5full, errornvar104K5addon),
measurewithquart(errornvar104K10full, errornvar104K10addon),

measurewithquart(errornvar102K3full, errornvar102K3addon),
measurewithquart(errornvar102K5full, errornvar102K5addon),
measurewithquart(errornvar102K10full, errornvar102K10addon),


measurewithquart(errornvar20K3full, errornvar20K3addon),
measurewithquart(errornvar20K5full, errornvar20K5addon),
measurewithquart(errornvar20K10full, errornvar20K10addon),

measurewithquart(errornvar203K3full, errornvar203K3addon),
measurewithquart(errornvar203K5full, errornvar203K5addon),
measurewithquart(errornvar203K10full, errornvar203K10addon),

measurewithquart(errornvar204K3full, errornvar204K3addon),
measurewithquart(errornvar204K5full, errornvar204K5addon),
measurewithquart(errornvar204K10full, errornvar204K10addon),

measurewithquart(errornvar202K3full, errornvar202K3addon),
measurewithquart(errornvar202K5full, errornvar202K5addon),
measurewithquart(errornvar202K10full, errornvar202K10addon),


measurewithquart(errornvarbigK3full, errornvarbigK3addon),
measurewithquart(errornvarbigK5full, errornvarbigK5addon),
measurewithquart(errornvarbigK10full, errornvarbigK10addon),

measurewithquart(errornvarbig3K3full, errornvarbig3K3addon),
measurewithquart(errornvarbig3K5full, errornvarbig3K5addon),
measurewithquart(errornvarbig3K10full, errornvarbig3K10addon),

measurewithquart(errornvarbig4K3full, errornvarbig4K3addon),
measurewithquart(errornvarbig4K5full, errornvarbig4K5addon),
measurewithquart(errornvarbig4K10full, errornvarbig4K10addon),

measurewithquart(errornvarbig2K3full, errornvarbig2K3addon),
measurewithquart(errornvarbig2K5full, errornvarbig2K5addon),
measurewithquart(errornvarbig2K10full, errornvarbig2K10addon))



# e_full,K(s)- and e_incompl,K(s)-value:

errorsaddon <- c(mean(errornvar5K3addon), 
mean(errornvar5K5addon), 
mean(errornvar5K10addon), 
mean(errornvar53K3addon), 
mean(errornvar53K5addon), 
mean(errornvar53K10addon), 
mean(errornvar54K3addon), 
mean(errornvar54K5addon), 
mean(errornvar54K10addon), 
mean(errornvar52K3addon), 
mean(errornvar52K5addon), 
mean(errornvar52K10addon), 
mean(errornvar10K3addon), 
mean(errornvar10K5addon), 
mean(errornvar10K10addon), 
mean(errornvar103K3addon), 
mean(errornvar103K5addon), 
mean(errornvar103K10addon), 
mean(errornvar104K3addon), 
mean(errornvar104K5addon), 
mean(errornvar104K10addon), 
mean(errornvar102K3addon), 
mean(errornvar102K5addon), 
mean(errornvar102K10addon), 
mean(errornvar20K3addon), 
mean(errornvar20K5addon), 
mean(errornvar20K10addon), 
mean(errornvar203K3addon), 
mean(errornvar203K5addon), 
mean(errornvar203K10addon), 
mean(errornvar204K3addon), 
mean(errornvar204K5addon), 
mean(errornvar204K10addon), 
mean(errornvar202K3addon), 
mean(errornvar202K5addon), 
mean(errornvar202K10addon), 
mean(errornvarbigK3addon), 
mean(errornvarbigK5addon), 
mean(errornvarbigK10addon), 
mean(errornvarbig3K3addon), 
mean(errornvarbig3K5addon), 
mean(errornvarbig3K10addon), 
mean(errornvarbig4K3addon), 
mean(errornvarbig4K5addon), 
mean(errornvarbig4K10addon), 
mean(errornvarbig2K3addon), 
mean(errornvarbig2K5addon), 
mean(errornvarbig2K10addon))





errorsfull <- c(mean(errornvar5K3full), 
mean(errornvar5K5full), 
mean(errornvar5K10full), 
mean(errornvar53K3full), 
mean(errornvar53K5full), 
mean(errornvar53K10full), 
mean(errornvar54K3full), 
mean(errornvar54K5full), 
mean(errornvar54K10full), 
mean(errornvar52K3full), 
mean(errornvar52K5full), 
mean(errornvar52K10full), 
mean(errornvar10K3full), 
mean(errornvar10K5full), 
mean(errornvar10K10full), 
mean(errornvar103K3full), 
mean(errornvar103K5full), 
mean(errornvar103K10full), 
mean(errornvar104K3full), 
mean(errornvar104K5full), 
mean(errornvar104K10full), 
mean(errornvar102K3full), 
mean(errornvar102K5full), 
mean(errornvar102K10full), 
mean(errornvar20K3full), 
mean(errornvar20K5full), 
mean(errornvar20K10full), 
mean(errornvar203K3full), 
mean(errornvar203K5full), 
mean(errornvar203K10full), 
mean(errornvar204K3full), 
mean(errornvar204K5full), 
mean(errornvar204K10full), 
mean(errornvar202K3full), 
mean(errornvar202K5full), 
mean(errornvar202K10full), 
mean(errornvarbigK3full), 
mean(errornvarbigK5full), 
mean(errornvarbigK10full), 
mean(errornvarbig3K3full), 
mean(errornvarbig3K5full), 
mean(errornvarbig3K10full), 
mean(errornvarbig4K3full), 
mean(errornvarbig4K5full), 
mean(errornvarbig4K10full), 
mean(errornvarbig2K3full), 
mean(errornvarbig2K5full), 
mean(errornvarbig2K10full))



# Data.frame tailored for plot problem:

labsnvars <- c("psel = 5", "psel = 10", "psel = 20", "psel = p/2")

results <- data.frame(nvars=factor(rep(labsnvars, each=3*4), levels=labsnvars),
dataset=rep(rep(c("ProstatecTranscr", "GSE33205", "GSE20189", "GSE37356"), each=3), times=4),
K=rep(c(3,5,10), times=length(cviimwithquartiles)/3),
CVIIM=sapply(cviimwithquartiles, function(x) x$cvim),
CVIIM25=sapply(cviimwithquartiles, function(x) x$quartiles[1]),
CVIIM75=sapply(cviimwithquartiles, function(x) x$quartiles[2]),
errorsaddon=errorsaddon,
errorsfull=errorsfull)

results$dataID <- NA
results$dataID[results$dataset=="ProstatecTranscr"] <- 14
results$dataID[results$dataset=="GSE33205"] <- 25
results$dataID[results$dataset=="GSE20189"] <- 15
results$dataID[results$dataset=="GSE37356"] <- 30
  
  

  

# Get sample sizes of data sets:
  
datanames <- c("ProstatecTranscr", "GSE33205", "GSE20189", "GSE37356")

if(file.exists("./CVIIMCodeData/DataRetrieval/DataSetsPCA/ProstatecTranscr.Rda") &
  file.exists("./CVIIMCodeData/DataRetrieval/DataSetsPCA/GSE33205.Rda") & 
  file.exists("./CVIIMCodeData/DataRetrieval/DataSetsPCA/GSE20189.Rda") & 
  file.exists("./CVIIMCodeData/DataRetrieval/DataSetsPCA/GSE37356.Rda")) {
  
nsamples <- 0
load("./CVIIMCodeData/DataRetrieval/DataSetsPCA/ProstatecTranscr.Rda")
nsamples[1] <- length(y)
load("./CVIIMCodeData/DataRetrieval/DataSetsPCA/GSE33205.Rda")
nsamples[2] <- length(y)
load("./CVIIMCodeData/DataRetrieval/DataSetsPCA/GSE20189.Rda")
nsamples[3] <- length(y)
load("./CVIIMCodeData/DataRetrieval/DataSetsPCA/GSE37356.Rda")
nsamples[4] <- length(y)

} else {
  nsamples <- c(102, 50, 100, 36)
}

results$nsample <- sapply(results$dataset, function(x) nsamples[datanames==x]) 
results$diffmeasure <- ifelse(results$errorsaddon - results$errorsfull>0, results$errorsaddon - results$errorsfull, 0)



# Sub-Plot: average CVIIM_s,n,K- and e_full,K(s)-values against sample sizes:

resultsum2 <- ddply(results, .variables=c("dataset", "dataID", "nsample"), .fun=summarise, dataseterror=mean(errorsaddon, na.rm=TRUE), datasetCVIIM=mean(CVIIM, na.rm=TRUE),
  datasetdiffmeasure=mean(diffmeasure, na.rm=TRUE))

  
p1 <- ggplot(data=resultsum2, aes(x=nsample, y=dataseterror)) +
  geom_text(label=as.character(as.numeric(resultsum2$dataID)), size=4) + geom_hline(yintercept=0, linetype=2) + 
  labs(x="n", y="", title="Est. error")
p1

p2 <- ggplot(data=resultsum2, aes(x=nsample, y=datasetCVIIM)) +
  geom_text(label=as.character(as.numeric(resultsum2$dataID)), size=4) + geom_hline(yintercept=0, linetype=2) + 
  labs(x="n", y="", title="CVIIM")
p2


grobframe4 <- arrangeGrob(p2, p1, ncol=2, nrow=1, main=textGrob("Supervised variable selection", gp=gpar(fontsize=20))) 
grobframe4 

















# Now the previously generated subplots on the averages of the CVIIM_s,n,K- and e_full,K(s)-values 
# against the sample sizes are combined to one plot, which is presented in Additional file 2:
#####################################################################################################

grobframeall <- arrangeGrob(grobframe3, grobframe1, grobframe2, grobframe4, ncol=1, nrow=4) 
grobframeall  

ggsave(file="./CVIIMCodeData/Plots/Supplementary Figure 12.eps", plot=grobframeall, width=10, height=15)
















