# NOTE: For this script to give the intended results it is necessary
# that the 16 data sets in form of the Rda-files which can be generated by 
# the "E-GEOD-XXXX.R"-scripts found in the folder "RealDataApplications/PrincipalComponentAnalysisExtensiveStudy/DataSets"
# are present. 
####################################################################

# Determine the paths to the data sets:

labels <- c("ProstatecTranscr", "GSE33205", "GSE20189", "GSE37356", 
"E-GEOD-25609", "E-GEOD-31629", "E-GEOD-32393", "E-GEOD-33615", 
"E-GEOD-36769", "E-GEOD-37582", "E-GEOD-37965", "E-GEOD-39046", 
"E-GEOD-39345", "E-GEOD-42042", "E-GEOD-42826", "E-GEOD-42830", 
"E-GEOD-43329", "E-GEOD-48153", "E-GEOD-49641", "E-GEOD-57285")
datasets <- paste("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", labels, ".Rda", sep="")

# Build the setting table:

settingtable <- expand.grid(c(3,5,10), datasets, c(2,5,10,15), c("lda", "randomforest"))

# Add shorter names:
names <- gsub("\\.Rda", "", gsub("./CVIIMCodeData/DataRetrieval/DataSetsPCA/", "", settingtable$Var2))
settingtable$names <- names

# Build an index variable which distributes the different settings to the different cpus:
cpuindex <- as.numeric(factor(apply(data.frame(settingtable$Var2, settingtable$Var3, ifelse(settingtable$Var1==10, 10, 35)), 1, function(x) paste(x, collapse=""))))

# Load informations on data sets:
load("./CVIIMCodeData/DataRetrieval/datainfoNormPCA.Rda")
datatable <- datainfo[datainfo$study=="PCA",]

# For data sets with less than 2000 variables all settings per value of K can be done on 
# one CPU:
sort(datatable$nvar)
datanamessmall <- datatable$label[datatable$nvar < 2000]

count <- 1
kvalues <- c(3,5,10)
for(i in seq(along=datanamessmall)) {
  for(j in seq(along=kvalues)) {
    cpuindex[(settingtable$names==datanamessmall[i]) & (settingtable$Var1==kvalues[j])] <- letters[count]
    count <- count+1
  }
}
cpuindex <- as.numeric(factor(cpuindex))



# Transform the factor-valued data set names into characters:

settingtable$Var2 <- as.character(settingtable$Var2)


# Write the Rda-files:

for(i in 1:length(unique(cpuindex))) {
  Kvals <- settingtable$Var1[cpuindex==i]
  datasets <- as.character(settingtable$Var2[cpuindex==i])
  ncomps <- settingtable$Var3[cpuindex==i]
  classifiers <- as.character(settingtable$Var4[cpuindex==i])
  save(datasets, Kvals, ncomps, classifiers, file=paste("./CVIIMCodeData/PrincipalComponentAnalysisStudy/Settings/settingpca", i, ".Rda", sep=""))
} 
