# Set working directory to the folder the simulation results are stored:

workingdir <- getwd()
setwd("~/SimulationCVIIM/confs")


# Read in the parameters for each simulation scenario stored in a table:

tableresults <- read.table("ScenarioTable.txt", header=TRUE)



# Load the results for each scenario and prepare them:

errorfulltrues <- 0
errorincompltrues <- 0

errorfullmiss <- 0
errorincomplmiss <- 0

errorfullsimitalls <- list()
errorincomplsimitalls <- list()

for(i in 1:24) {

# Loading of the i-th scenario:
eval(parse(text=paste("load(\"resultsscenario", i, ".RData\")", sep="")))

errorfulltrue <- unlist(errorfulltrue)
# true 'average error':
errorfulltrues[i] <- mean(errorfulltrue, na.rm=TRUE)

errorincompltrue <- unlist(errorincompltrue)
# true 'average incomplete error':
errorincompltrues[i] <- mean(errorincompltrue, na.rm=TRUE)

# Percentage of missing values (zero in all cases):
errorfullmiss[i] <- mean(is.na(errorfulltrue))
errorincomplmiss[i] <- mean(is.na(errorincompltrue))


# Combine fold errors of full CV:

errorfullsimitalls[[i]] <- list()
k <- 1

for(j in seq(along=errorfullsimitall)) {
  for(l in 1:length(errorfullsimitall[[j]])) {
    errorfullsimitalls[[i]][[k]] <- errorfullsimitall[[j]][[l]]
    k <- k+1
  }
}


# Combine fold errors of incomplete CV:

errorincomplsimitalls[[i]] <- list()
k <- 1

for(j in seq(along=errorincomplsimitall)) {
  for(l in 1:length(errorincomplsimitall[[j]])) {
    errorincomplsimitalls[[i]][[k]] <- errorincomplsimitall[[j]][[l]]
    k <- k+1
  }
}

}


# Include certain simulation results into the table where the
# simulation scenario parameters are stored:

tableresults$errorfulltrues <- errorfulltrues
tableresults$errorincompltrues <- errorincompltrues

errorfullmiss
errorincomplmiss

# errorfull: mean error of repeated incomplete CV,
# erroraddon: mean error of repeated full CV
measure <- function(errorfull, erroraddon) {
  meas <- sapply(1 - errorfull/erroraddon, function(x) max(c(0, x)))
  meas[is.na(meas)] <- 0
  return(meas)
}

# CVIIM_P,n,K-values:
tableresults$CVIIMtrue <- measure(tableresults$errorincompltrues, tableresults$errorfulltrues)

# Averages over CVIIM_s,n,K-values:
tableresults$CVIIMestmean <- mapply(function(x, y) mean(measure(sapply(y, mean), sapply(x, mean))), errorfullsimitalls, errorincomplsimitalls)

tableresults$meancov <- factor(tableresults$meancov, levels=c("corbigsignal", "corweaksignal"))



# Calculate the values of the "observed variability" (see Additional file 2):

# errorfull: errors of incomplete CV,
# erroraddon: errors of full CV
measureb <- function(errorfull, erroraddon) {
  meas <- 1 - errorfull/erroraddon
  return(meas)
}

CVIIMb <- list()

for(i in 1:nrow(tableresults)) {
  CVIIMb[[i]] <- mapply(function(x, y) mapply(function(x2, y2) measureb(mean(x2), mean(y2)), data.frame(x), data.frame(y)), errorincomplsimitalls[[i]], errorfullsimitalls[[i]])
  cat(paste("Scenario", i, "of", nrow(tableresults)), "\n")
}

CVIIMb <- lapply(CVIIMb,  function(x) {x[is.na(x)] <- 0; x})
CVIIMb <- lapply(CVIIMb,  function(x) {x[is.infinite(x)] <- NA; x})

CVIIMintrvar <- lapply(CVIIMb, function(x) apply(x, 2, var, na.rm=TRUE))


# Save the fold errors occuring in full and incomplete CV, as well as the extended table of the 
# simulation scenario parameters:
save(errorfullsimitalls, errorincomplsimitalls, tableresults, CVIIMintrvar, file="SimulationResults.RData")

# Clear the workspace:
rm(list=ls())



##############################
##############################
##############################
##############################
##############################
##############################
##############################
##############################
##############################



# After the above (time-consuming) part has been executed once the following
# code can be executed independently of the above:

if(exists("workingdir"))
  setwd(workingdir)


# Load the simulation results stored with the above code:

load("~/SimulationCVIIM/confs/SimulationResults.RData")

measure <- function(errorfull, erroraddon) {
  meas <- sapply(1 - errorfull/erroraddon, function(x) max(c(0, x)))
  meas[is.na(meas)] <- 0
  return(meas)
}

# Calculate the CVIIM_s,n,K-values:
CVIIMest <- mapply(function(x, y) measure(sapply(y, mean), sapply(x, mean)), errorfullsimitalls, errorincomplsimitalls, SIMPLIFY=FALSE)






# Plot: Estimates CVIIM_s,n,K from all simulation iterations and true CVIIM_P,n,K-values:

tableresults2 <- tableresults
tableresults2$K <- paste("K = ", tableresults2$K, sep="")
tableresults2$K <- factor(tableresults2$K, levels=c("K = 3", "K = 5", "K = 10"))

tableresults2$psel <- paste("psel = ", tableresults2$psel, sep="")
tableresults2$psel <- factor(tableresults2$psel, levels=c("psel = 10", "psel = 1000"))

tableresults2$n_meancov <- paste(tableresults2$n, tableresults2$meancov, sep="_")
tableresults2$n_meancov <- factor(tableresults2$n_meancov, levels=c("50_corbigsignal", "50_corweaksignal", 
  "100_corbigsignal", "100_corweaksignal"))

tableresults2$IDscen <- 1:nrow(tableresults2)

CVIIMdataframe <- data.frame(IDscen=rep(1:length(CVIIMest), times=sapply(CVIIMest, length)), CVIIM=unlist(CVIIMest))

CVIIMresults <- merge(tableresults2, CVIIMdataframe, by="IDscen")

xlength <- 0.4
tableresults3 <- data.frame(tableresults2[rep(1:nrow(tableresults2), each=2),], x=rep(as.numeric(tableresults2$n_meancov), each=2) + rep(c(-1,1)*xlength, times=nrow(tableresults2)))

library("reshape")
tableresults3long <- reshape(tableresults3, varying=list(c("CVIIMtrue", "CVIIMestmean")), v.names=c("CVIIMtrueestmean"),
  direction="long")
tableresults3long$lineID <- paste(tableresults3long$IDscen, tableresults3long$time)

# , linetype=factor(time)
# IDscen + time
library("ggplot2")
library("grid")
p <- ggplot(data=CVIIMresults, aes(x=n_meancov, y=CVIIM)) +
  geom_boxplot() +   geom_line(data=tableresults3long, aes(x=x, y=CVIIMtrueestmean, group=lineID, color=factor(time), linetype=factor(time))) + facet_wrap(~ K + psel, nrow=3, ncol=2) + 
  scale_x_discrete(breaks=levels(CVIIMresults$n_meancov), labels=c("strong eff.\nn = 50", "weak eff.\nn = 50", "strong eff.\nn = 100", "weak eff.\nn = 100")) +
  theme(legend.title=element_blank(), legend.position="bottom", legend.key.width=unit(3,"line")) + 
  scale_color_discrete(labels=c(expression(CVIIM["P,n,K"]), expression(mean(CVIIM[paste(bold(s), ",n,K", sep="")])))) +
  scale_color_manual(values = c("red", "blue"), labels=c(expression(CVIIM["P,n,K"]), expression(mean(CVIIM[paste(bold(s), ",n,K", sep="")])))) + 
  scale_linetype_discrete(labels=c(expression(CVIIM["P,n,K"]), expression(mean(CVIIM[paste(bold(s), ",n,K", sep="")])))) +
  labs(x="", y=expression(CVIIM[paste(bold(s), ",n,K", sep="")]))
  
p

ggsave(file="./CVIIMCodeData/Plots/Supplementary Figure 1.eps", width=7.5, height=10.5)







tableresults2$n <- factor(paste("n = ", tableresults2$n, sep=""), levels=c("n = 50", "n = 100")) 

p1 <- ggplot(data=tableresults2, aes(x=n, y=CVIIMtrue)) + geom_line(aes(group=paste(K, meancov, psel))) +
  labs(title="n", x="", y=expression(CVIIM["P,n,K"])) +
  geom_point()
p1

p2 <- ggplot(data=tableresults2, aes(x=K, y=CVIIMtrue)) + geom_line(aes(group=paste(n, meancov, psel))) +
  labs(title="K", x="", y=expression(CVIIM["P,n,K"])) +
  geom_point()
p2

p3 <- ggplot(data=tableresults2, aes(x=meancov, y=CVIIMtrue)) + geom_line(aes(group=paste(K, n, psel))) +
  labs(title="MeanCov", x="", y=expression(CVIIM["P,n,K"])) +
  scale_x_discrete(labels=c("strong signal", "weak signal")) + 
  geom_point()
p3

p4 <- ggplot(data=tableresults2, aes(x=psel, y=CVIIMtrue)) + geom_line(aes(group=paste(K, n, meancov))) +
  labs(title="psel", x="", y=expression(CVIIM["P,n,K"])) +
  geom_point()
p4


library("gridExtra")
grobframe <- arrangeGrob(p1, p2, p3, p4, ncol=2, nrow=2) 
grobframe

ggsave(file="./CVIIMCodeData/Plots/Supplementary Figure 2.eps", plot=grobframe, width=10, height=7)







# Plot: (Approximated) true variances of CVIIM_s,n,K for different parameter settings
# grouped according to n, K, MeanCov and psel, and scatterplot of the variance of CVIIM_s,n,K
# vs. the true CVIIM_P,n,K-values. The true variances are approximated by the empirical variances
# over the 2000 simulation iterations:


tableresults2$CVIIMvar <- sapply(CVIIMest, var)

p1 <- ggplot(data=tableresults2, aes(x=n, y=CVIIMvar)) + geom_line(aes(group=paste(K, meancov, psel))) +
  labs(title="n", x="", y=expression(V(CVIIM[paste(bold(s), ",n,K", sep="")]))) +
  geom_point()
p1

p2 <- ggplot(data=tableresults2, aes(x=K, y=CVIIMvar)) + geom_line(aes(group=paste(n, meancov, psel))) +
  labs(title="K", x="", y=expression(V(CVIIM[paste(bold(s), ",n,K", sep="")]))) +
  geom_point()
p2

p3 <- ggplot(data=tableresults2, aes(x=meancov, y=CVIIMvar)) + geom_line(aes(group=paste(K, n, psel))) +
  labs(title="MeanCov", x="", y=expression(V(CVIIM[paste(bold(s), ",n,K", sep="")]))) +
  scale_x_discrete(labels=c("strong signal", "weak signal")) + 
  geom_point()
p3

p4 <- ggplot(data=tableresults2, aes(x=psel, y=CVIIMvar)) + geom_line(aes(group=paste(K, n, meancov))) +
  labs(title="psel", x="", y=expression(V(CVIIM[paste(bold(s), ",n,K", sep="")]))) +
  geom_point()
p4

p5 <- ggplot(data=tableresults2, aes(x=CVIIMtrue, y=CVIIMvar)) + 
  geom_point(aes(color=psel, shape=psel)) +
  theme(legend.title=element_blank(), legend.position=c(0.22,0.85)) + 
  scale_shape_manual(values=c(1,3)) + 
  labs(title="", x=expression(CVIIM["P,n,K"]), y=expression(V(CVIIM[paste(bold(s), ",n,K", sep="")])))
p5


library("gridExtra")
grobframe <- arrangeGrob(p1, p2, p3, p4, p5, ncol=3, nrow=2) 
grobframe

ggsave(file="./CVIIMCodeData/Plots/Supplementary Figure 3.eps", plot=grobframe, width=11, height=7)









# This function is the function 'draw.ellipse' from the plotrix package,
# modified to return the 'x' and 'y' values of the ellipse
# instead of drawing the ellipse:

mydraw.ellipse <- function (x, y, a = 1, b = 1, angle = 0, segment = c(0, 360), 
    arc.only = TRUE, deg = TRUE, nv = 100, border = NULL, col = NA, 
    lty = 1, lwd = 1, ...) 
{
    draw1ellipse <- function(x, y, a = 1, b = 1, angle = 0, segment = c(0, 
        360), arc.only = TRUE, nv = 100, deg = TRUE, border = NULL, 
        col = NA, lty = 1, lwd = 1, ...) {
        if (deg) {
            angle <- angle * pi/180
            segment <- segment * pi/180
        }
        z <- seq(segment[1], segment[2], length = nv + 1)
        xx <- a * cos(z)
        yy <- b * sin(z)
        alpha <- xyangle(xx, yy, directed = TRUE, deg = FALSE)
        rad <- sqrt(xx^2 + yy^2)
        xp <- rad * cos(alpha + angle) + x
        yp <- rad * sin(alpha + angle) + y
        if (!arc.only) {
            xp <- c(x, xp, x)
            yp <- c(y, yp, y)
        }
       ### polygon(xp, yp, border = border, col = col, lty = lty, 
       ###     lwd = lwd, ...)
       ### invisible(NULL)
       return(data.frame(x=xp, y=yp))  #####
    }
    xyangle <- function(x, y, directed = FALSE, deg = TRUE) {
        if (missing(y)) {
            y <- x[, 2]
            x <- x[, 1]
        }
        out <- atan2(y, x)
        if (!directed) 
            out <- out%%pi
        if (deg) 
            out <- out * 180/pi
        out
    }
    if (missing(y)) {
        y <- x[, 2]
        x <- x[, 1]
    }
    n <- length(x)
    if (length(a) < n) 
        a <- rep(a, n)[1:n]
    if (length(b) < n) 
        b <- rep(b, n)[1:n]
    if (length(angle) < n) 
        angle <- rep(angle, n)[1:n]
    if (length(col) < n) 
        col <- rep(col, n)[1:n]
    if (length(border) < n) 
        border <- rep(border, n)[1:n]
    if (length(nv) < n) 
        nv <- rep(nv, n)[1:n]
    if (n == 1) 
        return(draw1ellipse(x, y, a, b, angle = angle, segment = segment,   ###
            arc.only = arc.only, deg = deg, nv = nv, col = col, 
            border = border, lty = lty, lwd = lwd, ...))
    else {
        if (length(segment) < 2 * n) 
            segment <- matrix(segment[1:2], n, 2, byrow = TRUE)
        lapply(1:n, function(i) draw1ellipse(x[i], y[i], a[i], 
            b[i], angle = angle[i], segment = segment[i, ], arc.only = arc.only, 
            deg = deg, nv = nv[i], col = col[i], border = border[i], 
            lty = lty, lwd = lwd, ...))
    }
    invisible(NULL)
}




ellipse1 <- mydraw.ellipse(mean(tableresults2$errorfulltrues[tableresults2$psel=="psel = 10" & 
  tableresults2$meancov=="corbigsignal"]), mean(tableresults2$CVIIMtrue[tableresults2$psel=="psel = 10" & 
  tableresults2$meancov=="corbigsignal"]), 0.031, 0.08, border=2,
 angle=-17, lty=1)
ellipse2 <- mydraw.ellipse(mean(tableresults2$errorfulltrues[tableresults2$psel=="psel = 10" & 
  tableresults2$meancov=="corweaksignal"])+0.005, mean(tableresults2$CVIIMtrue[tableresults2$psel=="psel = 10" & 
  tableresults2$meancov=="corweaksignal"])+0.006, 0.025, 0.082, border=2,
 angle=-27, lty=2)
ellipse3 <- mydraw.ellipse(mean(tableresults2$errorfulltrues[tableresults2$psel=="psel = 1000" & 
  tableresults2$meancov=="corbigsignal"]), mean(tableresults2$CVIIMtrue[tableresults2$psel=="psel = 1000" & 
  tableresults2$meancov=="corbigsignal"]), 0.031, 0.09, border=4,
 angle=-25, lty=1)
ellipse4 <- mydraw.ellipse(mean(tableresults2$errorfulltrues[tableresults2$psel=="psel = 1000" & 
  tableresults2$meancov=="corweaksignal"]), mean(tableresults2$CVIIMtrue[tableresults2$psel=="psel = 1000" & 
  tableresults2$meancov=="corweaksignal"]), 0.031, 0.09, border=4,
 angle=-25, lty=2)


# Determine default colors of 'ggplot2'-package:
gg_color_hue <- function(n) {
  hues = seq(15, 375, length=n+1)
  hcl(h=hues, l=65, c=100)[1:n]
}
cols = gg_color_hue(2)

p1 <- ggplot(data=tableresults2, aes(x=errorfulltrues, y=CVIIMtrue)) + 
  geom_point(aes(color=psel, shape=psel)) +
  theme(legend.title=element_blank(), legend.position=c(0.15,0.9)) +
  geom_path(data=ellipse1, aes(x=x, y=y), colour=cols[1]) + 
  geom_path(data=ellipse2, aes(x=x, y=y), colour=cols[1], linetype=2) + 
  geom_path(data=ellipse3, aes(x=x, y=y), colour=cols[2]) + 
  geom_path(data=ellipse4, aes(x=x, y=y), colour=cols[2], linetype=2) + 
  scale_shape_manual(values=c(1,3)) +
  labs(x=expression(paste("E", group("[", e["full, K"](bold(S)), "]"), sep="")), y=expression(CVIIM["P,n,K"])) + 
  guides(linetype=FALSE)
p1



ellipse1 <- mydraw.ellipse(mean(tableresults2$errorfulltrues[tableresults2$psel=="psel = 10" & 
  tableresults2$meancov=="corbigsignal"]), 2.5*mean((tableresults2$errorfulltrues - tableresults2$errorincompltrues)[tableresults2$psel=="psel = 10" & 
  tableresults2$meancov=="corbigsignal"]), 0.028, 0.05, border=2,
 angle=-45, lty=1)
ellipse2 <- mydraw.ellipse(mean(tableresults2$errorfulltrues[tableresults2$psel=="psel = 10" & 
  tableresults2$meancov=="corweaksignal"])+0.013, 2.5*(mean((tableresults2$errorfulltrues - tableresults2$errorincompltrues)[tableresults2$psel=="psel = 10" & 
  tableresults2$meancov=="corweaksignal"])+0.004), 0.02, 0.085, border=2,
 angle=-35, lty=2)
ellipse3 <- mydraw.ellipse(mean(tableresults2$errorfulltrues[tableresults2$psel=="psel = 1000" & 
  tableresults2$meancov=="corbigsignal"]), 2.5*(mean((tableresults2$errorfulltrues - tableresults2$errorincompltrues)[tableresults2$psel=="psel = 1000" & 
  tableresults2$meancov=="corbigsignal"])+0.002), 0.025, 0.085, border=4,
 angle=-28, lty=1)
ellipse4 <- mydraw.ellipse(mean(tableresults2$errorfulltrues[tableresults2$psel=="psel = 1000" & 
  tableresults2$meancov=="corweaksignal"]), 2.5*mean((tableresults2$errorfulltrues - tableresults2$errorincompltrues)[tableresults2$psel=="psel = 1000" & 
  tableresults2$meancov=="corweaksignal"]), 0.031, 0.105, border=4,
 angle=-22, lty=2)

p2 <- ggplot(data=tableresults2, aes(x=errorfulltrues, y=2.5*(errorfulltrues - errorincompltrues))) + 
  geom_point(aes(color=psel, shape=psel)) +
  theme(legend.position="none") +
  geom_path(data=ellipse1, aes(x=x, y=y), colour=cols[1]) + 
  geom_path(data=ellipse2, aes(x=x, y=y), colour=cols[1], linetype=2) + 
  geom_path(data=ellipse3, aes(x=x, y=y), colour=cols[2]) + 
  geom_path(data=ellipse4, aes(x=x, y=y), colour=cols[2], linetype=2) + 
  scale_shape_manual(values=c(1,3)) +
  scale_y_continuous(breaks=2.5*c(0.05, 0.1, 0.15), labels=c(0.05, 0.1, 0.15)) +
  labs(x=expression(paste("E", group("[", e["full, K"](bold(S)), "]"), sep="")), y=expression(paste("max", group("(", ~~ paste(paste("E", group("[", e["full, K"](bold(S)), "]"), sep="") ~~ - ~~ paste("E", group("[", e["incompl, K"](bold(S)), "]"), sep=""), ", 0 ", sep=""), ")"), sep="")))

p2


library("gridExtra")
grobframe <- arrangeGrob(p1, p2, ncol=2, nrow=1) 
grobframe

ggsave(file="./CVIIMCodeData/Plots/Supplementary Figure 4.eps", plot=grobframe, width=11, height=5)
















# Plot: Estimates CVIIM_s,n,K from all simulation iterations and true CVIIM_P,n,K-values:


# Modified functions from ggplot2 to draw boxplots without outliers:

geom_boxplot_noOutliers <- function (mapping = NULL, data = NULL, stat = "boxplot",
                          position = "dodge", outlier.colour = NULL,
                          outlier.shape = NULL, outlier.size = NULL,
                          notch = FALSE, notchwidth = .5, varwidth = FALSE,
                          ...) {

  #outlier_defaults <- ggplot2:::Geom$find('point')$default_aes()
  #outlier.colour   <- outlier.colour %||% outlier_defaults$colour
  #outlier.shape    <- outlier.shape  %||% outlier_defaults$shape
  #outlier.size     <- outlier.size   %||% outlier_defaults$size

  GeomBoxplot_noOutliers$new(mapping = mapping, data = data, stat = stat,
                  position = position, outlier.colour = outlier.colour,
                  outlier.shape = outlier.shape, outlier.size = outlier.size, notch = notch,
                  notchwidth = notchwidth, varwidth = varwidth, ...)
}


library("proto")

GeomBoxplot_noOutliers <- proto(ggplot2:::Geom, {
  objname <- "boxplot_noOutliers"

  reparameterise <- function(., df, params) {
    df$width <- df$width %||%
      params$width %||% (resolution(df$x, FALSE) * 0.9)

  # if (!is.null(df$outliers)) {
  #    suppressWarnings({
  #      out_min <- vapply(df$outliers, min, numeric(1))
  #      out_max <- vapply(df$outliers, max, numeric(1))
  #    })
  #    
  #    df$ymin_final <- pmin(out_min, df$ymin)
  #    df$ymax_final <- pmax(out_max, df$ymax)
  #   }

    # if `varwidth` not requested or not available, don't use it
    if (is.null(params) || is.null(params$varwidth) || !params$varwidth || is.null(df$relvarwidth)) {
      df$xmin <- df$x - df$width / 2
      df$xmax <- df$x + df$width / 2
    } else {
      # make `relvarwidth` relative to the size of the largest group
      df$relvarwidth <- df$relvarwidth / max(df$relvarwidth)
      df$xmin <- df$x - df$relvarwidth * df$width / 2
      df$xmax <- df$x + df$relvarwidth * df$width / 2
    }
    df$width <- NULL
    if (!is.null(df$relvarwidth)) df$relvarwidth <- NULL

    df
  }

  draw <- function(., data, ..., fatten = 2, outlier.colour = NULL, outlier.shape = NULL, outlier.size = 2,
                   notch = FALSE, notchwidth = .5, varwidth = FALSE) {
    common <- data.frame(
      colour = data$colour,
      size = data$size,
      linetype = data$linetype,
      fill = alpha(data$fill, data$alpha),
      group = data$group,
      stringsAsFactors = FALSE
    )

    whiskers <- data.frame(
      x = data$x,
      xend = data$x,
      y = c(data$upper, data$lower),
      yend = c(data$ymax, data$ymin),
      alpha = NA,
      common)

    box <- data.frame(
      xmin = data$xmin,
      xmax = data$xmax,
      ymin = data$lower,
      y = data$middle,
      ymax = data$upper,
      ynotchlower = ifelse(notch, data$notchlower, NA),
      ynotchupper = ifelse(notch, data$notchupper, NA),
      notchwidth = notchwidth,
      alpha = data$alpha,
      common)

  #  if (!is.null(data$outliers) && length(data$outliers[[1]] >= 1)) {
  #    outliers <- data.frame(
  #      y = data$outliers[[1]],
  #      x = data$x[1],
  #      colour = outlier.colour %||% data$colour[1],
  #      shape = outlier.shape %||% data$shape[1],
  #      size = outlier.size %||% data$size[1],
  #      fill = NA,
  #      alpha = NA,
  #      stringsAsFactors = FALSE)
  #    outliers_grob <- GeomPoint$draw(outliers, ...)
  #  } else {
      outliers_grob <- NULL
  #  }

    ggname(.$my_name(), grobTree(
      outliers_grob,
      GeomSegment$draw(whiskers, ...),
      GeomCrossbar$draw(box, fatten = fatten, ...)
    ))
  }

  guide_geom <- function(.) "boxplot_noOutliers"
  draw_legend <- function(., data, ...)  {
    data <- aesdefaults(data, .$default_aes(), list(...))
    gp <- with(data, gpar(col=colour, fill=alpha(fill, alpha), lwd=size * .pt, lty = linetype))
    gTree(gp = gp, children = gList(
      linesGrob(0.5, c(0.1, 0.25)),
      linesGrob(0.5, c(0.75, 0.9)),
      rectGrob(height=0.5, width=0.75),
      linesGrob(c(0.125, 0.875), 0.5)
    ))
  }

  default_stat <- function(.) StatBoxplot
  default_pos <- function(.) PositionDodge
  default_aes <- function(.) aes(weight=1, colour="grey20", fill="white", size=0.5, alpha = NA, shape = 16, linetype = "solid")
  required_aes <- c("x", "lower", "upper", "middle", "ymin", "ymax")

})



CVIIMintrvarsdataframe <- data.frame(IDscen=rep(1:length(CVIIMintrvar), times=sapply(CVIIMintrvar, length)), CVIIMintrvar=unlist(CVIIMintrvar))

CVIIMresults <- merge(tableresults2, CVIIMintrvarsdataframe, by="IDscen")

p1 <- ggplot(data=CVIIMresults, aes(x=CVIIMvar, y=CVIIMintrvar)) +
  theme(legend.title=element_blank(), legend.position=c(0.2,0.955)) +
  geom_boxplot_noOutliers(aes(group=paste(meancov, psel, n), colour=psel), width=0.003)  + facet_wrap(~ K, nrow=3, ncol=1) +
  labs(x=expression(V(CVIIM[paste(bold(s), ",n,K", sep="")])), y="Observed Variability")

p1

p2 <- ggplot(data=CVIIMresults, aes(x=log(CVIIMvar), y=log(CVIIMintrvar))) +
  theme(legend.position="none") +
  geom_boxplot_noOutliers(aes(group=paste(meancov, psel, n), colour=psel), width=0.3)  + facet_wrap(~ K, nrow=3, ncol=1) +
  labs(x=expression(log(V(CVIIM[paste(bold(s), ",n,K", sep="")]))), y="log(Observed Variability)")

p2


library("gridExtra")
grobframe <- arrangeGrob(p1, p2, ncol=2, nrow=1) 
grobframe

ggsave(file="./CVIIMCodeData/Plots/Supplementary Figure 5.eps", plot=grobframe, width=8, height=10)

