# Load the simulation setting:
##############################
# Set working directory to the folder in which this file is contained:
#and set path where user packages are installed
#---------------#
#.libPaths(c('~/R/smuc30',.libPaths()))
setwd("~/SimulationCVIIM")


##get command line arguments (settingnumber)
args <- commandArgs(trailingOnly = TRUE)
settingnumber<-as.numeric(args[1])
print('settingnumber:')
print(settingnumber)
load(paste("confs/scenario", settingnumber, ".RData", sep=""))
#----------------------#

# Load simulation parameters:
#####################################################################################

load(paste("confs/simu", meancov, ".RData", sep=""))
# Objects: "covs1inf", "covs2inf", "covsnoninf", "diffm", "p", "p1"  


# Load package for simulation from multivariate normal distribution:

library(mvtnorm)

# Load CMA for error estimation and classification functions:

library(CMA)
# Load the modified 'scdaCMA'-function which trains Nearest Shrunken Centroids,
# resp. in our case with delta = 0 (and s_0 = 0) Diagonal Linear Discriminant
# Analysis and returns a function to predict new observations.
source("confs/scdaCMApred.R")


# Load MASS-package for using the 'lda'-function:

library(MASS)



# First part:
# Approximate the real e_full and e_incompl for approximating the true
# CVIIM:
#######################################################################

# Initialize vectors for e_full and e_incompl in the iterations:

errorfullit <- errorincomplit <- 0


# 'nitertrueerror' repetitions of the simulation:

nitertrueerror <- 1e+5


# Learning set sizes:

ntrain <- ceiling(n*(K-1)/K)




#############################
## PARALLELIZATION NECESSARY
#############################
#------------------------------#
###use pbd mpi and deternmine own rank
library(pbdMPI)
init(set.seed=FALSE)
rank<-comm.rank()+1

###determine number of ranks
nranks<-comm.size()


#generate set seed for this rank
load("confs/seeds.RData")
set.seed(seeds[settingnumber])
seedrank<-sample(1:1e+09,nranks)[rank]
set.seed(seedrank)  



###determine number of tasks to be performed by this rank
ntasks<-floor(nitertrueerror/nranks)+c(rep(1,nitertrueerror%%nranks),rep(0,nranks-nitertrueerror%%nranks))[rank]

#generate seed for each i
seedslocal<-sample(1:1e+09,ntasks)


#generate seed for part B
seedB<-sample(1:1e+09,1)

# Start the simulation:



###
for(i in 1:ntasks) {
set.seed(seedslocal[i])
#--------------------------------#
# Simulate a data set of size n:

X1 <- rmvnorm(n = n/2, mean = rep(0, p1), sigma = covs1inf)
X2 <- rmvnorm(n = n/2, mean = diffm, sigma = covs2inf)
Xwhole <- rbind(X1, X2)

for(bb in 0:((p-p1)/p1-1)){
  Xwhole <- cbind(Xwhole, rmvnorm(n = n, mean = rep(0, p1), sigma = covsnoninf[[bb+1]]))
}

ywhole <- factor(rep(c(1,2),each=n/2))


# Randomly subset into a training set of size 'ntrain'
# and a test set of size 'n-train':

trainind <- sample(1:n, size=ntrain)
testind <- setdiff(1:n, trainind)

Xtrain <- Xwhole[trainind,]
ytrain <- ywhole[trainind]

Xtest <- Xwhole[testind,]
ytest <- ywhole[testind]


# Estimate full error from this iteration:

# Variable selection on the training set:
selg <- GeneSelection(y = ytrain, X = Xtrain, method = 't.test')@rankings[[1]][1:psel]


# If 'psel' equals to 10 LDA is performed, otherwise DLDA:

if(psel == 10) {

# Fit the LDA-model:
ldamodel <- lda(Xtrain[,selg], ytrain)

# predict ytest:
ypred <- predict(ldamodel, newdata=Xtest[,selg], type="class")$class

}
else {

# Fit the DLDA-model:
dldamodel <- scdaCMApred(Xtrain[,selg], ytrain, delta = 0, models=TRUE)

# predict ytest:
ypred <- dldamodel(Xtest[,selg])

}

# estimated full error:
errorfullit[i] <- mean(ypred!=ytest)



# Estimate incomplete error from this iteration:

# Variable selection on the whole data set:
selg <- GeneSelection(y = ywhole, X = Xwhole, method = 't.test')@rankings[[1]][1:psel]

if(psel == 10) {

# Fit the LDA-model:
ldamodel <- lda(Xtrain[,selg], ytrain)

# predict ytest:
ypred <- predict(ldamodel, newdata=Xtest[,selg], type="class")$class

}
else {

# Fit the DLDA-model:
dldamodel <- scdaCMApred(Xtrain[,selg], ytrain, delta = 0, models=TRUE)

# predict ytest:
ypred <- dldamodel(Xtest[,selg])

}

# estimated incomplete error:
errorincomplit[i] <- mean(ypred!=ytest)

}


# Calculate true e_full and e_incompl from the 'nitertrueerror' simulation 
# repetitions:
#--------#
###collect results
allerrorfullit<-gather(errorfullit)
allerrorincomplit<-gather(errorincomplit)
###compute means later (better if NAs exist), just  copying to keep the names (rank 1 only)
if(rank==1){
errorfulltrue <- allerrorfullit
errorincompltrue <- allerrorincomplit
}



# Second  part:
# Simulate data sets, and calculate full and incomplete errors, each time performing B = 300
# repetitions of the CV - all fold errors are stored:
##########################################################################################


# 'nitersim' repetitions of the simulation:

nitersim <- 2000
# 1000 should be enough, but if it would be no problem, 2000 would surely suffice.


# 'niter' corresponds to the B repetititions of the CV:

niter <- 300


# The fold errors for full and incomplete CV will be stored in a list:

errorfullsimit <- errorincomplsimit <- list()






#############################
## PARALLELIZATION NECESSARY
#############################



#-----------#
set.seed(seedB)


#determine number of tasks to be performed by this rank
ntasksB<-floor(nitersim/nranks)+c(rep(1,nitersim%%nranks),rep(0,nranks-nitersim%%nranks))[rank]

#generate local seeds for part B
seedslocalB<-sample(1:1e+09,ntasksB)



# Start the simulation:
#-----------------#
for(simit in 1:ntasksB) {
set.seed(seedslocalB[simit])

#--------------------#

  
# Simulate a data set of size n:

X1 <- rmvnorm(n = n/2, mean = rep(0, p1), sigma = covs1inf)
X2 <- rmvnorm(n = n/2, mean = diffm, sigma = covs2inf)
Xwhole <- rbind(X1, X2)

for(bb in 0:((p-p1)/p1-1)){
  Xwhole <- cbind(Xwhole, rmvnorm(n = n, mean = rep(0, p1), sigma = covsnoninf[[bb+1]]))
}

ywhole <- factor(rep(c(1,2),each=n/2))


# Generate learning sets for this iteration of the simulation:

cvdatasets <- GenerateLearningsets(y = ywhole, method = "CV", fold = K, niter=niter)


# Perform the full CV:

if(psel == 10)
  nestedcrossval <- classification(Xwhole, ywhole, learningsets = cvdatasets, 
    classifier = ldaCMA, nbgene = psel, genesellist = list(method = "t.test"))
else
  nestedcrossval <- classification(Xwhole, ywhole, learningsets = cvdatasets, 
    classifier = scdaCMA, nbgene = psel, genesellist = list(method = "t.test"), delta = 0)

errorfullsimit[[simit]] <- matrix(nrow=K, ncol=niter, data=evaluation(nestedcrossval, measure = "misclassification")@score)


# Perform the incomplete CV:

varinds <- GeneSelection(Xwhole, ywhole, method = "t.test")@rankings[[1]][1, 1:psel]
Xwholesub <- Xwhole[, varinds]

if(psel == 10)
  nestedcrossval <- classification(Xwholesub, ywhole, learningsets = cvdatasets, 
    classifier = ldaCMA)
else
  nestedcrossval <- classification(Xwholesub, ywhole, learningsets = cvdatasets, 
    classifier = scdaCMA, delta=0)

errorincomplsimit[[simit]] <- matrix(nrow=K, ncol=niter, data=evaluation(nestedcrossval, measure = "misclassification")@score)

}


# Save all relevant results, that is the (approximated) true e_true and e_incompl and for each simulation
# repetition the folds errors belonging to full and incomplete CV:
###########################################################################################

#--------------#
##collect results
errorfullsimitall<-gather(errorfullsimit)
 errorincomplsimitall<-gather(errorincomplsimit)

###save (rank 1 only)


if(rank==1){
save(errorfulltrue, errorincompltrue, errorfullsimitall, errorincomplsimitall, file=paste("confs/resultsscenario", settingnumber, ".RData", sep=""))
}

###finalize mpi
finalize()


#----------------#
