# The CMA-function 'scdaCMA' performing Nearest Shrunken Centroids doesn't return a 'model-object', 
# so independent observations cannot be predicted.
# Because of this the function was modified to return only a function to
# predict new observations:

scdaCMApred <- function (X, y, f, learnind, delta = 0.5, models = FALSE, ...) 
{
    nrx <- nrow(X)
    ly <- length(y)
    if (nrx != length(y)) 
        stop("Number of rows of 'X' must agree with length of y \n")
    if (missing(learnind)) 
        learnind <- 1:nrx
    if (length(learnind) > nrx) 
        stop("length of 'learnind' must be smaller than the number of observations. \n")
    y <- as.factor(y)
    K <- nlevels(y)
    levels(y) <- 1:K
    if (K > 2) 
        mode <- "multiclass"
    else mode <- "binary"
    y <- as.numeric(y) - 1
    Ylearn <- y[learnind]
    Xlearn <- X[learnind, ]
    centroids <- matrix(nrow = ncol(X), ncol = K)
    variances <- matrix(nrow = ncol(X), ncol = K)
    mk <- as.numeric(sqrt(1/table(Ylearn) - 1/length(learnind)))
    for (k in 1:K) {
        indk <- (Ylearn == (k - 1))
        centroids[, k] <- muk <- colMeans(Xlearn[indk, , drop = FALSE])
        variances[, k] <- colSums((Xlearn[indk, , drop = FALSE] - 
            muk)^2)
    }
    variances <- rowSums(variances)/(length(learnind) - K)
    overallmu <- colMeans(Xlearn)
    D <- ((centroids - overallmu)/mk) * variances^{
        -1/2
    }
    shrunkD <- sign(D) * pmax(abs(D) - delta, 0)
    shrunkcentroids <- overallmu + (mk * shrunkD) * variances^{
        1/2
    }
    priors <- as.numeric(-2 * log(table(Ylearn)/sum(table(Ylearn))))
    Xtest <- X[-learnind, , drop = FALSE]
    if (nrow(Xtest) == 0) {
        Xtest <- Xlearn
        y <- Ylearn
    }
    else y <- y[-learnind]
    dist <- t(apply(Xtest, 1, function(z) colSums((z - shrunkcentroids)^2/variances) + 
        priors))
    dist <- dist - rowMeans(dist)
    prob <- safeexp(-0.5 * dist)
    prob <- prob/rowSums(prob)
    yhat <- apply(prob, 1, which.max) - 1
    if (models == TRUE) 
        modd <- list(NULL)
    if (models == FALSE) 
        modd <- list(NULL)
    # new("cloutput", yhat = yhat, y = y, learnind = learnind, 
    #     prob = prob, method = "scDA", mode = mode, model = modd)

	
	# This function returned by 'scdaCMApred' can be used to classify new observations:
    function(xnew) {
      dist <- t(apply(xnew, 1, function(z) colSums((z - shrunkcentroids)^2/variances) + 
          priors))
      dist <- dist - rowMeans(dist)
      prob <- safeexp(-0.5 * dist)
      prob <- prob/rowSums(prob)
      yhat <- apply(prob, 1, which.max)
      yhat
    }
}

# To make the functions available inside 'scdaCMApred', we have to use the same environment
# as 'scdaCMA', in which this functions are kept:
environment(scdaCMApred) <- environment(scdaCMA)